<?php



/**

 * The admin-specific functionality of the plugin.

 *

 * @link       https://aonetheme.com/

 * @since      1.0.0

 *

 * @package    Appointy

 * @subpackage Appointy/admin

 */



/**

 * The admin-specific functionality of the plugin.

 *

 * Defines the plugin name, version, and two examples hooks for how to

 * enqueue the admin-specific stylesheet and JavaScript.

 *

 * @package    Appointy

 * @subpackage Appointy/admin

 * @author     Aone Team <aonetheme@gmail.com>

 */

class Appointy_Admin {



	/**

	 * The ID of this plugin.

	 *

	 * @since    1.0.0

	 * @access   private

	 * @var      string    $plugin_name    The ID of this plugin.

	 */

	private $plugin_name;



	/**

	 * The version of this plugin.

	 *

	 * @since    1.0.0

	 * @access   private

	 * @var      string    $version    The current version of this plugin.

	 */

	private $version;



	/**

	 * Initialize the class and set its properties.

	 *

	 * @since    1.0.0

	 * @param      string    $plugin_name       The name of this plugin.

	 * @param      string    $version    The version of this plugin.

	 */

	public function __construct( $plugin_name, $version ) {



		$this->plugin_name = $plugin_name;

		$this->version = $version;



	}



	/**

	 * Register the stylesheets for the admin area.

	 *

	 * @since    1.0.0

	 */

	public function enqueue_styles() {



		wp_enqueue_style( 'admin-core', APPOINTY_PLUGIN_URL . 'admin/css/appointy-admin.css', array(), $this->version, 'all' );
		
		wp_enqueue_script( 'admin-core', APPOINTY_PLUGIN_URL . 'admin/js/admin-core.js', array( 'jquery' ), $this->version, true );



	}
	
	/**
	 * Alerts messages html in footer
	 *
	 * @return void
	 */
	public function alerts_html_to_footer() {
		Appointy_Template_Loader::get_template_part( 'alert-message' );
	}

	/**
	 * Fetch google calendar events
	 *
	 * @return void
	 */
	public function process_fetch_gc_events() {
		$staffs = get_users( array( 'role__in' => array( 'appointy_staff' ) ) );
		
		if( !empty( $staffs ) ) {
			foreach( $staffs as $staff ) {
				$staffid = $staff->ID;
				Appointy_Google_Calendar_Helper::fetchGoogleCalendarAppointments($staffid);
			}
		}
		
	}
	
	/**
	 * Activare repeat service
	 *
	 * @return void
	 */
	public function process_activate_repeat_service() {
		global $wpdb;
		
		$appointment_id = 0;
		$results = $wpdb->get_results($wpdb->prepare('SELECT `appointment_id`,`service_id`,`repeat_service_id` FROM `'.$wpdb->prefix.'appointy_booked_services` WHERE `booking_date` < CURDATE() AND `has_repeat` = "yes" AND `appointment_id` > %d',$appointment_id));
		
		if(!empty($results)) {
			foreach($results as $row){
				$appointment_id = Appointy_Router_Helper::get_sanitize_data( $row, 'appointment_id' );
				$service_id = Appointy_Router_Helper::get_sanitize_data( $row, 'service_id' );
				$repeat_service_id = Appointy_Router_Helper::get_sanitize_data( $row, 'repeat_service_id' );
				
				$repeat_service['status']	= 'past';
				
				$where = array(
					'id' => $repeat_service_id
				);
				
				$wpdb->update($wpdb->prefix.'appointy_repeat_schedule',wp_unslash($repeat_service),$where);
				
				$results2 = $wpdb->get_row($wpdb->prepare('SELECT `id`,`date` FROM `'.$wpdb->prefix.'appointy_repeat_schedule` WHERE `status` = "upcoming" AND `appointment_id` = %d AND `service_id` = %d order by `date` asc limit 0,1',$appointment_id,$service_id));
				
				if(!empty($results2)) {
					$nextdate = Appointy_Router_Helper::get_sanitize_data( $results2, 'date' );
					$repeat_service_id = Appointy_Router_Helper::get_sanitize_data( $results2, 'id' );
					
					$booked_service['booking_date']	= $nextdate;
					$booked_service['repeat_service_id']	= $repeat_service_id;
					$booked_service['repeat_service_payment']	= 'pending';
					$booked_service['service_status']	= 'pending';
					
					$where = array(
						'appointment_id' => $appointment_id,
						'service_id' => $service_id
					);
					
					$wpdb->update($wpdb->prefix.'appointy_booked_services',wp_unslash($booked_service),$where);
					
					$repeat_service_update['status']	= 'active';
					
					$where = array(
						'id' => $repeat_service_id
					);
					
					$wpdb->update($wpdb->prefix.'appointy_repeat_schedule',wp_unslash($repeat_service_update),$where);
				}
			}
		}
		
	}

	/**

	 * Register the JavaScript for the admin area.

	 *

	 * @since    1.0.0

	 */

	public function enqueue_scripts() {

	

		/**

		 * Register admin scripts

		 * 

		 * js libraries

		 */

		 
		$pagename = Appointy_Router_Helper::get_request_param('page');
		
		if( is_admin() && isset($_GET['page']) && ($pagename === 'appointment' || $pagename === 'appointy-settings')) {

		$jsurl = ( is_ssl() ? 'https:' : 'http:' ) . '//cdn.datatables.net/1.12.1/js/jquery.dataTables.min.js';

		$cssurl = ( is_ssl() ? 'https:' : 'http:' ) . '//cdn.datatables.net/1.12.1/css/jquery.dataTables.min.css';

		

		$jsresponse = wp_remote_head($jsurl);

	

		// Load local file if CDN down

		if ( is_wp_error($jsresponse) || 200 != $jsresponse['response']['code'] ) {

	

			$jsurl = APPOINTY_PLUGIN_URL . 'assets/js/jquery.dataTables.min.js';

		}

		

		$cssresponse = wp_remote_head($cssurl);

		

		if ( is_wp_error($cssresponse) || 200 != $cssresponse['response']['code'] ) {

	

			$cssurl = APPOINTY_PLUGIN_URL . 'assets/css/jquery.dataTables.min.css';

		}

		$locale = substr(get_locale(), 0, 2);

		

		wp_register_script('datatables', $jsurl, [ 'jquery' ] , null, true);

		wp_register_style('datatables', $cssurl,'',null);

		

		$jsurl = ( is_ssl() ? 'https:' : 'http:' ) . '//cdn.datatables.net/1.12.1/js/dataTables.bootstrap5.min.js';

		$cssurl = ( is_ssl() ? 'https:' : 'http:' ) . '//cdn.datatables.net/1.12.1/css/dataTables.bootstrap5.min.css';

		

		$jsresponse = wp_remote_head($jsurl);

	

		// Load local file if CDN down

		if ( is_wp_error($jsresponse) || 200 != $jsresponse['response']['code'] ) {

	

			$jsurl = APPOINTY_PLUGIN_URL . 'assets/js/dataTables.bootstrap5.min.js';

		}

		

		$cssresponse = wp_remote_head($cssurl);

		

		if ( is_wp_error($cssresponse) || 200 != $cssresponse['response']['code'] ) {

	

			$cssurl = APPOINTY_PLUGIN_URL . 'assets/css/dataTables.bootstrap5.min.css';

		}

		

		wp_register_style('bootstrap-datatable', $cssurl,'',null);

		wp_register_script('bootstrap-datatable', $jsurl, [ 'jquery','datatables' ] , null, true);

		Appointy_Misc_Helper::dynamic_style();

		wp_register_style( 'bootstrap', APPOINTY_PLUGIN_URL . 'assets/css/bootstrap.min.css', [], false, 'all' );

		wp_register_script( 'bootstrap', APPOINTY_PLUGIN_URL . 'assets/js/bootstrap.min.js', ['jquery','popper'], false, true ); 

		

		wp_register_style( 'bootstrap-toggle', APPOINTY_PLUGIN_URL . 'assets/css/bootstrap4-toggle.min.css', [], false, 'all' );

		wp_register_script( 'bootstrap-toggle', APPOINTY_PLUGIN_URL . 'assets/js/bootstrap4-toggle.min.js', ['jquery'], false, true );

		

		wp_register_script( 'popper', APPOINTY_PLUGIN_URL . 'assets/js/popper.min.js', ['jquery'], false, true );

		

		wp_register_style( 'font-awesome', APPOINTY_PLUGIN_URL . 'assets/css/font-awesome.min.css', [], false, 'all' );
		
		wp_enqueue_style( 'appointy-gfonts', $this->fonts_url(), [], false, 'all' );

		

		wp_enqueue_style( 'feather', APPOINTY_PLUGIN_URL . 'assets/css/feather.css', [], false, 'all' );

		

		wp_register_style( 'fullcalendar-main', APPOINTY_PLUGIN_URL . 'assets/fullcalendar/main.min.css', '', null );

		wp_register_script( 'fullcalendar-main', APPOINTY_PLUGIN_URL . 'assets/fullcalendar/main.min.js', [ 'jquery' ], '5.11.2', true );

		

		wp_enqueue_script('bootbox', APPOINTY_PLUGIN_URL . 'assets/js/bootbox.min.js', [ 'jquery' ] , '5.5.2', true);

		wp_enqueue_script('bootbox-locales',  APPOINTY_PLUGIN_URL . 'assets/js/bootbox.locales.min.js', [ 'jquery' ] , '5.5.2', true);

		

		wp_register_style( 'bootstrap-datepicker', APPOINTY_PLUGIN_URL . 'assets/css/bootstrap-datepicker.min.css', '', null );

		wp_register_script( 'bootstrap-datepicker', APPOINTY_PLUGIN_URL . 'assets/js/datepicker/bootstrap-datepicker.min.js', [ 'jquery' ], '1.9.0', true );

		wp_register_script('bootstrap-datepicker-'.$locale, APPOINTY_PLUGIN_URL . 'assets/js/datepicker/locales/bootstrap-datepicker.'.$locale.'.js', [ 'jquery' ], '1.9.0', true );

		

		wp_enqueue_script( 'jquery-validate', APPOINTY_PLUGIN_URL . 'assets/js/dist/jquery.validate.min.js', [ 'jquery' ], '1.19.3', true );

		

		// Time picker scripts

		wp_enqueue_style('bootstrap-datetimepicker', APPOINTY_PLUGIN_URL . 'assets/css/bootstrap-datetimepicker.min.css','',null);

		wp_enqueue_script('moment-with-locales', APPOINTY_PLUGIN_URL . 'assets/js/moment-with-locales.js', [ 'jquery' ] , null, true);

		wp_enqueue_script('bootstrap-datetimepicker', APPOINTY_PLUGIN_URL . 'assets/js/bootstrap-datetimepicker.min.js', [ 'jquery' ] , '4.17.47', true);

		

		wp_enqueue_script('jRate',  APPOINTY_PLUGIN_URL . 'assets/js/jRate.js', [ 'jquery' ] , null, true);

		

		wp_register_style('daterangepicker', APPOINTY_PLUGIN_URL . 'assets/css/daterangepicker.css','',null);

		wp_register_script('daterangepicker', APPOINTY_PLUGIN_URL . 'assets/js/daterangepicker.js', [ 'jquery' ] , '3.1', true);

		

		wp_register_script( 'jquery-validate', APPOINTY_PLUGIN_URL . 'assets/js/dist/jquery.validate.min.js', [ 'jquery' ], '1.19.5', true );

		

		wp_enqueue_script( 'bootstrap-datepicker' );

		if( 'en' != $locale ) {



			wp_enqueue_script( 'bootstrap-datepicker-'.$locale );

		}

		wp_enqueue_style( 'bootstrap-datepicker' );

		

		

		

		//For google autocomplete
		wp_register_script('maps-googleapis', '//maps.googleapis.com/maps/api/js?key='.Appointy_Map_Helper::get_google_api_key().'&libraries=places', [ 'jquery' ] , null, false);


		/*Bootstrap Charts (Graphs)*/

		wp_register_script('mdb-chart', APPOINTY_PLUGIN_URL . 'assets/js/mdb.min.js', [ 'jquery' ] , '4.20.0', true);

		

		wp_register_script('bootstrap-slider', APPOINTY_PLUGIN_URL . 'assets/js/bootstrap-slider.min.js', [ 'jquery' ] , '11.0.2', true);

		wp_register_style( 'bootstrap-slider', APPOINTY_PLUGIN_URL . 'assets/css/bootstrap-slider.min.css', '', null );

		wp_enqueue_script('livestamp', APPOINTY_PLUGIN_URL . 'assets/js/livestamp.js', [ 'jquery' ] , null, true);
		
		wp_enqueue_style('select2', APPOINTY_PLUGIN_URL . 'assets/css/select2.min.css','',null);
		wp_enqueue_script('select2', APPOINTY_PLUGIN_URL . 'assets/js/select2.min.js', [ 'jquery' ] , null, true);

		if( is_admin() && isset($_GET['page']) && ($pagename === 'appointment' || $pagename === 'appointy-settings')) {
		wp_register_style( 'appointy-admin-style', APPOINTY_PLUGIN_URL . 'assets/css/admin-style.css', '', null );
		}

		wp_register_script( 'appointy-global', APPOINTY_PLUGIN_URL . 'assets/js/global.js', array( 'jquery' ), $this->version, true );
		
		if(Appointy_Router_Helper::jamming_rules() === true) {
		wp_register_script( $this->plugin_name, APPOINTY_PLUGIN_URL . 'admin/js/appointy-admin.js', array( 'jquery' ), $this->version, true );
		}

		

		wp_enqueue_style( 'bootstrap-toggle' );

		wp_enqueue_script( 'bootstrap-toggle' );

		wp_enqueue_style('bootstrap');

		wp_enqueue_script('bootstrap');

		wp_enqueue_script('popper');

		wp_enqueue_style('font-awesome');

		wp_enqueue_style('appointy-admin-style');
		
		wp_enqueue_script( 'appointy-global' );

		}
		
		$locale = substr(get_locale(), 0, 2);

		$appointy_options = array(

			'_nonce' => wp_create_nonce( 'appointy_ajax_nonce' ),

			'not_avl' => esc_html__( 'Not available', 'appointy' ),

			'image_text' => esc_html__( 'Upload Image','appointy' ),

			'dateformat' => Appointy_Misc_Helper::datepicker_format(),

			'timezone' => wp_timezone_string(),

			'default_country_code' => Appointy_Location_Helper::get_default_country_code(),

			'default_country' => Appointy_Location_Helper::get_default_country(),

			'default_state' => Appointy_Location_Helper::get_default_state(),

			'are_you_sure' => esc_html__( 'Are you sure?', 'appointy' ),

			'select_checkbox' => esc_html__( 'Please select atleast one checkbox', 'appointy' ),

			'sEmptyTable' => esc_html__( 'No data available in table', 'appointy' ),

			'sInfo' => esc_html__( 'Showing _START_ to _END_ of _TOTAL_ entries', 'appointy' ),

			'sInfoEmpty' => esc_html__( 'Showing 0 to 0 of 0 entries', 'appointy' ),

			'sInfoFiltered' => esc_html__( '(filtered from _MAX_ total entries)', 'appointy' ),

			'sLengthMenu' => esc_html__( 'Show _MENU_ entries', 'appointy' ),

			'sLoadingRecords' => esc_html__( 'Loading...', 'appointy' ),

			'sProcessing' => esc_html__( 'Processing...', 'appointy' ),

			'sSearch' => esc_html__( 'Search:', 'appointy' ),

			'sZeroRecords' => esc_html__( 'No matching records found', 'appointy' ),

			'sFirst' => esc_html__( 'First', 'appointy' ),

			'sLast' => esc_html__( 'Last', 'appointy' ),

			'sNext' => esc_html__( 'Next', 'appointy' ),

			'sPrevious' => esc_html__( 'Previous', 'appointy' ),

			'sSortAscending' => esc_html__( ': activate to sort column ascending', 'appointy' ),

			'sSortDescending' => esc_html__( ': activate to sort column descending', 'appointy' ),

			'sSortDescending' => esc_html__( ': activate to sort column descending', 'appointy' ),

			'minutes' => esc_html__( 'Minutes', 'appointy' ),

			'hours' => esc_html__( 'Hours', 'appointy' ),

			'price' => esc_html__( 'Price', 'appointy' ),

			'duration' => esc_html__( 'Duration', 'appointy' ),

			'service_name' => esc_html__( 'Service Name', 'appointy' ),

			'currency_symbol' => Appointy_Misc_Helper::get_currency_symbol(),

			'add_sale_price' => esc_html__( 'Please insert sale price', 'appointy' ),

			'add_regular_price' => esc_html__( 'Please insert regular price', 'appointy' ),

			'inert_veriation_name' => esc_html__( 'Please insert service veriation name', 'appointy' ),

			'date_n_time_required' => esc_html__( 'Please select appointment date & time by click on manage date & time button', 'appointy' ),

			'minutes_short' => esc_html__( 'Mins', 'appointy' ),

			'start_str' => esc_html__( 'Start', 'appointy' ),

			'end_str' => esc_html__( 'End', 'appointy' ),

			'select_startendtime' => esc_html__( 'Please select start and endtime', 'appointy' ),

			'endtime_greater_than_starttime' => esc_html__( 'End time should be greater than start time', 'appointy' ),

			'select_interval' => esc_html__( 'Please select interval', 'appointy' ),

			'start_date' => esc_html__( 'Start Date', 'appointy' ),

			'end_date' => esc_html__( 'End Date', 'appointy' ),

			'to' => esc_html__( 'to', 'appointy' ),

			'timeslot_exist' => esc_html__( 'This timeslot already taken.', 'appointy' ),

			'other_cancellation_reason' => esc_html__( 'Please enter reason for the cancellation', 'appointy' ),

			'select_starttime' => esc_html__( 'Please select start time', 'appointy' ),

			'validate_staff_member' => esc_html__( 'Please select staff member', 'appointy' ),

			'text_edit_staff' => esc_html__( 'Edit Member', 'appointy' ),

			'text_assign_staff' => esc_html__( 'Assign to the Member', 'appointy' ),
			
			'select_duration' => esc_html__( 'Please select duration', 'appointy' ),
			
			'locale' => $locale,
			
			'time_format' => (get_option( 'time_format' ) === 'H:i') ? 'HH:mm' : 'LT',
			
			'location' => esc_html__( 'Location', 'appointy' ),
			
			'staff_members' => esc_html__( 'Staff Members', 'appointy' ),
			
			'location_already_added' => esc_html__( 'Location already added!', 'appointy' ),
			
			'delete_str' => esc_html__( 'Remove', 'appointy' ),
			
			'all_locations' => esc_html__( 'All Locations', 'appointy' ),
			
			'select_member' => esc_html__( 'Please select staff member', 'appointy' ),
			
			'select_location' => esc_html__( 'Please select location', 'appointy' ),
			
			'enter_regular_price' => esc_html__( 'Please enter regular price', 'appointy' ),
			
			'regular_price' => esc_html__( 'Regular Price', 'appointy' ),
			
			'sale_price' => esc_html__( 'Sale Price', 'appointy' ),
			
			'add_price_by_locations' => esc_html__( 'Add Price by Locations', 'appointy' ),
			
			'enter_start_end_time' => esc_html__( 'Please enter start and end time.', 'appointy' ),
			
			'select_avl_dates' => esc_html__( 'Please select only avaialble dates.', 'appointy' ),

		);

		wp_localize_script( $this->plugin_name, 'appointy_options', $appointy_options);



	}
	
	public function fonts_url() {
		$fonts_url = '';
		
		if ( 'off' !== _x( 'on', 'Google font: on or off', 'appointy' ) ) {

			$Poppins = _x( 'on', 'Poppins font: on or off', 'appointy' );
			
			if ( 'off' !== $Poppins ) {
				$font_families = array();
				 
				if ( 'off' !== $Poppins ) {
				$font_families[] = 'Poppins:wght@300,400,500,600,700,800,900';
				}
				 
				$final_fonts = array_unique( $font_families );
				$query_args  = [
					'family'  => urlencode( implode( '|', $final_fonts ) ),
					'display' => urlencode( 'swap' ),
				];
	
				$fonts_url = add_query_arg( $query_args, "//fonts.googleapis.com/css" );
			}

		}
		
		return esc_url_raw( $fonts_url );
	}

	

	public function create_menu() {



		add_menu_page( esc_html__( 'Product License', 'appointy' ), esc_html__( 'Product License', 'appointy' ), 'manage_options', 'product-license', array( $this, 'display_product_license_page' ),'dashicons-admin-network', 10 );
		
		if(Appointy_Router_Helper::is_code_activator() === true) {
		add_menu_page( esc_html__( 'Appointy', 'appointy' ), esc_html__( 'Appointy', 'appointy' ), 'manage_options', 'appointment', array($this, 'display_plugin_setup_page' ),'dashicons-businessman', 15 );
		}



	}

	

	public function admin_body_class( $classes ) {
		
		$pagename = Appointy_Router_Helper::get_request_param('page');
		
		if( is_admin() && isset($_GET['page']) && ($pagename === 'appointment' || $pagename === 'appointy-settings')) {

		  $classes = $classes.' appointy-admin appointy';

		}

		return $classes;

	}

	

	

	public function display_plugin_setup_page() {



		Appointy_Template_Loader::get_template_part( 'admin/layout' );

	

	}

	public function display_product_license_page() {



		Appointy_Template_Loader::get_template_part( 'admin/product-license' );

	

	}

}

