<?php 
class Appointy_Coupon_Helper {

	/**
     * Initialize the class
     *
     * @since     1.0.0
     */
    public function __construct() {
		add_action('wp_ajax_appointy_get_coupons', array($this, 'get_coupons'));
		add_action('wp_ajax_appointy_save_coupon', array($this, 'save_coupon'));
		add_action('wp_ajax_appointy_load_coupon', array($this, 'load_coupon'));
		add_action('wp_ajax_appointy_delete_coupon', array($this, 'delete_coupon'));
    }
	
	/**
	 * Get coupons
	 *
	 * @return void
	 */
	public static function get_coupons() {
	    global $wpdb;
		
		$args = array(
            'post_type' => 'appointy_coupons',
            'post_status' => 'publish',
            'posts_per_page' => -1,
            'orderby' => 'ID',
            'order' => 'DESC',
        );
		
        $the_query = new \WP_Query($args);
		
		$data = array();
		if ( $the_query->have_posts() ) {
			$nestedData = array();
			while ( $the_query->have_posts() ) : $the_query->the_post();
				$couponid = get_the_id();
				
				$nestedData['delete'] = '<div class="checkbox sf-radio-checkbox">
											<input type="checkbox" id="coupon-'.esc_attr($couponid).'" value="'.esc_attr($couponid).'" class="delete_row delete_coupon">
											<label for="coupon-'.esc_attr($couponid).'"></label>
										</div>';
				$nestedData['coupon_code'] =  get_the_title();
				
				$discount_type = (get_post_meta($couponid,'discount_type',true) === 'percent') ? '%' : '$';
				
				$nestedData['discount'] =  get_post_meta($couponid,'discount',true).''.$discount_type;
				$nestedData['maxusage'] =  (get_post_meta($couponid,'maxusage',true) != '') ? get_post_meta($couponid,'maxusage',true) : '-';
				$nestedData['timeused'] =  '-';
				
				$status = self::get_coupon_status( $couponid );
				
				if( $status === 'expired' ) {
					$display_status = '<button type="button" class="btn btn-xs btn-light-danger">'.esc_html__('Expired', 'appointy').'</button>';
				} elseif( $status === 'inactive' ){
					$display_status = '<button type="button" class="btn btn-xs btn-light-warning">'.esc_html__('Inactive', 'appointy').'</button>';
				} elseif( $status === 'active' ){
					$display_status = '<button type="button" class="btn btn-xs btn-light-success">'.esc_html__('Active', 'appointy').'</button>';
				}
				
				$nestedData['status'] =  $display_status;
				
				$actions = '<div class="dropdown action-dropdown dropdown-left">
							  <button class="action-button btn btn-primary dropdown-toggle" type="button" data-bs-toggle="dropdown"><i class="fa fa-ellipsis-v"></i></button>
							  <ul class="dropdown-menu">
								<li><a href="javascript:;" class="dropdown-item editcoupon" data-couponid="'.esc_attr($couponid).'"><i class="fa fa-pencil"></i> '.esc_html__( 'Edit','appointy' ).'</a></li>
							  </ul>
							</div>';
				
				$nestedData['action'] = $actions;
				
				$data[] = $nestedData;	
			endwhile;
		}
		
		$json_data = array( 'data' => $data );
		
		echo json_encode( $json_data );
		die();
	}
	
	/**
     * Save coupon
     *
     * @since    1.0.0
     */
    public function save_coupon() {
		global $current_user;
        if( ! wp_verify_nonce( $_POST['_nonce'], 'appointy_ajax_nonce' ) || !current_user_can('manage_options') ) {
			wp_send_json_error();
			die();
		}
		
		$couponid = Appointy_Router_Helper::get_sanitize_data( $_POST, 'couponid' );
		
		$coupon_fields = Appointy_Coupon_Helper::coupon_fields( $couponid );
                        
		$meta_fields = array();
		
		if( !empty($coupon_fields) ) {
			foreach( $coupon_fields as $key => $field ) {
				if($key === 'services') {
					$services = (!empty($_POST['services'])) ? $_POST['services'] : array();
		
					$services = (!empty($services)) ? implode(',',$services) : '';
		
					$meta_fields[$key] 	= $services;
				} else {
					$meta_fields[$key] 	= Appointy_Router_Helper::get_sanitize_data( $_POST, $key );
				}
				
			}
		}
		
		if( !empty( $couponid ) ) {
			$coupon_post = array(
				'ID'   	  	  =>  $couponid,
				'post_title' => Appointy_Router_Helper::get_sanitize_data($_POST,'coupon_code'),
				'post_status' => 'publish',
				'post_type' => 'appointy_coupons',
				'post_author' => $current_user->ID,
				'meta_input'   => $meta_fields
			);
			$postid = wp_update_post( $coupon_post ) ;		
		} else {
			$coupon_post = array(
				'post_title' => Appointy_Router_Helper::get_sanitize_data($_POST,'coupon_code'),
				'post_status' => 'publish',
				'post_type' => 'appointy_coupons',
				'post_author' => $current_user->ID,
				'meta_input'   => $meta_fields
			);
			$postid = wp_insert_post( $coupon_post );
		}
		
		$response = array( 'msg' => esc_html__('Coupon saved.', 'appointy') );
        wp_send_json_success($response);
        die();
    }
	
	/**
	 * Get coupon status
	 *
	 * @return string
	 */
	public static function get_coupon_status( $couponid = 0 ) {
		global $wpdb;
		
		$applies_date_from = get_post_meta($couponid,'applies_date_from',true);
		$applies_date_to = get_post_meta($couponid,'applies_date_to',true);
		
		if( strtotime($applies_date_to) < strtotime(date('Y-m-d')) ) {
			$status = 'expired';
		} elseif( strtotime(date('Y-m-d')) < strtotime($applies_date_from) ) {
			$status = 'inactive';
		} else {
			$status = 'active';
		}
		
		return $status;
	}
	
	/**
	 * Delete coupon
	 *
	 * @return array
	 */
	public static function delete_coupon() {
		global $wpdb;
		
		$data_ids = Appointy_Router_Helper::get_request_data( $_POST, 'data_ids' );
		
		$data_id_array = explode(",", $data_ids); 

		if(!empty($data_id_array)) {
			foreach($data_id_array as $locationid) {
				$force_delete = true;
				wp_delete_post( $locationid, $force_delete );
			}
		}
		
		wp_send_json_success();
		die();
	}
	
	/**
	 * Process load coupon
	 *
	 * @return array
	 */
	public static function load_coupon( ) {
		global $wpdb;
		
		$couponid = Appointy_Router_Helper::get_request_data( $_POST, 'couponid' );
		
		$coupon_fields = Appointy_Coupon_Helper::coupon_fields( $couponid );
                        
		$meta_fields = array();
		
		if( !empty($coupon_fields) ) {
			foreach( $coupon_fields as $key => $field ) {
				if($key === 'services') {
					$services = get_post_meta($couponid, $key, true);
					
					if(!empty($services)) {
						$services = explode(',',$services);
						$services = json_encode($services);
					}else{
						$services = array();
						$services = json_encode($services);
					}
					$meta_fields[$key] 	= $services;
				} else {
					$meta_fields[$key] 	= get_post_meta($couponid, $key, true);
				}
			}
		}
		
		$response = $meta_fields;
		
		wp_send_json_success($response);
		
   		die();
	}
	
	public static function coupon_fields( $post_id = 0 ) {
	
		$fields = apply_filters( 'appointy_coupon_form_fields', array(
			'coupon_code' => array(
				'label'       => esc_html__( 'Coupon Code', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-tag',
				'colum-width' => 'col-lg-12',
				'required'    => true,
				'placeholder' => '',
				'priority'    => 1
			),
			'discount' => array(
				'label'       => esc_html__( 'Discount', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-tag',
				'colum-width' => 'col-lg-6',
				'required'    => true,
				'placeholder' => '',
				'priority'    => 2
			),
			'discount_type' => array(
				'label'       => esc_html__( 'Discount Type', 'appointy' ),
				'type'        => 'select',
				'icon'        => 'fa fa-globe',
				'colum-width' => 'col-lg-6',
				'required'    => true,
				'placeholder' => '',
				'priority'    => 3,
				'options' 	  => array('percent' => '%','fixed' => '$')
			),
			'applies_date_from' => array(
				'label'       => esc_html__( 'Applies date from', 'appointy' ),
				'type'        => 'date',
				'default'     => '',
				'icon'        => 'fa fa-map-marker',
				'colum-width' => 'col-lg-6',
				'required'    => true,
				'priority'    => 4,
			),
			'applies_date_to' => array(
				'label'       => esc_html__( 'Applies date to', 'appointy' ),
				'type'        => 'date',
				'default'     => '',
				'icon'        => 'fa fa-map-marker',
				'colum-width' => 'col-lg-6',
				'required'    => true,
				'priority'    => 5
			),
			'maxusage' => array(
				'label'       => esc_html__( 'Max Usage', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-info',
				'colum-width' => 'col-lg-6',
				'required'    => false,
				'placeholder' => esc_html__( 'No Limit', 'appointy' ),
				'priority'    => 6
			),
			'services' => array(
				'label'       => esc_html__( 'Services', 'appointy' ),
				'type'        => 'multi-select',
				'default'     => '',
				'icon'        => 'fa fa-map-marker',
				'colum-width' => 'col-lg-6',
				'required'    => false,
				'placeholder' => esc_html__( 'Select service', 'appointy' ),
				'priority'    => 7,
				'options' 	  => Appointy_Service_Helper::get_service_array()
			),
		) );

		return Appointy_Form_Helper::get_fields( $fields );	
	}
	
}
new Appointy_Coupon_Helper();