<?php 
class Appointy_Emails_Helper {

	/**
     * Initialize the class
     *
     * @since     1.0.0
     */
    public function __construct() {
		
		add_action('admin_init', array($this, 'email_template_default_fields'));
		add_action('admin_init', array($this, 'email_template_fields'));
		
		add_action('wp_ajax_appointy_get_email_templates', array($this, 'get_email_templates'));
		add_action('wp_ajax_appointy_save_email_templates', array($this, 'save_email_templates'));
		
    }
	
	/**
	 * Get email templates
	 *
	 * @return array
	 */
	public static function get_email_templates( ) {
		global $wpdb;
		
		$email_templates = self::email_template_fields();
		
		if ( ! empty( $email_templates ) ) {
			foreach ( $email_templates as $key => $email_template ) {
				
				$nestedData['templatename'] = self::get_email_section_label($key);
				
				$params['section'] = $key;
				$managecolom_url = Appointy_Router_Helper::generate_link( ['email_templates', 'form'],$params );
				
				$managecolom = '<a href="'.esc_url( $managecolom_url ).'" class="site-button-outline button-sm">'.esc_html__( 'Manage','appointy' ).'</a>';
				
				$nestedData['manage'] = $managecolom;
				
				$data[] = $nestedData;
				
			}
		}
		
		$json_data = array( 'data' => $data );
		
		echo json_encode( $json_data );
		die();
	}
	
	/**
	 * Email template fields
	 *
	 * @return array
	 */
	public static function email_template_fields( ) {
		
		$fields = apply_filters( 'appointy_email_template_form_fields', array(
			'general' => array(
				'from_name' => array(
					'label'       => esc_html__( 'From Name', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-6',
					'placeholder' => esc_html__( 'Enter from name', 'appointy' ),
					'priority'    => 1
				),
				'from_email' => array(
					'label'       => esc_html__( 'From Email ID', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-6',
					'placeholder' => esc_html__( 'Enter from email', 'appointy' ),
					'priority'    => 2
				),
				'tagline' => array(
					'label'       => esc_html__( 'Tagline', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-6',
					'placeholder' => esc_html__( 'Enter tagline', 'appointy' ),
					'priority'    => 2
				),
				'header' => array(
					'label'       => esc_html__( 'Mail Header', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '',
					'priority'    => 3
				),
				'footer' => array(
					'label'       => esc_html__( 'Mail Footer', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '',
					'priority'    => 4
				)
			),
			'new_appointment' => array(
				'new_appointment_to_customer_subject' => array(
					'label'       => esc_html__( 'Subject (Customer)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 3
				),
				'new_appointment_to_customer' => array(
					'label'       => esc_html__( 'Body (Customer)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICES%, %APPOINTMENT_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %APPOINTMENT_AMOUNT%, %PAYMENT_METHOD%, %PAYMENT_STATUS%, %SITETITLE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 4
				),
				'new_appointment_to_admin_subject' => array(
					'label'       => esc_html__( 'Subject (Admin)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 5
				),
				'new_appointment_to_admin' => array(
					'label'       => esc_html__( 'Body (Admin)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICES%, %APPOINTMENT_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %APPOINTMENT_AMOUNT%, %PAYMENT_METHOD%, %PAYMENT_STATUS%, %SITETITLE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 6
				),
				'new_appointment_to_member_subject' => array(
					'label'       => esc_html__( 'Subject (Staff Member)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 5
				),
				'new_appointment_to_member' => array(
					'label'       => esc_html__( 'Body (Staff Member)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICES%, %APPOINTMENT_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %APPOINTMENT_AMOUNT%, %PAYMENT_METHOD%, %PAYMENT_STATUS%, %SITETITLE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 6
				)
			),
			'reminder_repeatpayment' => array(
				'reminder_repeatpayment_to_customer_subject' => array(
					'label'       => esc_html__( 'Subject (Customer)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 1
				),
				'reminder_repeatpayment_to_customer' => array(
					'label'       => esc_html__( 'Body (Customer)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %TAX_AMOUNT%, %TOTAL_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%, %PAYMENTLINK%',
					'priority'    => 2
				),
			),
			'received_repeatpayment' => array(
				'received_repeatpayment_to_customer_subject' => array(
					'label'       => esc_html__( 'Subject (Customer)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 1
				),
				'received_repeatpayment_to_customer' => array(
					'label'       => esc_html__( 'Body (Customer)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %TAX_AMOUNT%, %TOTAL_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 2
				),
				'received_repeatpayment_to_admin_subject' => array(
					'label'       => esc_html__( 'Subject (Admin)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 3
				),
				'received_repeatpayment_to_admin' => array(
					'label'       => esc_html__( 'Body (Admin)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %TAX_AMOUNT%, %TOTAL_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 4
				)
			),
			'received_fullpayment' => array(
				'received_fullpayment_to_customer_subject' => array(
					'label'       => esc_html__( 'Subject (Customer)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 1
				),
				'received_fullpayment_to_customer' => array(
					'label'       => esc_html__( 'Body (Customer)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %ADDRESS%, %DUEAMOUNT%, %DEPOSITAMOUNT%, %TOTALAMOUNT%',
					'priority'    => 2
				),
				'received_fullpayment_to_admin_subject' => array(
					'label'       => esc_html__( 'Subject (Admin)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 3
				),
				'received_fullpayment_to_admin' => array(
					'label'       => esc_html__( 'Body (Admin)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %ADDRESS%, %DUEAMOUNT%, %DEPOSITAMOUNT%, %TOTALAMOUNT%',
					'priority'    => 4
				)
			),
			'service_reschedule' => array(
				'service_reschedule_to_customer_subject' => array(
					'label'       => esc_html__( 'Subject (Customer)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 3
				),
				'service_reschedule_to_customer' => array(
					'label'       => esc_html__( 'Body (Customer)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 4
				),
				'service_reschedule_to_admin_subject' => array(
					'label'       => esc_html__( 'Subject (Admin)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 5
				),
				'service_reschedule_to_admin' => array(
					'label'       => esc_html__( 'Body (Admin)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 6
				),
				'service_reschedule_to_member_subject' => array(
					'label'       => esc_html__( 'Subject (Staff Member)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 7
				),
				'service_reschedule_to_member' => array(
					'label'       => esc_html__( 'Body (Staff Member)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 8
				)
			),
			'service_complete' => array(
				'service_complete_to_customer_subject' => array(
					'label'       => esc_html__( 'Subject (Customer)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 3
				),
				'service_complete_to_customer' => array(
					'label'       => esc_html__( 'Body (Customer)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 4
				),
				'service_complete_to_admin_subject' => array(
					'label'       => esc_html__( 'Subject (Admin)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 5
				),
				'service_complete_to_admin' => array(
					'label'       => esc_html__( 'Body (Admin)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 6
				),
				'service_complete_to_member_subject' => array(
					'label'       => esc_html__( 'Subject (Staff Member)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 7
				),
				'service_complete_to_member' => array(
					'label'       => esc_html__( 'Body (Staff Member)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 8
				)
			),
			'service_cancel' => array(
				'service_cancel_to_customer_subject' => array(
					'label'       => esc_html__( 'Subject (Customer)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 3
				),
				'service_cancel_to_customer' => array(
					'label'       => esc_html__( 'Body (Customer)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 4
				),
				'service_cancel_to_admin_subject' => array(
					'label'       => esc_html__( 'Subject (Admin)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 5
				),
				'service_cancel_to_admin' => array(
					'label'       => esc_html__( 'Body (Admin)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 6
				),
				'service_cancel_to_member_subject' => array(
					'label'       => esc_html__( 'Subject (Staff Member)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 7
				),
				'service_cancel_to_member' => array(
					'label'       => esc_html__( 'Body (Staff Member)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 8
				)
			),
			'add_feedback' => array(
				'add_feedback_to_customer_subject' => array(
					'label'       => esc_html__( 'Subject (Customer)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 3
				),
				'add_feedback_to_customer' => array(
					'label'       => esc_html__( 'Body (Customer)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%, %REVIEW_TITLE%, %DESCRIPTION%, %RATING%, %FROM_NAME%, %FROM_EMAIL%',
					'priority'    => 4
				),
				'add_feedback_to_admin_subject' => array(
					'label'       => esc_html__( 'Subject (Admin)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 5
				),
				'add_feedback_to_admin' => array(
					'label'       => esc_html__( 'Body (Admin)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%, %REVIEW_TITLE%, %DESCRIPTION%, %RATING%, %FROM_NAME%, %FROM_EMAIL%',
					'priority'    => 6
				),
				'add_feedback_to_member_subject' => array(
					'label'       => esc_html__( 'Subject (Staff Member)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 7
				),
				'add_feedback_to_member' => array(
					'label'       => esc_html__( 'Body (Staff Member)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%, %REVIEW_TITLE%, %DESCRIPTION%, %RATING%, %FROM_NAME%, %FROM_EMAIL%',
					'priority'    => 8
				)
			),
			'update_feedback' => array(
				'update_feedback_to_customer_subject' => array(
					'label'       => esc_html__( 'Subject (Customer)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 3
				),
				'update_feedback_to_customer' => array(
					'label'       => esc_html__( 'Body (Customer)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%, %REVIEW_TITLE%, %DESCRIPTION%, %RATING%, %FROM_NAME%, %FROM_EMAIL%',
					'priority'    => 4
				),
				'update_feedback_to_admin_subject' => array(
					'label'       => esc_html__( 'Subject (Admin)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 5
				),
				'update_feedback_to_admin' => array(
					'label'       => esc_html__( 'Body (Admin)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%, %REVIEW_TITLE%, %DESCRIPTION%, %RATING%, %FROM_NAME%, %FROM_EMAIL%',
					'priority'    => 6
				),
				'update_feedback_to_member_subject' => array(
					'label'       => esc_html__( 'Subject (Staff Member)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 7
				),
				'update_feedback_to_member' => array(
					'label'       => esc_html__( 'Body (Staff Member)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%, %REVIEW_TITLE%, %DESCRIPTION%, %RATING%, %FROM_NAME%, %FROM_EMAIL%',
					'priority'    => 8
				)
			),
			'new_user' => array(
				'new_user_to_customer_subject' => array(
					'label'       => esc_html__( 'Subject (Customer)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 3
				),
				'new_user_to_customer' => array(
					'label'       => esc_html__( 'Body (Customer)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %PASSWORD%',
					'priority'    => 4
				)
			),
			'update_service_staff' => array(
				'update_service_staff_to_customer_subject' => array(
					'label'       => esc_html__( 'Subject (Customer)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 1
				),
				'update_service_staff_to_customer' => array(
					'label'       => esc_html__( 'Body (Customer)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 2
				),
				'update_service_staff_to_admin_subject' => array(
					'label'       => esc_html__( 'Subject (Admin)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 3
				),
				'update_service_staff_to_admin' => array(
					'label'       => esc_html__( 'Body (Admin)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 4
				),
				'update_service_staff_to_member_subject' => array(
					'label'       => esc_html__( 'Subject (Staff Member)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 5
				),
				'update_service_staff_to_member' => array(
					'label'       => esc_html__( 'Body (Staff Member)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 6
				)
			),
			'remove_service_staff' => array(
				'remove_service_staff_to_member_subject' => array(
					'label'       => esc_html__( 'Subject (Admin)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 1
				),
				'remove_service_staff_to_member' => array(
					'label'       => esc_html__( 'Body (Admin)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 2
				)
			),
			'giftcard_generate' => array(
				'giftcard_generate_to_buyer_subject' => array(
					'label'       => esc_html__( 'Subject (Customer)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 1
				),
				'giftcard_generate_to_buyer' => array(
					'label'       => esc_html__( 'Body (Customer)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %TITLE%, %FROM_NAME%, %FROM_EMAIL%, %RECIPIENT_NAME%, %RECIPIENT_EMAIL%, %VOUCHER_AMOUNT%, %MESSAGE%',
					'priority'    => 2
				),
				'giftcard_generate_to_admin_subject' => array(
					'label'       => esc_html__( 'Subject (Admin)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 3
				),
				'giftcard_generate_to_admin' => array(
					'label'       => esc_html__( 'Body (Admin)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %TITLE%, %FROM_NAME%, %FROM_EMAIL%, %RECIPIENT_NAME%, %RECIPIENT_EMAIL%, %VOUCHER_AMOUNT%, %MESSAGE%, %EXPIRY_DATE%',
					'priority'    => 4
				),
				'giftcard_generate_to_recipient_subject' => array(
					'label'       => esc_html__( 'Subject (Admin)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 5
				),
				'giftcard_generate_to_recipient' => array(
					'label'       => esc_html__( 'Body (Admin)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %TITLE%, %FROM_NAME%, %FROM_EMAIL%, %RECIPIENT_NAME%, %RECIPIENT_EMAIL%, %VOUCHER_AMOUNT%, %MESSAGE%, %EXPIRY_DATE%',
					'priority'    => 6
				)
			),
			'invoice_generate' => array(
				'invoice_generate_to_customer_subject' => array(
					'label'       => esc_html__( 'Subject (Customer)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 3
				),
				'invoice_generate_to_customer' => array(
					'label'       => esc_html__( 'Body (Customer)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %INVOICEID%, %DUEDATE%, %STATUS%, %INVOICE_ITEMS%, %TAX_INFO%, %TAX_AMOUNT%, %DISCOUNT_INFO%, %DISCOUNT_AMOUNT%, %SUBTOTAL%, %GRAND_TOTAL%, %PAYNOW_LINK%',
					'priority'    => 4
				),
				'invoice_generate_to_admin_subject' => array(
					'label'       => esc_html__( 'Subject (Admin)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 5
				),
				'invoice_generate_to_admin' => array(
					'label'       => esc_html__( 'Body (Admin)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %INVOICEID%, %DUEDATE%, %STATUS%, %INVOICE_ITEMS%, %TAX_INFO%, %TAX_AMOUNT%, %DISCOUNT_INFO%, %DISCOUNT_AMOUNT%, %SUBTOTAL%, %GRAND_TOTAL%, %PAYNOW_LINK%',
					'priority'    => 6
				)
			),
			'invoice_paid' => array(
				'invoice_paid_to_customer_subject' => array(
					'label'       => esc_html__( 'Subject (Customer)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 3
				),
				'invoice_paid_to_customer' => array(
					'label'       => esc_html__( 'Body (Customer)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %INVOICEID%, %DUEDATE%, %STATUS%, %INVOICE_ITEMS%, %TAX_INFO%, %TAX_AMOUNT%, %DISCOUNT_INFO%, %DISCOUNT_AMOUNT%, %SUBTOTAL%, %GRAND_TOTAL%',
					'priority'    => 4
				),
				'invoice_paid_to_admin_subject' => array(
					'label'       => esc_html__( 'Subject (Admin)', 'appointy' ),
					'type'        => 'text',
					'icon'        => 'fa fa-user-o',
					'colum-width' => 'col-lg-12',
					'placeholder' => esc_html__( 'Enter mail subject', 'appointy' ),
					'priority'    => 5
				),
				'invoice_paid_to_admin' => array(
					'label'       => esc_html__( 'Body (Admin)', 'appointy' ),
					'type'        => 'wp-editor',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %INVOICEID%, %DUEDATE%, %STATUS%, %INVOICE_ITEMS%, %TAX_INFO%, %TAX_AMOUNT%, %DISCOUNT_INFO%, %DISCOUNT_AMOUNT%, %SUBTOTAL%, %GRAND_TOTAL%',
					'priority'    => 6
				)
			)
		) );
		
		return Appointy_Form_Helper::get_fields( $fields );	
	}
	
	/**
	 * Email template fields label
	 *
	 * @return array
	 */
	public static function email_template_fields_label( ) {
		
		$fields = apply_filters( 'appointy_email_template_form_fields_label', array(
			'general' => esc_html__( 'General settings', 'appointy' ),
			'new_appointment' => esc_html__( 'New appointment', 'appointy' ),
			'service_reschedule' => esc_html__( 'Appointment reschedule', 'appointy' ),
			'reminder_repeatpayment' => esc_html__( 'Repeat payment reminder', 'appointy' ),
			'received_repeatpayment' => esc_html__( 'Received repeat payment', 'appointy' ),
			'received_fullpayment' => esc_html__( 'Received full payment', 'appointy' ),
			'service_complete' => esc_html__( 'Appointment completed', 'appointy' ),
			'service_cancel' => esc_html__( 'Appointment cancelled', 'appointy' ),
			'add_feedback' => esc_html__( 'Add Feedback', 'appointy' ),
			'update_feedback' => esc_html__( 'Update Feedback', 'appointy' ),
			'update_service_staff' => esc_html__( 'Update service staff', 'appointy' ),
			'remove_service_staff' => esc_html__( 'Remove service staff', 'appointy' ),
			'giftcard_generate' => esc_html__( 'Generate giftcard', 'appointy' ),
			'invoice_generate' => esc_html__( 'Invoice generate', 'appointy' ),
			'invoice_paid' => esc_html__( 'Invoice paid', 'appointy' ),
			'new_user' => esc_html__( 'New User', 'appointy' ),
		) );
		
		return Appointy_Form_Helper::get_fields( $fields );	
	}
	
	/**
	 * Get email section label
	 *
	 * @return array
	 */
	public static function get_email_section_label($key = '') {
		
		$template_label = self::email_template_fields_label();
		return Appointy_Router_Helper::get_sanitize_data( $template_label, $key );
	}
	
	/**
	 * Email template default fields
	 *
	 * @return array
	 */
	public static function email_template_default_fields( ) {
		$default_templates = [];
		
		$default_templates['from_name'] = '';
		$default_templates['from_email'] = '';
		$default_templates['tagline'] = __( 'If your experience matches what we are looking for, someone from our Human Resources team will be reaching out to you shortly with further instructions regarding the application process.', 'appointy' );
		$default_templates['header'] = '<h1 style="font-size:20px; font-weight:600; margin:0px 20px 30px;"></h1>';
		$default_templates['footer'] = '<span style="color:#f11749; font-size:18px; font-weight:500; padding:0px; display:block;">'.__( 'Give us a call anytime', 'appointy' ).'</span>
        								<span style="color:#0b2832; font-size:30px; font-weight:900; padding:0px; display:block;">X-XXX-XXX-XXXX</span>';
		$default_templates['new_appointment_to_customer_subject'] = __( 'Appointment made successfully', 'appointy' );
		$default_templates['new_appointment_to_customer'] = __( 'Hey %CUSTOMER_NAME%!
											  You have done a new appointment at %SITETITLE%. Appointment details are following
											  <h4>Appointment Details</h4> <br/>
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  Services: %SERVICES% <br/>
											  Status: %APPOINTMENT_STATUS% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  <h4>Payment Details</h4> <br/>
											  Amount: %APPOINTMENT_AMOUNT% <br/>
											  Payment method: %PAYMENT_METHOD% <br/>
											  Payment status: %PAYMENT_STATUS% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		$default_templates['new_appointment_to_admin_subject'] = __( 'Appointment made successfully', 'appointy' );
		$default_templates['new_appointment_to_admin'] = __( 'Hey Admin!
											  New appointment made at %SITETITLE%. Appointment details are following
											  <h4>Appointment Details</h4> <br/>
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  Services: %SERVICES% <br/>
											  Status: %APPOINTMENT_STATUS% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  <h4>Payment Details</h4> <br/>
											  Amount: %APPOINTMENT_AMOUNT% <br/>
											  Payment method: %PAYMENT_METHOD% <br/>
											  Payment status: %PAYMENT_STATUS% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		$default_templates['new_appointment_to_member_subject'] = __( 'Appointment made successfully', 'appointy' );
		$default_templates['new_appointment_to_member'] = __( 'Hey Member!
											  New appointment made at %SITETITLE%. Appointment details are following
											  <h4>Appointment Details</h4> <br/>
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  Services: %SERVICES% <br/>
											  Status: %APPOINTMENT_STATUS% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  <h4>Payment Details</h4> <br/>
											  Amount: %APPOINTMENT_AMOUNT% <br/>
											  Payment method: %PAYMENT_METHOD% <br/>
											  Payment status: %PAYMENT_STATUS% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );											  
		
		$default_templates['reminder_repeatpayment_to_customer_subject'] = __( 'Repeat payment reminder successfully', 'appointy' );
		$default_templates['reminder_repeatpayment_to_customer'] = __( 'Hey %CUSTOMER_NAME%!
											  Repeat payment reminder at %SITETITLE%.
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Service Amount: %SERVICE_AMOUNT% <br/>
											  Tax Amount: %TAX_AMOUNT% <br/>
											  Total Amount: %TOTAL_AMOUNT% <br/>
											  Payment Link: %PAYMENTLINK% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		
		
		$default_templates['received_repeatpayment_to_customer_subject'] = __( 'Received repeat payment successfully', 'appointy' );
		$default_templates['received_repeatpayment_to_customer'] = __( 'Hey %CUSTOMER_NAME%!
											  Received repeat payment at %SITETITLE%.
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Service Amount: %SERVICE_AMOUNT% <br/>
											  Tax Amount: %TAX_AMOUNT% <br/>
											  Total Amount: %TOTAL_AMOUNT% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		$default_templates['received_repeatpayment_to_admin_subject'] = __( 'Received repeat payment successfully', 'appointy' );
		$default_templates['received_repeatpayment_to_admin'] = __( 'Hey Admin!
											  Received repeat payment at %SITETITLE%.
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Service Amount: %SERVICE_AMOUNT% <br/>
											  Tax Amount: %TAX_AMOUNT% <br/>
											  Total Amount: %TOTAL_AMOUNT% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		
		$default_templates['received_fullpayment_to_customer_subject'] = __( 'Received full payment successfully', 'appointy' );
		$default_templates['received_fullpayment_to_customer'] = __( 'Hey %CUSTOMER_NAME%!
											  Received full payment at %SITETITLE%.
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Due Amount: %DUEAMOUNT% <br/>
											  Deposit Amount: %DEPOSITAMOUNT% <br/>
											  Total Amount: %TOTALAMOUNT% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		$default_templates['received_fullpayment_to_admin_subject'] = __( 'Received full payment successfully', 'appointy' );
		$default_templates['received_fullpayment_to_admin'] = __( 'Hey Admin!
											  Received full payment at %SITETITLE%.
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Due Amount: %DUEAMOUNT% <br/>
											  Deposit Amount: %DEPOSITAMOUNT% <br/>
											  Total Amount: %TOTALAMOUNT% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		
		$default_templates['service_reschedule_to_customer_subject'] = __( 'Service rescheduled successfully', 'appointy' );
		$default_templates['service_reschedule_to_customer'] = __( 'Hey %CUSTOMER_NAME%!
											  Service rescheduled at %SITETITLE%. Service details are following
											  <h4>Appointment Details</h4> <br/>
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  Service Name: %SERVICE_NAME% <br/>
											  Date: %SERVICE_DATE% <br/>
											  Time: %SERVICE_TIME% <br/>
											  Duration: %SERVICE_DURATION% <br/>
											  Member name: %MEMBER_NAME% <br/>
											  Branch address: %BRANCH_ADDRESS% <br/>
											  Service Amount: %SERVICE_AMOUNT% <br/>
											  Service Status: %SERVICE_STATUS% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		$default_templates['service_reschedule_to_admin_subject'] = __( 'Service rescheduled successfully', 'appointy' );
		$default_templates['service_reschedule_to_admin'] = __( 'Hey Admin!
											  Service rescheduled at %SITETITLE%. Service details are following
											  <h4>Appointment Details</h4> <br/>
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  Service Name: %SERVICE_NAME% <br/>
											  Date: %SERVICE_DATE% <br/>
											  Time: %SERVICE_TIME% <br/>
											  Duration: %SERVICE_DURATION% <br/>
											  Member name: %MEMBER_NAME% <br/>
											  Branch address: %BRANCH_ADDRESS% <br/>
											  Service Amount: %SERVICE_AMOUNT% <br/>
											  Service Status: %SERVICE_STATUS% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		$default_templates['service_reschedule_to_member_subject'] = __( 'Service rescheduled successfully', 'appointy' );
		$default_templates['service_reschedule_to_member'] = __( 'Hey Member!
											  Service rescheduled at %SITETITLE%. Service details are following
											  <h4>Appointment Details</h4> <br/>
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  Service Name: %SERVICE_NAME% <br/>
											  Date: %SERVICE_DATE% <br/>
											  Time: %SERVICE_TIME% <br/>
											  Duration: %SERVICE_DURATION% <br/>
											  Member name: %MEMBER_NAME% <br/>
											  Branch address: %BRANCH_ADDRESS% <br/>
											  Service Amount: %SERVICE_AMOUNT% <br/>
											  Service Status: %SERVICE_STATUS% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		$default_templates['service_complete_to_customer_subject'] = __( 'Service completed successfully', 'appointy' );
		$default_templates['service_complete_to_customer'] = __( 'Hey %CUSTOMER_NAME%!
											  Service completed at %SITETITLE%. Service details are following
											  <h4>Appointment Details</h4> <br/>
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  Service Name: %SERVICE_NAME% <br/>
											  Date: %SERVICE_DATE% <br/>
											  Time: %SERVICE_TIME% <br/>
											  Duration: %SERVICE_DURATION% <br/>
											  Member name: %MEMBER_NAME% <br/>
											  Branch address: %BRANCH_ADDRESS% <br/>
											  Service Amount: %SERVICE_AMOUNT% <br/>
											  Service Status: %SERVICE_STATUS% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		$default_templates['service_complete_to_admin_subject'] = __( 'Service completed successfully', 'appointy' );
		$default_templates['service_complete_to_admin'] = __( 'Hey Admin!
											  Service completed at %SITETITLE%. Service details are following
											  <h4>Appointment Details</h4> <br/>
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  Service Name: %SERVICE_NAME% <br/>
											  Date: %SERVICE_DATE% <br/>
											  Time: %SERVICE_TIME% <br/>
											  Duration: %SERVICE_DURATION% <br/>
											  Member name: %MEMBER_NAME% <br/>
											  Branch address: %BRANCH_ADDRESS% <br/>
											  Service Amount: %SERVICE_AMOUNT% <br/>
											  Service Status: %SERVICE_STATUS% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		$default_templates['service_complete_to_member_subject'] = __( 'Service completed successfully', 'appointy' );
		$default_templates['service_complete_to_member'] = __( 'Hey Member!
											  Service completed at %SITETITLE%. Service details are following
											  <h4>Appointment Details</h4> <br/>
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  Service Name: %SERVICE_NAME% <br/>
											  Date: %SERVICE_DATE% <br/>
											  Time: %SERVICE_TIME% <br/>
											  Duration: %SERVICE_DURATION% <br/>
											  Member name: %MEMBER_NAME% <br/>
											  Branch address: %BRANCH_ADDRESS% <br/>
											  Service Amount: %SERVICE_AMOUNT% <br/>
											  Service Status: %SERVICE_STATUS% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		$default_templates['service_cancel_to_customer_subject'] = __( 'Service cancelled successfully', 'appointy' );
		$default_templates['service_cancel_to_customer'] = __( 'Hey %CUSTOMER_NAME%!
											  Service cancelled at %SITETITLE%. Service details are following
											 <h4>Appointment Details</h4> <br/>
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  Service Name: %SERVICE_NAME% <br/>
											  Date: %SERVICE_DATE% <br/>
											  Time: %SERVICE_TIME% <br/>
											  Duration: %SERVICE_DURATION% <br/>
											  Member name: %MEMBER_NAME% <br/>
											  Branch address: %BRANCH_ADDRESS% <br/>
											  Service Amount: %SERVICE_AMOUNT% <br/>
											  Service Status: %SERVICE_STATUS% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		$default_templates['service_cancel_to_admin_subject'] = __( 'Service cancelled successfully', 'appointy' );
		$default_templates['service_cancel_to_admin'] = __( 'Hey Admin!
											  Service cancelled at %SITETITLE%. Service details are following
											  <h4>Appointment Details</h4> <br/>
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  Service Name: %SERVICE_NAME% <br/>
											  Date: %SERVICE_DATE% <br/>
											  Time: %SERVICE_TIME% <br/>
											  Duration: %SERVICE_DURATION% <br/>
											  Member name: %MEMBER_NAME% <br/>
											  Branch address: %BRANCH_ADDRESS% <br/>
											  Service Amount: %SERVICE_AMOUNT% <br/>
											  Service Status: %SERVICE_STATUS% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		$default_templates['service_cancel_to_member_subject'] = __( 'Service cancelled successfully', 'appointy' );
		$default_templates['service_cancel_to_member'] = __( 'Hey Member!
											  Service cancelled at %SITETITLE%. Service details are following
											  <h4>Appointment Details</h4> <br/>
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  Service Name: %SERVICE_NAME% <br/>
											  Date: %SERVICE_DATE% <br/>
											  Time: %SERVICE_TIME% <br/>
											  Duration: %SERVICE_DURATION% <br/>
											  Member name: %MEMBER_NAME% <br/>
											  Branch address: %BRANCH_ADDRESS% <br/>
											  Service Amount: %SERVICE_AMOUNT% <br/>
											  Service Status: %SERVICE_STATUS% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );											  
		
		
		
		$default_templates['add_feedback_to_customer_subject'] = __( 'Feedback added successfully', 'appointy' );
		$default_templates['add_feedback_to_customer'] = __( 'Hey %CUSTOMER_NAME%!
											  Feedback added at %SITETITLE%. Service details are following
											  <h4>Review Details</h4> <br/>
											  Review Title: %REVIEW_TITLE% <br/>
											  Description: %DESCRIPTION% <br/>
											  Rating: %RATING% <br/>
											  From Name: %FROM_NAME% <br/>
											  From Email: %FROM_EMAIL% <br/>
											  <h4>Appointment Details</h4> <br/>
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  Service Name: %SERVICE_NAME% <br/>
											  Date: %SERVICE_DATE% <br/>
											  Time: %SERVICE_TIME% <br/>
											  Duration: %SERVICE_DURATION% <br/>
											  Member name: %MEMBER_NAME% <br/>
											  Branch address: %BRANCH_ADDRESS% <br/>
											  Service Amount: %SERVICE_AMOUNT% <br/>
											  Service Status: %SERVICE_STATUS% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		$default_templates['add_feedback_to_admin_subject'] = __( 'Feedback added successfully', 'appointy' );
		$default_templates['add_feedback_to_admin'] = __( 'Hey Admin!
											  Feedback added at %SITETITLE%. Service details are following
											  <h4>Review Details</h4> <br/>
											  Review Title: %REVIEW_TITLE% <br/>
											  Description: %DESCRIPTION% <br/>
											  Rating: %RATING% <br/>
											  From Name: %FROM_NAME% <br/>
											  From Email: %FROM_EMAIL% <br/>
											  <h4>Appointment Details</h4> <br/>
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  Service Name: %SERVICE_NAME% <br/>
											  Date: %SERVICE_DATE% <br/>
											  Time: %SERVICE_TIME% <br/>
											  Duration: %SERVICE_DURATION% <br/>
											  Member name: %MEMBER_NAME% <br/>
											  Branch address: %BRANCH_ADDRESS% <br/>
											  Service Amount: %SERVICE_AMOUNT% <br/>
											  Service Status: %SERVICE_STATUS% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		$default_templates['add_feedback_to_member_subject'] = __( 'Feedback added successfully', 'appointy' );
		$default_templates['add_feedback_to_member'] = __( 'Hey Member!
											  Feedback added at %SITETITLE%. Service details are following
											  <h4>Review Details</h4> <br/>
											  Review Title: %REVIEW_TITLE% <br/>
											  Description: %DESCRIPTION% <br/>
											  Rating: %RATING% <br/>
											  From Name: %FROM_NAME% <br/>
											  From Email: %FROM_EMAIL% <br/>
											  <h4>Appointment Details</h4> <br/>
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  Service Name: %SERVICE_NAME% <br/>
											  Date: %SERVICE_DATE% <br/>
											  Time: %SERVICE_TIME% <br/>
											  Duration: %SERVICE_DURATION% <br/>
											  Member name: %MEMBER_NAME% <br/>
											  Branch address: %BRANCH_ADDRESS% <br/>
											  Service Amount: %SERVICE_AMOUNT% <br/>
											  Service Status: %SERVICE_STATUS% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		
		
		$default_templates['update_feedback_to_customer_subject'] = __( 'Feedback updated successfully', 'appointy' );
		$default_templates['update_feedback_to_customer'] = __( 'Hey %CUSTOMER_NAME%!
											  Feedback updated at %SITETITLE%. Service details are following
											  <h4>Review Details</h4> <br/>
											  Review Title: %REVIEW_TITLE% <br/>
											  Description: %DESCRIPTION% <br/>
											  Rating: %RATING% <br/>
											  From Name: %FROM_NAME% <br/>
											  From Email: %FROM_EMAIL% <br/>
											  <h4>Appointment Details</h4> <br/>
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  Service Name: %SERVICE_NAME% <br/>
											  Date: %SERVICE_DATE% <br/>
											  Time: %SERVICE_TIME% <br/>
											  Duration: %SERVICE_DURATION% <br/>
											  Member name: %MEMBER_NAME% <br/>
											  Branch address: %BRANCH_ADDRESS% <br/>
											  Service Amount: %SERVICE_AMOUNT% <br/>
											  Service Status: %SERVICE_STATUS% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		$default_templates['update_feedback_to_admin_subject'] = __( 'Feedback updated successfully', 'appointy' );
		$default_templates['update_feedback_to_admin'] = __( 'Hey Admin!
											  Feedback updated at %SITETITLE%. Service details are following
											  <h4>Review Details</h4> <br/>
											  Review Title: %REVIEW_TITLE% <br/>
											  Description: %DESCRIPTION% <br/>
											  Rating: %RATING% <br/>
											  From Name: %FROM_NAME% <br/>
											  From Email: %FROM_EMAIL% <br/>
											  <h4>Appointment Details</h4> <br/>
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  Service Name: %SERVICE_NAME% <br/>
											  Date: %SERVICE_DATE% <br/>
											  Time: %SERVICE_TIME% <br/>
											  Duration: %SERVICE_DURATION% <br/>
											  Member name: %MEMBER_NAME% <br/>
											  Branch address: %BRANCH_ADDRESS% <br/>
											  Service Amount: %SERVICE_AMOUNT% <br/>
											  Service Status: %SERVICE_STATUS% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		$default_templates['update_feedback_to_member_subject'] = __( 'Feedback updated successfully', 'appointy' );
		$default_templates['update_feedback_to_member'] = __( 'Hey Member!
											  Feedback updated at %SITETITLE%. Service details are following
											  <h4>Review Details</h4> <br/>
											  Review Title: %REVIEW_TITLE% <br/>
											  Description: %DESCRIPTION% <br/>
											  Rating: %RATING% <br/>
											  From Name: %FROM_NAME% <br/>
											  From Email: %FROM_EMAIL% <br/>
											  <h4>Appointment Details</h4> <br/>
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  Service Name: %SERVICE_NAME% <br/>
											  Date: %SERVICE_DATE% <br/>
											  Time: %SERVICE_TIME% <br/>
											  Duration: %SERVICE_DURATION% <br/>
											  Member name: %MEMBER_NAME% <br/>
											  Branch address: %BRANCH_ADDRESS% <br/>
											  Service Amount: %SERVICE_AMOUNT% <br/>
											  Service Status: %SERVICE_STATUS% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		
		$default_templates['update_service_staff_to_customer_subject'] = __( 'Update service staff successfully', 'appointy' );
		$default_templates['update_service_staff_to_customer'] = __( 'Hey %CUSTOMER_NAME%!
											  Service staff updated at %SITETITLE%. Service details are following
											  <h4>Appointment Details</h4> <br/>
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  Service Name: %SERVICE_NAME% <br/>
											  Date: %SERVICE_DATE% <br/>
											  Time: %SERVICE_TIME% <br/>
											  Duration: %SERVICE_DURATION% <br/>
											  Member name: %MEMBER_NAME% <br/>
											  Branch address: %BRANCH_ADDRESS% <br/>
											  Service Amount: %SERVICE_AMOUNT% <br/>
											  Service Status: %SERVICE_STATUS% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		$default_templates['update_service_staff_to_admin_subject'] = __( 'Update service staff successfully', 'appointy' );
		$default_templates['update_service_staff_to_admin'] = __( 'Hey Admin!
											  Service staff updated at %SITETITLE%. Service details are following
											  <h4>Appointment Details</h4> <br/>
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  Service Name: %SERVICE_NAME% <br/>
											  Date: %SERVICE_DATE% <br/>
											  Time: %SERVICE_TIME% <br/>
											  Duration: %SERVICE_DURATION% <br/>
											  Member name: %MEMBER_NAME% <br/>
											  Branch address: %BRANCH_ADDRESS% <br/>
											  Service Amount: %SERVICE_AMOUNT% <br/>
											  Service Status: %SERVICE_STATUS% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		$default_templates['update_service_staff_to_member_subject'] = __( 'Update service staff successfully', 'appointy' );
		$default_templates['update_service_staff_to_member'] = __( 'Hey Admin!
											  Service staff updated at %SITETITLE%. Service details are following
											  <h4>Appointment Details</h4> <br/>
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  Service Name: %SERVICE_NAME% <br/>
											  Date: %SERVICE_DATE% <br/>
											  Time: %SERVICE_TIME% <br/>
											  Duration: %SERVICE_DURATION% <br/>
											  Member name: %MEMBER_NAME% <br/>
											  Branch address: %BRANCH_ADDRESS% <br/>
											  Service Amount: %SERVICE_AMOUNT% <br/>
											  Service Status: %SERVICE_STATUS% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );		
		$default_templates['remove_service_staff_to_member_subject'] = __( 'Assign other service staff', 'appointy' );
		$default_templates['remove_service_staff_to_member'] = __( 'Hey Admin!
											  Assign other service staff to service at %SITETITLE%. Service details are following
											  <h4>Appointment Details</h4> <br/>
											  Appointment ID: %APPOINTMENT_ID% <br/>
											  Service Name: %SERVICE_NAME% <br/>
											  Date: %SERVICE_DATE% <br/>
											  Time: %SERVICE_TIME% <br/>
											  Duration: %SERVICE_DURATION% <br/>
											  Member name: %MEMBER_NAME% <br/>
											  Branch address: %BRANCH_ADDRESS% <br/>
											  Service Amount: %SERVICE_AMOUNT% <br/>
											  Service Status: %SERVICE_STATUS% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		$default_templates['giftcard_generate_to_buyer_subject'] = __( 'Giftcard gererated', 'appointy' );
		$default_templates['giftcard_generate_to_buyer'] = __( 'Hey %FROM_NAME%!
											  You have purchased gift card for %TO_NAME% from %SITETITLE%. Gift card emailed to recipient email successfully.
											  <h4>Giftcard Details</h4> <br/>
											  Title: %TITLE% <br/>
											  From Name: %FROM_NAME% <br/>
											  From Email: %FROM_EMAIL% <br/>
											  Recipient Name: %RECIPIENT_NAME% <br/>
											  Recipient Name: %RECIPIENT_EMAIL% <br/>
											  Voucher Amount: %VOUCHER_AMOUNT% <br/>
											  Message: %MESSAGE%<br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		$default_templates['giftcard_generate_to_admin_subject'] = __( 'Giftcard gererated', 'appointy' );
		$default_templates['giftcard_generate_to_admin'] = __( 'Hey Admin!
											  Giftcard generated on %SITETITLE%. Gift card emailed to recipient email successfully.
											  <h4>Giftcard Details</h4> <br/>
											  Title: %TITLE% <br/>
											  From Name: %FROM_NAME% <br/>
											  From Email: %FROM_EMAIL% <br/>
											  Recipient Name: %RECIPIENT_NAME% <br/>
											  Recipient Name: %RECIPIENT_EMAIL% <br/>
											  Voucher Amount: %VOUCHER_AMOUNT% <br/>
											  Message: %MESSAGE%<br/>
											  Expiry Date: %EXPIRY_DATE%<br/><br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		$default_templates['giftcard_generate_to_recipient_subject'] = __( 'Giftcard received', 'appointy' );
		$default_templates['giftcard_generate_to_recipient'] = __( 'Hey %RECIPIENT_NAME%!
											  You have received gift card from %FROM_NAME% from %SITETITLE%. Please find attachement for giftcard.
											  <h4>Giftcard Details</h4> <br/>
											  Title: %TITLE% <br/>
											  From Name: %FROM_NAME% <br/>
											  From Email: %FROM_EMAIL% <br/>
											  Recipient Name: %RECIPIENT_NAME% <br/>
											  Recipient Name: %RECIPIENT_EMAIL% <br/>
											  Voucher Amount: %VOUCHER_AMOUNT% <br/>
											  Message: %MESSAGE%<br/>
											  Expiry Date: %EXPIRY_DATE%<br/><br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );											  											  
		$default_templates['invoice_generate_to_customer_subject'] = __( 'Invoice gererated', 'appointy' );
		$default_templates['invoice_generate_to_customer'] = __( 'Hey %CUSTOMER_NAME%!
											  You have received a new invoice from '.get_bloginfo('name').'. Invoice details are following
											  Invoice ID: %INVOICEID% <br/>
											  Due Date: %DUEDATE% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  <h4>Invoice Items</h4> <br/>
											  %INVOICE_ITEMS% <br/>
											  <h4>Tax Info</h4> <br/>
											  %TAX_INFO% <br/>
											  Tax Amount: %TAX_AMOUNT%<br/>
											  <h4>Discount Info</h4> <br/>
											  %DISCOUNT_INFO% <br/>
											  Discount Amount: %DISCOUNT_AMOUNT%<br/><br/>
											  <strong>Sub Total: %SUBTOTAL%</strong><br/>
											  <strong>Grand Total: %GRAND_TOTAL%</strong><br/><br/>
											  %PAYNOW_LINK%<br/><br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		$default_templates['invoice_generate_to_admin_subject'] = __( 'Invoice gererated', 'appointy' );
		$default_templates['invoice_generate_to_admin'] = __( 'Hey Admin!
											  New invoice generated from %SITETITLE%. Invoice details are following
											 Invoice ID: %INVOICEID% <br/>
											  Due Date: %DUEDATE% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  <h4>Invoice Items</h4> <br/>
											  %INVOICE_ITEMS% <br/>
											  <h4>Tax Info</h4> <br/>
											  %TAX_INFO% <br/>
											  Tax Amount: %TAX_AMOUNT%<br/>
											  <h4>Discount Info</h4> <br/>
											  %DISCOUNT_INFO% <br/>
											  Discount Amount: %DISCOUNT_AMOUNT%<br/><br/>
											  <strong>Sub Total: %SUBTOTAL%</strong><br/>
											  <strong>Grand Total: %GRAND_TOTAL%</strong><br/><br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		$default_templates['invoice_paid_to_customer_subject'] = __( 'Invoice paid', 'appointy' );
		$default_templates['invoice_paid_to_customer'] = __( 'Hey %CUSTOMER_NAME%!
											  You have successfully paid invoice to %SITETITLE%. Invoice details are following
											  Invoice ID: %INVOICEID% <br/>
											  Due Date: %DUEDATE% <br/>
											  <h4>Doctor Details</h4> <br/>
											  Name: %DOCTOR_NAME% <br/>
											  Email: %DOCTOR_EMAIL% <br/>
											  Phone: %DOCTOR_PHONE% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  <h4>Invoice Items</h4> <br/>
											  %INVOICE_ITEMS% <br/>
											  <h4>Tax Info</h4> <br/>
											  %TAX_INFO% <br/>
											  Tax Amount: %TAX_AMOUNT%<br/>
											  <h4>Discount Info</h4> <br/>
											  %DISCOUNT_INFO% <br/>
											  Discount Amount: %DISCOUNT_AMOUNT%<br/><br/>
											  <strong>Sub Total: %SUBTOTAL%</strong><br/>
											  <strong>Grand Total: %GRAND_TOTAL%</strong><br/><br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		$default_templates['invoice_paid_to_admin_subject'] = __( 'Invoice paid', 'appointy' );
		$default_templates['invoice_paid_to_admin'] = __( 'Hey Admin!
											  Customer have successfully paid invoice to %SITETITLE%. Invoice details are following
											  Invoice ID: %INVOICEID% <br/>
											  Due Date: %DUEDATE% <br/>
											  <h4>Doctor Details</h4> <br/>
											  Name: %DOCTOR_NAME% <br/>
											  Email: %DOCTOR_EMAIL% <br/>
											  Phone: %DOCTOR_PHONE% <br/>
											  <h4>Customer Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  <h4>Invoice Items</h4> <br/>
											  %INVOICE_ITEMS% <br/>
											  <h4>Tax Info</h4> <br/>
											  %TAX_INFO% <br/>
											  Tax Amount: %TAX_AMOUNT%<br/>
											  <h4>Discount Info</h4> <br/>
											  %DISCOUNT_INFO% <br/>
											  Discount Amount: %DISCOUNT_AMOUNT%<br/><br/>
											  <strong>Sub Total: %SUBTOTAL%</strong><br/>
											  <strong>Grand Total: %GRAND_TOTAL%</strong><br/><br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
		
		$default_templates['new_user_to_customer_subject'] = __( 'New Customer Account created', 'appointy' );
		$default_templates['new_user_to_customer'] = __( 'Hey Customer!
											  Account created at %SITETITLE%. Account details are following
											  <h4>Account Details</h4> <br/>
											  Name: %CUSTOMER_NAME% <br/>
											  Email: %CUSTOMER_EMAIL% <br/>
											  Phone: %CUSTOMER_PHONE% <br/>
											  Password: %PASSWORD% <br/>
											  Sincerely,
											  Your friends at %SITETITLE%', 'appointy' );
											  
		$default_templates = apply_filters( 'appointy_default_email_templates', $default_templates );
		
		return $default_templates;	
	}
	
	/**
	 * Save email templates
	 *
	 * @return array
	 */
	public static function save_email_templates( ) {
		global $wpdb;
		
		$email_template_key = Appointy_Router_Helper::get_sanitize_data( $_POST, 'email_template_key' );
		
		$email_fields = Appointy_Emails_Helper::email_template_fields();
		$email_fields = ( !empty($email_fields[$email_template_key]) ) ? (array) $email_fields[$email_template_key] : array();
		
		$mail_templates = get_option( 'appointy_email_templates' );
		
		if( !empty( $email_fields ) ) {
			foreach( $email_fields as $key => $field ){
				$mail_templates[$email_template_key][$key] = wp_kses_post($_POST[$key]);
			}
		}
		
		update_option( 'appointy_email_templates', $mail_templates );
			
		$redirecturl = add_query_arg( array( 'page' => 'appointment','menu_item' => 'email_templates__index' ), admin_url( 'admin.php' ) );
		
		$response = array( 'msg' => esc_html__('Email template saved successfully.', 'appointy'), 'redirect' => $redirecturl );
		wp_send_json_success($response);
		die();
	}
}
new Appointy_Emails_Helper();