<?php

class Appointy_Gift_Cards_Helper {

	/**
     * Initialize the class
     *
     * @since     1.0.0
     */
    public function __construct() {
		add_action('wp_ajax_appointy_get_giftcards', array($this, 'get_giftcards'));
		add_action('wp_ajax_appointy_save_giftcard', array($this, 'save_giftcard'));
		add_action('wp_ajax_appointy_load_giftcard', array($this, 'load_giftcard'));
		add_action('wp_ajax_appointy_delete_giftcard', array($this, 'delete_giftcard'));
    }
	
	/**
	 * Get giftcards
	 *
	 * @return void
	 */
	public static function get_giftcards() {
	    global $wpdb;
		
		$args = array(
            'post_type' => 'appointy_giftcards',
            'post_status' => 'publish',
            'posts_per_page' => -1,
            'orderby' => 'ID',
            'order' => 'DESC',
        );
		
        $the_query = new \WP_Query($args);
		
		$data = array();
		if ( $the_query->have_posts() ) {
			$nestedData = array();
			while ( $the_query->have_posts() ) : $the_query->the_post();
				$giftcardid = get_the_id();
				
				$nestedData['delete'] = '<div class="checkbox sf-radio-checkbox">
											<input type="checkbox" id="giftcard-'.esc_attr($giftcardid).'" value="'.esc_attr($giftcardid).'" class="delete_row delete_giftcard">
											<label for="giftcard-'.esc_attr($giftcardid).'"></label>
										</div>';
				$nestedData['title'] =  get_the_title();
				
				$nestedData['code'] =  get_post_meta($giftcardid,'code',true);
				
				$amount = ( get_post_meta($giftcardid,'amount',true) != '' ) ? get_post_meta($giftcardid,'amount',true) : 0;
				
				$nestedData['balance'] =  Appointy_Misc_Helper::get_price_format($amount);
				
				$spent = ( get_post_meta($giftcardid,'spent',true) != '' ) ? get_post_meta($giftcardid,'spent',true) : 0;
				
				$nestedData['spent'] =  Appointy_Misc_Helper::get_price_format($spent);
				
				$leftover = floatval($amount) - floatval($spent);
				
				$nestedData['leftover'] =  Appointy_Misc_Helper::get_price_format($leftover);
				
				$actions = '<div class="dropdown action-dropdown dropdown-left">
							  <button class="action-button btn btn-primary dropdown-toggle" type="button" data-bs-toggle="dropdown"><i class="fa fa-ellipsis-v"></i></button>
							  <ul class="dropdown-menu">
								<li><a href="javascript:;" class="dropdown-item editgiftcard" data-giftcardid="'.esc_attr($giftcardid).'"><i class="fa fa-pencil"></i> '.esc_html__( 'Edit','appointy' ).'</a></li>
							  </ul>
							</div>';
				
				$nestedData['action'] = $actions;
				
				$data[] = $nestedData;	
			endwhile;
		}
		
		$json_data = array( 'data' => $data );
		
		echo json_encode( $json_data );
		die();
	}
	
	/**
     * Save giftcard
     *
     * @since    1.0.0
     */
    public function save_giftcard() {
		global $current_user;
        if( ! wp_verify_nonce( $_POST['_nonce'], 'appointy_ajax_nonce' ) || !current_user_can('manage_options') ) {
			wp_send_json_error();
			die();
		}
		
		$attachment_id = Appointy_Router_Helper::get_sanitize_data( $_POST, 'image_id' );
		$giftcardid = Appointy_Router_Helper::get_sanitize_data( $_POST, 'giftcardid' );
		
		$giftcard_fields = self::giftcard_fields( $giftcardid );
                        
		$meta_fields = array();
		
		if( !empty($giftcard_fields) ) {
			foreach( $giftcard_fields as $key => $field ) {
				$meta_fields[$key] 	= Appointy_Router_Helper::get_sanitize_data( $_POST, $key );
			}
		}
		
		$meta_fields['image_id'] 	= $attachment_id;
		
		if( !empty( $giftcardid ) ) {
			$giftcard_post = array(
				'ID'   	  	  =>  $giftcardid,
				'post_title' => Appointy_Router_Helper::get_sanitize_data($_POST,'title'),
				'post_status' => 'publish',
				'post_type' => 'appointy_giftcards',
				'post_author' => $current_user->ID,
				'meta_input'   => $meta_fields
			);
			$postid = wp_update_post( $giftcard_post ) ;		
		} else {
			$giftcard_post = array(
				'post_title' => Appointy_Router_Helper::get_sanitize_data($_POST,'title'),
				'post_status' => 'publish',
				'post_type' => 'appointy_giftcards',
				'post_author' => $current_user->ID,
				'meta_input'   => $meta_fields
			);
			$postid = wp_insert_post( $giftcard_post );
		}
		
		$pdfhtml = self::get_giftcard_html( $postid );
		
		$pdfname = 'giftcart-'.$postid.'.pdf';
		
		$upload_dir   = wp_upload_dir();
		
		if (!file_exists($upload_dir['basedir'].'/giftcard')) {
			mkdir($upload_dir['basedir'].'/giftcard', 0777, true);
		}
		
		$pdfpath = $upload_dir['basedir'].'/giftcard/'.$pdfname;
		
		Appointy_Pdf_Helper::generate_pdf($pdfhtml,$pdfpath);
		
		Appointy_Send_Email_Notification_Helper::send_giftcard_generate_email_notifications($postid,$pdfpath);
		
		$response = array( 'msg' => esc_html__('Giftcard saved.', 'appointy') );
        wp_send_json_success($response);
        die();
    }
	
	/**
	 * Get giftcart html
	 *
	 * @return array
	 */
	public static function get_giftcard_html( $giftcardid = 0 ) {
		ob_start();
		$giftcard_top_area = Appointy_Misc_Helper::get_settings( 'giftcard_settings', 'giftcard_top_area' );
		$giftcard_bottom_area = Appointy_Misc_Helper::get_settings( 'giftcard_settings', 'giftcard_bottom_area' );
		?>
		<div class="page-wraper">

			<div class="payment-wraper">
				<table style="width: 100%; padding: 30px 0px; max-width:700px; border:1px solid #ddd; text-align:center; margin-left: auto; margin-right: auto; background-color: #fff; font-family:Arial, Helvetica, sans-serif;">
					<tr>
						<td style="padding:0px 0px 10px;">
							<table style="width:100%;">
								<tr>
									<td>
										<h2 style="font-size:36px; color:#01adb3; text-transform:uppercase; margin:0px; "><?php echo get_the_title($giftcardid); ?></h2>
										
										
									</td>
								</tr>
							</table>
						</td>
					</tr>
					<tr>
						<td style="padding:0px 0px 20px;">
							<table style="width:100%;">
								<tr>
									<td style="font-size:20px; ">
										<a href="#" style="color:#222; text-decoration:none;"><?php echo home_url(); ?></a>
									</td>
								</tr>
							</table>
						</td>
					</tr>
					
					<?php if($giftcard_top_area !== '') { ?>
					<tr>
						<td style="padding:0px 0px 10px;">
							<table style="width:100%;">
								<tr>
									<td>
										<h6 style="font-size:20px; font-weight:normal; color:#01adb3; text-transform:uppercase; margin:0px;">
										<?php echo wp_kses_post($giftcard_top_area); ?>
										</h6>
									</td>
								</tr>
							</table>
						</td>
					</tr>
					<?php } ?>
					
					<tr>
						<td style="padding:20px 30px;">
							<table style="width:100%; border:2px dashed #01adb3; text-align:center; padding:20px; border-radius:10px;">
								<tr>
									<td style="padding:0px 30px 10px;" valign="top">
										<div style="min-width:100px; height:100px; font-weight:bold; font-size:24px; background:#01adb3; color:#fff; border-radius:100%; line-height:100px; display:table; margin: auto;"><?php echo Appointy_Misc_Helper::get_price_format(get_post_meta($giftcardid,'amount',true)); ?></div>
									</td>
								</tr>
								<tr>
									<td style="padding:0px 30px 0px;" valign="top">
										<div style="border:2px solid #dfd8b4; padding:10px 25px; font-size:14px; display:table; margin:auto; ">
											<?php echo get_post_meta($giftcardid,'description',true); ?>
										</div>
									</td>
								</tr>
								<tr>
									<td style="padding:0px 30px 0px;" valign="top">
										<div style="border:2px dotted #ddd; padding:10px 35px; font-size:28px; display:table; margin:auto; letter-spacing:2px; ">
											<?php echo get_post_meta($giftcardid,'code',true); ?>
											<div style="text-align:center;"><?php echo esc_html__( 'PIN','appointy' ); ?>: <?php echo get_post_meta($giftcardid,'pin',true); ?></div>
										</div>
									</td>
								</tr>
								
							</table>
						</td>
					</tr>
					<?php if($giftcard_bottom_area !== '') { ?>
					<tr>
						<td style="padding:0px;">
							<table style="width:100%; color:#999;">
								<tr>
									<td style="padding:0px 30px 20px;" valign="top">
										<?php echo wp_kses_post($giftcard_bottom_area); ?>
									</td>
								</tr>
							</table>
						</td>
					</tr>
					<?php } ?>
				</table>
			</div>
			
		</div>
		<?php
		
		return ob_get_clean();
	}
	
	/**
	 * Delete giftcard
	 *
	 * @return array
	 */
	public static function delete_giftcard() {
		global $wpdb;
		
		$data_ids = Appointy_Router_Helper::get_request_data( $_POST, 'data_ids' );
		
		$data_id_array = explode(",", $data_ids); 

		if(!empty($data_id_array)) {
			foreach($data_id_array as $giftcardid) {
				$force_delete = true;
				wp_delete_post( $giftcardid, $force_delete );
			}
		}
		
		wp_send_json_success();
		die();
	}
	
	/**
	 * Process load giftcard
	 *
	 * @return array
	 */
	public static function load_giftcard( ) {
		global $wpdb;
		
		$giftcardid = Appointy_Router_Helper::get_request_data( $_POST, 'giftcardid' );
		
		$giftcard_fields = self::giftcard_fields( $giftcardid );
                        
		$meta_fields = array();
		
		if( !empty($giftcard_fields) ) {
			foreach( $giftcard_fields as $key => $field ) {
				$meta_fields[$key] 	= get_post_meta($giftcardid, $key, true);
			}
		}
		
		$attachment_id = get_post_meta($giftcardid, 'image_id', true);
		
		if($attachment_id > 0) {
			$image_url = Appointy_Image_Helper::get_image_url_by_id($attachment_id);
			$image_tag = '<img src="'.esc_url($image_url).'"/>';
			$image_text = __( 'Remove','appointy' );
		} else {
			$attachment_id = 0;
			$image_tag = '';
			$image_text = __( 'Upload Image','appointy' );
		}	
			
		$meta_fields['image_text'] 	= $image_text;
		$meta_fields['image_tag'] 	= $image_tag;
		$meta_fields['attachment_id'] 	= $attachment_id;
		 
		$response = $meta_fields;
		
		wp_send_json_success($response);
		
   		die();
	}
	
	public static function giftcard_fields( $post_id = 0 ) {
	
		$fields = apply_filters( 'appointy_giftcard_form_fields', array(
			'title' => array(
				'label'       => esc_html__( 'Title', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-tag',
				'colum-width' => 'col-lg-12',
				'required'    => true,
				'placeholder' => '',
				'priority'    => 1
			),
			'from_name' => array(
				'label'       => esc_html__( 'From Name', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-tag',
				'colum-width' => 'col-lg-6',
				'required'    => true,
				'placeholder' => '',
				'priority'    => 1
			),
			'from_email' => array(
				'label'       => esc_html__( 'From Email', 'appointy' ),
				'type'        => 'email',
				'icon'        => 'fa fa-tag',
				'colum-width' => 'col-lg-6',
				'required'    => true,
				'placeholder' => '',
				'priority'    => 3
			),
			'to_name' => array(
				'label'       => esc_html__( 'Recipient Name', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-tag',
				'colum-width' => 'col-lg-6',
				'required'    => true,
				'placeholder' => '',
				'priority'    => 2
			),
			'to_email' => array(
				'label'       => esc_html__( 'Recipient Email', 'appointy' ),
				'type'        => 'email',
				'icon'        => 'fa fa-tag',
				'colum-width' => 'col-lg-6',
				'required'    => true,
				'placeholder' => '',
				'priority'    => 5
			),
			'amount' => array(
				'label'       => esc_html__( 'Voucher Value', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-tag',
				'colum-width' => 'col-lg-6',
				'required'    => true,
				'placeholder' => '',
				'priority'    => 3
			),
			'expirydate' => array(
				'label'       => esc_html__( 'Date of Expiry', 'appointy' ),
				'type'        => 'date',
				'default'     => '',
				'icon'        => 'fa fa-map-marker',
				'colum-width' => 'col-lg-6',
				'required'    => true,
				'priority'    => 4
			),
			'description' => array(
				'label'       => esc_html__( 'Personal Message', 'appointy' ),
				'type'        => 'textarea',
				'colum-width' => 'col-lg-12',
				'icon'        => 'fa fa-pencil',
				'required'    => false,
				'placeholder' => esc_html__( 'Personal Message', 'appointy' ),
				'priority'    => 5
			),
			'code' => array(
				'label'       => esc_html__( 'Code', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-tag',
				'colum-width' => 'col-lg-12',
				'required'    => true,
				'readonly'    => true,
				'value'    	  => self::get_random_code(),
				'placeholder' => '',
				'priority'    => 6
			),
			'pin' => array(
				'label'       => esc_html__( 'Pin', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-tag',
				'colum-width' => 'col-lg-12',
				'required'    => true,
				'readonly'    => true,
				'value'    	  => self::get_random_code(4),
				'placeholder' => '',
				'priority'    => 6
			)
		) );

		return Appointy_Form_Helper::get_fields( $fields );	
	}
	
	public static function giftcard_purchase_fields() {
	
		$fields = apply_filters( 'appointy_giftcard_form_fields', array(
			'title' => array(
				'label'       => esc_html__( 'Title', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-tag',
				'colum-width' => 'col-lg-12',
				'required'    => true,
				'placeholder' => '',
				'priority'    => 1
			),
			'from_name' => array(
				'label'       => esc_html__( 'From Name', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-tag',
				'colum-width' => 'col-lg-6',
				'required'    => true,
				'placeholder' => '',
				'priority'    => 2
			),
			'from_email' => array(
				'label'       => esc_html__( 'From Email', 'appointy' ),
				'type'        => 'email',
				'icon'        => 'fa fa-tag',
				'colum-width' => 'col-lg-6',
				'required'    => true,
				'placeholder' => '',
				'priority'    => 3
			),
			'to_name' => array(
				'label'       => esc_html__( 'Recipient Name', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-tag',
				'colum-width' => 'col-lg-6',
				'required'    => true,
				'placeholder' => '',
				'priority'    => 4
			),
			'to_email' => array(
				'label'       => esc_html__( 'Recipient Email', 'appointy' ),
				'type'        => 'email',
				'icon'        => 'fa fa-tag',
				'colum-width' => 'col-lg-6',
				'required'    => true,
				'placeholder' => '',
				'priority'    => 5
			),
			'amount' => array(
				'label'       => esc_html__( 'Voucher Amount', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-tag',
				'colum-width' => 'col-lg-6',
				'required'    => true,
				'placeholder' => '',
				'priority'    => 6
			),
			'description' => array(
				'label'       => esc_html__( 'Personal Message', 'appointy' ),
				'type'        => 'textarea',
				'colum-width' => 'col-lg-12',
				'icon'        => 'fa fa-pencil',
				'required'    => false,
				'placeholder' => esc_html__( 'Personal Message', 'appointy' ),
				'priority'    => 7
			)
		) );

		return Appointy_Form_Helper::get_fields( $fields );	
	}
	
	public static function get_random_code($limit = 16) {
		$code = '';
		
		for($i = 0; $i < $limit; $i++) { 
			$code .= mt_rand(0, 9); 
		}
		return $code;
	}
	
	public static function get_giftcard_pdf($giftcard_id = 0) {
		if( $giftcard_id > 0 ) {
			$upload_dir   = wp_upload_dir();
			$pdfname = 'giftcart-'.$giftcard_id.'.pdf';
	
			$pdfpath = $upload_dir['basedir'].'/giftcard/'.$pdfname;
			$pdfurl = $upload_dir['baseurl'].'/giftcard/'.$pdfname;
			
			$response = array(
				'path' => $pdfpath,
				'url' => $pdfurl
			);
			
			return $response;
		}
	}
	
	public static function send_giftcard($woopostdata = array(),$order_id = 0,$item_id = 0) {
		global $wpdb, $current_user;
		
		$order = new \WC_Order( $order_id );
				
		$payment_method = $order->get_payment_method();
		$order_status = $order->get_status();
		
		if ( $woopostdata && ! isset ( $woopostdata['processed'] ) ) {
			
			if($order_status === 'on-hold'){
				$status = 'draft';
			}elseif($order_status === 'completed' || $order_status === 'processing'){
				$status = 'publish';
			}
			
			$existinggiftcard = $wpdb->get_row($wpdb->prepare('SELECT `post_id` FROM '.$wpdb->prefix.'postmeta WHERE `meta_key` = "order_id" AND `meta_value` = %s',$order_id));
			if(!empty($existinggiftcard)) {
				
				$giftcard_id = Appointy_Router_Helper::get_request_data( $existinggiftcard, 'post_id' );
				
				$giftcard_post = array(
					'ID'           => $giftcard_id,
					'post_status'  => $status
				);
				wp_update_post( $giftcard_post );
				
				if($order_status === 'completed' || $order_status === 'processing') {
					$pdfpath = self::get_giftcard_pdf($giftcard_id);
					$pdfpath = Appointy_Router_Helper::get_request_data( $pdfpath, 'path' );
					Appointy_Send_Email_Notification_Helper::send_giftcard_generate_email_notifications($giftcard_id,$pdfpath);
				}
				
				return;
			}
			
			$giftcard_fields = self::giftcard_fields();
                        
			$meta_fields = array();
			
			if( !empty($giftcard_fields) ) {
				foreach( $giftcard_fields as $key => $field ) {
					$meta_fields[$key] 	= Appointy_Router_Helper::get_request_data( $woopostdata, $key );
				}
			}
			
			$meta_fields['code'] 	= self::get_random_code(16);
			$meta_fields['pin'] 	= self::get_random_code(4);
			
			$meta_fields['order_id'] = $order_id;
			$meta_fields['payment_type'] = 'woocommerce';
			
			$giftcard_post = array(
				'post_title' => Appointy_Router_Helper::get_request_data($woopostdata,'title'),
				'post_status' => 'draft',
				'post_type' => 'appointy_giftcards',
				'meta_input'   => $meta_fields
			);
			
			$postid = wp_insert_post( $giftcard_post );
			
			$pdfhtml = self::get_giftcard_html( $postid );
			
			$pdfname = 'giftcart-'.$postid.'.pdf';
			
			$upload_dir   = wp_upload_dir();
			
			if (!file_exists($upload_dir['basedir'].'/giftcard')) {
				mkdir($upload_dir['basedir'].'/giftcard', 0777, true);
			}
			
			$pdfpath = $upload_dir['basedir'].'/giftcard/'.$pdfname;
			
			Appointy_Pdf_Helper::generate_pdf($pdfhtml,$pdfpath);
			
		} else {
				$existinggiftcard = $wpdb->get_row($wpdb->prepare('SELECT `post_id` FROM '.$wpdb->prefix.'postmeta WHERE `meta_key` = "order_id" AND `meta_value` = %s',$order_id));		
				
				if(!empty($existinggiftcard) && ($order_status === 'completed' || $order_status === 'processing') && $woopostdata && ! isset ( $woopostdata['completed'] ) && ! isset ( $woopostdata['cancelled'] ))
				{
				
					$giftcard_id = Appointy_Router_Helper::get_request_data( $existinggiftcard, 'post_id' );
					
					$giftcard_post = array(
						'ID'           => $giftcard_id,
						'post_status'  => 'publish'
					);
					wp_update_post( $giftcard_post );
					
					$pdfpath = self::get_giftcard_pdf($giftcard_id);
					$pdfpath = Appointy_Router_Helper::get_request_data( $pdfpath, 'path' );
					Appointy_Send_Email_Notification_Helper::send_giftcard_generate_email_notifications($giftcard_id,$pdfpath);
				}	
		}
	
    }
	
}
new Appointy_Gift_Cards_Helper();