<?php 
class Appointy_Location_Helper {

	/**
     * Initialize the class
     *
     * @since     1.0.0
     */
    public function __construct() {
		add_action('wp_ajax_load_states', array($this, 'load_states'));
		add_action('wp_ajax_load_cities', array($this, 'load_cities'));
		add_action('wp_ajax_get_location', array($this, 'get_location'));
		add_action('wp_ajax_save_location', array($this, 'save_location'));
		add_action('wp_ajax_load_location', array($this, 'load_location'));
		add_action('wp_ajax_appointy_delete_location', array($this, 'delete_location'));
		add_action('wp_ajax_appointy_load_states_terms_ids', [ $this, 'load_states_terms_ids' ] );
		
    }
	
	/**
	 * Process load state terms
	 *
	 * @return array
	 */
	public static function load_states_terms_ids( ) {
		global $wpdb;
		extract($_POST);
		
		$default_country_id = Appointy_Router_Helper::get_request_data( $_POST, 'country' );
		
		$has_state = false;
		
		$texonomy = 'appointy_state';
		$args = array(
				'orderby'           => 'name',
				'order'             => 'ASC',
				'hide_empty'        => false
			); 
		$states = get_terms( $texonomy,$args );
		
		$option = '';
		if(!empty($states) && !empty($country))
		{
			$option .= '<option value="">'.sprintf( esc_html__( 'Choose %s', 'appointy' ), self::get_state_replacement( 'singular' ) ).'</option>';
			foreach($states as $term)
			{
				$country_id = get_term_meta($term->term_id, 'country', true);
				if($country_id === $default_country_id) {
					$has_state = true;
					$option .= '<option value="'.$term->term_id.'">'.$term->name.'</option>';		
				}
			}
		}
		
		if( $has_state === true ) {
			wp_send_json_success($option);
		} else {
			$option = '<option value="">'.esc_html__( 'Not available', 'appointy' ).'</option>';
			wp_send_json_success($option);
		}
		die();
	}
	
	/**
	 * Delete location
	 *
	 * @return array
	 */
	public static function delete_location() {
		global $wpdb;
		
		$data_ids = Appointy_Router_Helper::get_request_data( $_POST, 'data_ids' );
		
		$data_id_array = explode(",", $data_ids); 

		if(!empty($data_id_array)) {
			foreach($data_id_array as $locationid) {
				$force_delete = true;
				wp_delete_post( $locationid, $force_delete );
			}
		}
		
		wp_send_json_success();
		die();
	}
	
	/**
	 * Process load location
	 *
	 * @return array
	 */
	public static function load_location( ) {
		global $wpdb;
		
		$locationid = Appointy_Router_Helper::get_request_data( $_POST, 'locationid' );
		
		$attachment_id = get_post_meta($locationid, 'image_id', true);
		if($attachment_id > 0) {
			$image_url = Appointy_Image_Helper::get_image_url_by_id($attachment_id);
			$image_tag = '<img src="'.esc_url($image_url).'"/>';
			$image_text = esc_html__( 'Remove','appointy' );
		} else {
			$attachment_id = 0;
			$image_tag = '';
			$image_text = esc_html__( 'Upload Image','appointy' );
		}
		
		$country = get_post_meta($locationid, 'country', true);
		$state = get_post_meta($locationid, 'state', true);
		$city = get_post_meta($locationid, 'city', true);
		$states = self::get_states( $country );
		
		ob_start();
		if( !empty($states) ){
			foreach ( $states as $key => $value ){
				if($state === $key) {
					$slect = 'selected="selected"';
				}else{
					$slect = '';
				}
				echo '<option value="'.esc_attr( $key ).'" '.esc_attr($slect).'>'.esc_html( $value ).'</option>';			
			}
		}
		$states = ob_get_clean();
		
		$cities = self::get_cities( $country,$state );
		
		ob_start();
		if( !empty($cities) ){
			foreach ( $cities as $key => $value ){
				if($city === $key) {
					$slect = 'selected="selected"';
				}else{
					$slect = '';
				}
				echo '<option value="'.esc_attr( $key ).'" '.esc_attr($slect).'>'.esc_html( $value ).'</option>';			
			}
		}
		$cities = ob_get_clean();
		
		$response = array( 
			'title' => get_the_title($locationid),
			'phone' => get_post_meta($locationid, 'phone', true),
			'description' => get_the_content('','',$locationid),
			'members' => get_post_meta($locationid, 'members', true),
			'country' => get_post_meta($locationid, 'country', true),
			'state' => get_post_meta($locationid, 'state', true),
			'states' => $states,
			'city' => get_post_meta($locationid, 'city', true),
			'cities' => $cities,
			'zipcode' => get_post_meta($locationid, 'zipcode', true),
			'latitude' => get_post_meta($locationid, 'latitude', true),
			'longitude' => get_post_meta($locationid, 'longitude', true),
			'friendly_address' => get_post_meta($locationid, 'friendly_address', true),
			'map_location' => get_post_meta($locationid, 'map_location', true),
			'image_text' => $image_text,
			'image_tag' => $image_tag,
			'attachment_id' => $attachment_id
		);
		wp_send_json_success($response);
		
   		die();
	}
	
	/**
     * Save locaion
     *
     * @since    1.0.0
     */
    public function save_location() {
		global $current_user;
        if( ! wp_verify_nonce( $_POST['_nonce'], 'appointy_ajax_nonce' ) || !current_user_can('manage_options') ) {
			wp_send_json_error();
			die();
		}
		
		$attachment_id = Appointy_Router_Helper::get_sanitize_data( $_POST, 'image_id' );
		$locationid = Appointy_Router_Helper::get_sanitize_data( $_POST, 'locationid' );
		
		$meta_fields['image_id'] 	= $attachment_id;
		$meta_fields['phone'] 	= Appointy_Router_Helper::get_sanitize_data( $_POST, 'phone' );
		$meta_fields['country'] 	= Appointy_Router_Helper::get_sanitize_data( $_POST, 'country' );
		$meta_fields['state'] 	= Appointy_Router_Helper::get_sanitize_data( $_POST, 'state' );
		$meta_fields['city'] 		= Appointy_Router_Helper::get_sanitize_data( $_POST, 'city' );
		$meta_fields['zipcode'] 		= Appointy_Router_Helper::get_sanitize_data( $_POST, 'zipcode' );
		$meta_fields['friendly_address'] 	= Appointy_Router_Helper::get_sanitize_data( $_POST, 'friendly_address' );
		$meta_fields['map_location'] 	= Appointy_Router_Helper::get_sanitize_data( $_POST, 'map_location' );
		$meta_fields['latitude'] 	= Appointy_Router_Helper::get_sanitize_data( $_POST, 'latitude' );
		$meta_fields['longitude'] 	= Appointy_Router_Helper::get_sanitize_data( $_POST, 'longitude' );
		$meta_fields['members'] 	= (!empty($_POST['members'])) ? implode(',',$_POST['members']) : '';
		
		if( !empty( $locationid ) ) {
			$location_post = array(
				'ID'   	  	  =>  $locationid,
				'post_title' => Appointy_Router_Helper::get_sanitize_data($_POST,'title'),
				'post_status' => 'publish',
				'post_type' => 'appointy_locations',
				'post_author' => $current_user->ID,
				'post_content' => Appointy_Router_Helper::get_sanitize_data($_POST,'description'),
				'meta_input'   => $meta_fields
			);
			$postid = wp_update_post( $location_post ) ;		
		} else {
			$location_post = array(
				'post_title' => Appointy_Router_Helper::get_sanitize_data($_POST,'title'),
				'post_status' => 'publish',
				'post_type' => 'appointy_locations',
				'post_author' => $current_user->ID,
				'post_content' => Appointy_Router_Helper::get_sanitize_data($_POST,'description'),
				'meta_input'   => $meta_fields
			);
			$postid = wp_insert_post( $location_post );
		}
		
		set_post_thumbnail( $postid, $attachment_id );
		
		$response = array( 'msg' => esc_html__('Location saved.', 'appointy') );
        wp_send_json_success($response);
        die();
    }
	
	/**
	 * Process load states
	 *
	 * @return array
	 */
	public static function load_states( ) {
		global $wpdb;
		extract($_POST);
		
		$country = Appointy_Router_Helper::get_request_data( $_POST, 'country' );
		
		$states = self::get_states( $country );
		
		$option = '';
		if(!empty($states) && !empty($country))
		{
			foreach($states as $key => $state)
			{
				$option .= '<option value="'.$key.'">'.$state.'</option>';		
			}
		}else	
		{
			$option .= '<option value="">'.esc_html__( 'Not available', 'appointy' ).'</option>';
		}
		
		wp_send_json_success($option);
		
   		die();
	}
	
	/**
	 * Process load cities
	 *
	 * @return array
	 */
	public static function load_cities( ) {
		global $wpdb;
		extract($_POST);
		
		$country = Appointy_Router_Helper::get_request_data( $_POST, 'country' );
		$state = Appointy_Router_Helper::get_request_data( $_POST, 'state' );
		
		$cities = self::get_cities( $country, $state );
		
		$option = '';
		if(!empty($cities) && !empty($state) && !empty($country))
		{
			foreach($cities as $key => $city)
			{
				$option .= '<option value="'.$key.'">'.$city.'</option>';		
			}
		}else	
		{
			$option .= '<option value="">'.esc_html__( 'Not available', 'appointy' ).'</option>';
		}
		
		wp_send_json_success($option);
		
   		die();
	}
	
	/**
	 * Get location
	 *
	 * @return void
	 */
	public static function get_location() {
	    global $wpdb;
		
		$args = array(
            'post_type' => 'appointy_locations',
            'post_status' => 'publish',
            'posts_per_page' => -1,
            'orderby' => 'ID',
            'order' => 'DESC',
        );
		
        $the_query = new \WP_Query($args);
		
		$data = array();
		if ( $the_query->have_posts() ) {
			$nestedData = array();
			while ( $the_query->have_posts() ) : $the_query->the_post();
				$locationid = get_the_id();
				
				$nestedData['delete'] = '<div class="checkbox sf-radio-checkbox">
											<input type="checkbox" id="location-'.esc_attr($locationid).'" value="'.esc_attr($locationid).'" class="delete_row delete_location">
											<label for="location-'.esc_attr($locationid).'"></label>
										</div>';
				$nestedData['title'] =  get_the_title();
				$nestedData['phone'] =  get_post_meta($locationid,'phone',true);
				$nestedData['address'] =  get_post_meta($locationid,'friendly_address',true);
				
				$actions = '<div class="dropdown action-dropdown dropdown-left">
							  <button class="action-button btn btn-primary dropdown-toggle" type="button" data-bs-toggle="dropdown"><i class="fa fa-ellipsis-v"></i></button>
							  <ul class="dropdown-menu">
								<li><a href="javascript:;" class="dropdown-item editlocation" data-locationid="'.esc_attr($locationid).'"><i class="fa fa-pencil"></i> '.esc_html__( 'Edit','appointy' ).'</a></li>
							  </ul>
							</div>';
				
				$nestedData['action'] = $actions;
				
				$data[] = $nestedData;	
			endwhile;
		}
		
		$json_data = array( 'data' => $data );
		
		echo json_encode( $json_data );
		die();
	}
	
	public static function location_fields( $post_id = 0 ) {
		
		$fields = apply_filters( 'appointy_location_form_fields', array(
			'title' => array(
				'label'       => esc_html__( 'Title', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-graduation-cap',
				'colum-width' => 'col-lg-6',
				'required'    => true,
				'validation_message' => esc_html__( 'Title is required', 'appointy' ),
				'placeholder' => '',
				'priority'    => 1
			),
			'phone' => array(
				'label'       => esc_html__( 'Phone', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-phone',
				'colum-width' => 'col-lg-6',
				'required'    => false,
				'placeholder' => '',
				'priority'    => 2
			),
			'description' => array(
				'label'       => esc_html__( 'Description', 'appointy' ),
				'type'        => 'textarea',
				'colum-width' => 'col-lg-12',
				'icon'        => 'fa fa-pencil',
				'required'    => false,
				'placeholder' => esc_html__( 'Description', 'appointy' ),
				'priority'    => 3
			)
		) );

		return Appointy_Form_Helper::get_fields( $fields );	
	}
	
	public static function address_fields( $post_id = 0 ) {
	
		$default_country = Appointy_Misc_Helper::get_settings( 'general_settings', 'default_country' );
		$default_state = Appointy_Misc_Helper::get_settings( 'general_settings', 'default_state' );
		
		$post_country = get_post_meta( $post_id,'country', true );
		$default_country = ( $post_country != '' ) ? $post_country : $default_country;
		
		$post_state = get_post_meta( $post_id,'state', true );
		$default_state = ( $post_state != '' ) ? $post_state : $default_state;
		
		$fields = apply_filters( 'appointy_address_form_fields', array(
			'country' => array(
				'label'       => esc_html__( 'Country', 'appointy' ),
				'type'        => 'select',
				'default'     => '',
				'icon'        => 'fa fa-globe',
				'colum-width' => 'col-lg-4',
				'required'    => true,
				'placeholder' => esc_html__( 'Please select country', 'appointy' ),
				'priority'    => 1,
				'default'    =>  $default_country,
				'options' 	  => self::get_countries()
			),
			'state' => array(
				'label'       => self::get_state_replacement( 'singular' ),
				'type'        => 'select',
				'icon'        => 'fa fa-globe',
				'colum-width' => 'col-lg-4',
				'required'    => true,
				'placeholder' => sprintf(esc_html__( 'Please select %s', 'appointy' ),self::get_state_replacement( 'singular' )),
				'priority'    => 2,
				'default'    =>  $default_state,
				'options' 	  => self::get_states( $default_country )
			),
			'city' => array(
				'label'       => self::get_city_replacement( 'singular' ),
				'type'        => 'select',
				'default'     => '',
				'icon'        => 'fa fa-map-marker',
				'colum-width' => 'col-lg-4',
				'required'    => true,
				'placeholder' => esc_html__( 'City is required', 'appointy' ),
				'priority'    => 3,
				'options' 	  => self::get_cities( $default_country,$default_state )
			),
			'zipcode' => array(
				'label'       => esc_html__( 'Enter Pincode', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-info',
				'colum-width' => 'col-lg-4',
				'required'    => false,
				'placeholder' => '',
				'priority'    => 4
			),
			'latitude' => array(
				'label'       => esc_html__( 'Latitude', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-street-view',
				'colum-width' => 'col-lg-4',
				'required'    => false,
				'placeholder' => '',
				'priority'    => 5
			),
			'longitude' => array(
				'label'       => esc_html__( 'Longitude', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-street-view',
				'colum-width' => 'col-lg-4',
				'required'    => false,
				'placeholder' => '',
				'priority'    => 6
			),
			'friendly_address' => array(
				'label'       => esc_html__( 'Friendly Address', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-map-marker',
				'colum-width' => 'col-lg-6',
				'required'    => true,
				'placeholder' => esc_html__( 'Enter address', 'appointy' ),
				'description' => esc_html__( 'It will be use for display purpose', 'appointy' ),
				'priority'    => 7
			),
			'map_location' => array(
				'label'       => esc_html__( 'Maps Location', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-map-marker',
				'colum-width' => 'col-lg-6',
				'required'    => false,
				'placeholder' => esc_html__( 'Enter map location', 'appointy' ),
				'description' => esc_html__( 'It will be use for map location', 'appointy' ),
				'priority'    => 8
			),
		) );

		return Appointy_Form_Helper::get_fields( $fields );	
	}
	
	/**
	 * Get countries
	 *
	 * @return array
	 */
	public static function get_countries( ) {
		
		$texonomy = 'appointy_country';
		$args = array(
				'orderby'           => 'name',
				'order'             => 'ASC',
				'hide_empty'        => false
			); 
		$countries = get_terms( $texonomy,$args );
		
		$countryarray[''] = esc_html__( 'Select country', 'appointy' );
		
		if ( !is_wp_error($countries) ) {
		
			if(!empty($countries)) {
				foreach($countries as $term) {
					
					$countryarray[$term->slug] = $term->name;
				}
			}
			
		}
		
		return $countryarray;
	}
	
	/**
	 * Get states
	 *
	 * @return array
	 */
	public static function get_states( $default_country = '' ) {
		
		$texonomy = 'appointy_state';
		$args = array(
				'orderby'           => 'name',
				'order'             => 'ASC',
				'hide_empty'        => false
			); 
		$states = get_terms( $texonomy,$args );
		
		$has_state = false;
		
		$statearray[''] = sprintf( esc_html__( 'Select %s', 'appointy' ), self::get_state_replacement( 'singular' ) );
		
		if ( !is_wp_error($states) ) {
		
			if(!empty($states)) {
				foreach($states as $term) {
				
					if( $default_country != '' ) {
					
						$country_id = get_term_meta($term->term_id, 'country', true);
						
						$country_slug = ( $country_id > 0 ) ? Appointy_Misc_Helper::get_category_slug($country_id,'appointy_country') : '';
						
						if(strtolower($country_slug) === strtolower($default_country)) {
							$has_state = true;
							$statearray[$term->slug] = $term->name;
						}
					} else {
						$has_state = true;
						$statearray[$term->slug] = $term->name;
					}
				}
			}
		}
		
		if( $has_state === true ) {
			return $statearray;
		} else {
			$statearray[''] = esc_html__( 'Not available', 'appointy' );
			return $statearray;
		}
		
	}
	
	/**
	 * Get cities
	 *
	 * @return array
	 */
	public static function get_cities( $default_country = '', $default_state = '' ) {
		
		$texonomy = 'appointy_city';
		$args = array(
				'orderby'           => 'name',
				'order'             => 'ASC',
				'hide_empty'        => false
			); 
		$cities = get_terms( $texonomy,$args );
		
		$has_city = false;
		
		$cityarray[''] = sprintf( esc_html__( 'Select %s', 'appointy' ), self::get_city_replacement( 'singular' ) );
		
		if ( !is_wp_error($cities) ) {
		
			if(!empty($cities)) {
				foreach($cities as $term) {
					
					if( $default_country != '' && $default_state != '' ) {
					
						$country_id = get_term_meta($term->term_id, 'country', true);
						$country_slug = ( $country_id > 0 ) ? Appointy_Misc_Helper::get_category_slug($country_id,'appointy_country') : '';
						
						$state_id = get_term_meta($term->term_id, 'state', true);
						$state_slug = ( $state_id > 0 ) ? Appointy_Misc_Helper::get_category_slug($state_id,'appointy_state') : '';
						
						if( strtolower($country_slug) === strtolower($default_country) && strtolower($state_slug) === strtolower($default_state) ) {
							$has_city = true;
							$cityarray[$term->slug] = $term->name;
						}
					} elseif( $default_country != '' ) {
					
						$country_id = get_term_meta($term->term_id, 'country', true);
						$country_slug = ( $country_id > 0 ) ? Appointy_Misc_Helper::get_category_slug($country_id,'appointy_country') : '';
						
						if( strtolower($country_slug) === strtolower($default_country) ) {
							$has_city = true;
							$cityarray[$term->slug] = $term->name;
						}
					} elseif( $default_state != '' ) {
					
						$state_id = get_term_meta($term->term_id, 'state', true);
						$state_slug = ( $state_id > 0 ) ? Appointy_Misc_Helper::get_category_slug($state_id,'appointy_state') : '';
						
						if( strtolower($state_slug) === strtolower($default_state) ) {
							$has_city = true;
							$cityarray[$term->slug] = $term->name;
						}
					} else {
						//$has_city = true;
						//$cityarray[$term->slug] = $term->name;
					}
					
				}
			}
			
		}
		
		if( $has_city === true ) {
			return $cityarray;
		} else {
			$cityarray[''] = esc_html__( 'Not available', 'appointy' );
			return $cityarray;
		}
	}
	
	public static function get_state_replacement( $noun = 'singular' ) {
		
		return ( $noun === 'singular' ) ? esc_html__( 'State', 'appointy' ) : esc_html__( 'States', 'appointy' );
	}
	
	public static function get_city_replacement( $noun = '' ) {
		
		return ( $noun === 'singular' ) ? esc_html__( 'City', 'appointy' ) : esc_html__( 'Cities', 'appointy' );
	}
	
	public static function get_default_country() {
		
		$default_country = Appointy_Misc_Helper::get_settings( 'general_settings', 'default_country' );
		
		return $default_country;
	}
	
	public static function get_default_state() {
		
		$default_state = Appointy_Misc_Helper::get_settings( 'general_settings', 'default_state' );
		
		return $default_state;
	}
	
	public static function get_default_country_code() {
		$country_code = '';

		$default_country = Appointy_Misc_Helper::get_settings( 'general_settings', 'default_country' );
		
		$term = get_term_by( 'slug', $default_country, 'appointy_country' );
		
		if ( !empty($term) ) {
			$termid = $term->term_id;
			$country_code = get_term_meta( $termid, 'country_code', true );
		}
		
		return $country_code;
	}
}
new Appointy_Location_Helper();