<?php 
class Appointy_Login_Helper {

	/**
     * Initialize the class
     *
     * @since     1.0.0
     */
    public function __construct() {
		
		add_action( 'wp_ajax_appointy_user_login', [ $this, 'process_login_form' ] );
		add_action( 'wp_ajax_nopriv_appointy_user_login', [ $this, 'process_login_form' ] );
    }
	
	public static function login_fields() {
		
		$fields = apply_filters( 'appointy_dynamic_login_form_fields', array(
			'username' => array(
				'label'       => esc_html__( 'Username/Email', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'feather-mail',
				'colum-width' => 'col-sm-12',
				'required'    => true,
				'validation_message' => esc_html__( 'Username/Email is required', 'appointy' ),
				'placeholder' => '',
				'priority'    => 1
			),
			'password' => array(
				'label'       => esc_html__( 'Password', 'appointy' ),
				'type'        => 'password',
				'icon'        => 'feather-lock',
				'colum-width' => 'col-sm-12',
				'id'          => 'login_password',
				'required'    => true,
				'validation_message' => esc_html__( 'Please enter password', 'appointy' ),
				'priority'    => 2
			)
		) );

		return Appointy_Form_Helper::get_fields( $fields );	
	}
	
	/**
	 * Process login form
	 *
	 * @return array
	 */
	public static function process_login_form( $args = array() ) {
		global $wpdb;
		
		if( !empty($args) ) {
			extract($args);
		} else {
			extract($_POST);
		}
		
		$invoiceid = Appointy_Router_Helper::get_request_data( $_POST, 'invoiceid' );
		$redirectto = Appointy_Router_Helper::get_request_data( $_POST, 'redirectto' );
		
		$creds = array();
		
		$creds['user_login'] = ( isset($username) ) ? sanitize_user( $username ) : '';
		$creds['user_password'] = ( isset($password) ) ? $password : '';
		$creds['rememberme'] = isset($rememberme) ? true : false;
		
		if (filter_var($creds['user_login'], FILTER_VALIDATE_EMAIL)) {
            $user_obj = get_user_by('email', $creds['user_login']);
        } else {
            $user_obj = get_user_by('login', $creds['user_login']);
        }
		
		$user_id = isset($user_obj->ID) ? $user_obj->ID : '0';
				
		$loginresponse = wp_signon( $creds, is_ssl() );
		
		if ( is_wp_error($loginresponse) ){
			$response = array('msg' => $loginresponse->get_error_message());
			wp_send_json_error($response);
	    } else {
			$user_id = $loginresponse->ID;
			$secure_cookie = true;
			wp_set_auth_cookie($user_id, $creds["rememberme"], $secure_cookie);
			wp_set_current_user($user_id);
			
			$redirect = get_admin_url('','admin.php?page=appointment');
			
			if( empty( $redirect ) ) {
				$redirect = home_url( '/' );
			}
			
			$user = wp_get_current_user();
			$user_roles = $user->roles;
			
			if(in_array('appointy_staff',$user_roles)) {
				$redirect = Appointy_Misc_Helper::get_url_by_shortcode( '[appointy-staff-dashboard' );
			}elseif(in_array('appointy_customer',$user_roles)) {
				$redirect = Appointy_Misc_Helper::get_url_by_shortcode( '[appointy-customer-dashboard' );
			}
			
	        $response = array('msg' => esc_html__('Login successful.', 'appointy'), 'redirect' => $redirect);
			
			wp_send_json_success($response);
	    }
   		die();
	}
}
new Appointy_Login_Helper();