<?php 
class Appointy_Payment_Helper {
	
    private $checkout_info = array();
	private $product_id;
	private $orderid;
	private $wooaction;
	private $appointment_data;

	public function __construct() {
		$this->product_id = Appointy_Misc_Helper::get_woocommerce_poduct_id();
		
		add_action( 'wp_ajax_addto_woo_cart', [ $this, 'process_addto_woo_cart' ] );
		add_action( 'wp_ajax_nopriv_addto_woo_cart', [ $this, 'process_addto_woo_cart' ] );
		
		if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
			add_action( 'woocommerce_add_to_cart',      		array( $this, 'empty_cart_before_add' ), 10, 3 );
			add_action( 'woocommerce_add_order_item_meta',      array( $this, 'update_woo_meda_data' ), 10, 3 );
            add_action( 'woocommerce_after_order_itemmeta',     array( $this, 'update_woo_cart_item' ), 10, 1 );
            add_action( 'woocommerce_before_calculate_totals',  array( $this, 'set_amount' ), 10, 1 );
			add_action( 'woocommerce_order_item_meta_end',      array( $this, 'update_woo_cart_item' ), 10, 1 );
			add_action( 'woocommerce_checkout_update_customer', array( $this, 'woo_checkout_update_customer' ), 10, 2 );
            
			add_action( 'woocommerce_order_status_cancelled',   array( $this, 'cancel_order' ), 10, 1 );
            add_action( 'woocommerce_order_status_completed',   array( $this, 'woo_payment_complete' ), 10, 1 );
            add_action( 'woocommerce_order_status_on-hold',     array( $this, 'woo_payment_complete' ), 10, 1 );
            add_action( 'woocommerce_order_status_processing',  array( $this, 'woo_payment_complete' ), 10, 1 );
            add_action( 'woocommerce_order_status_refunded',    array( $this, 'cancel_order' ), 10, 1 );
			
			add_filter( 'body_class', array( $this, 'body_classes' ) );

			add_filter( 'woocommerce_checkout_get_value',       array( $this, 'update_billing_info' ), 10, 2 );
            add_filter( 'woocommerce_get_item_data',            array( $this, 'update_cart_summary_meta_item' ), 10, 2 );
            add_filter( 'woocommerce_quantity_input_args',      array( $this, 'remove_quantity_field' ), 10, 2 );
			add_filter( 'woocommerce_thankyou',      			array( $this, 'redirect_after_payment' ), 10, 2 );
			add_filter( 'woocommerce_checkout_fields', array( $this, 'disable_checkout_fields' ), 10, 2 );
			
			/*Remove product name and product link from cart page*/
			add_filter('woocommerce_cart_item_permalink','__return_false');
			add_filter( 'woocommerce_cart_item_name', array( $this, 'cart_item_name_update' ), 10, 2 );
			
			/*Remove cart item quantity field from checkout page*/
			add_filter('woocommerce_checkout_cart_item_quantity','__return_false');
			
			/*Remove cart item quantity field from checkout page*/
			add_filter('woocommerce_order_item_permalink','__return_false');
			add_filter( 'woocommerce_order_item_name', array( $this, 'order_item_name_update' ), 10, 2 );
			add_filter('woocommerce_order_item_quantity_html','__return_false');
			
			/*Add service info on order deatails page (Thank you page)*/
			add_filter( 'woocommerce_order_details_after_order_table', array( $this, 'service_info_after_order_details' ), 10, 1 );
		}
	}

	/**
	 * Add to cart
	 *
	 * @return array
	 */
	public function process_addto_woo_cart() {
		global $wpdb, $current_user;
		
		$wootype = (!empty($_REQUEST['wootype'])) ? sanitize_text_field($_REQUEST['wootype']) : '';
		
		if($this->product_id === '' || !class_exists('woocommerce') || !intval($this->product_id) > 0) {
			$response = array(
				'msg'   => esc_html__( 'Please setup woocommerce payment.','appointy' )
			);
			wp_send_json_error($response);
			exit;
		}
		
		switch($wootype)
		{
			case 'appointment':
					$this->item_added_to_cart( $_REQUEST );
					break;
			case 'giftcard':
					$this->item_added_to_cart( $_REQUEST );
					break;		
			case 'invoice':
					$this->item_added_to_cart($_REQUEST);
					break;	
			case 'depositfullpayment':
					$this->item_added_to_cart($_REQUEST);
					break;
			case 'payrepeatpayment':
					$this->item_added_to_cart($_REQUEST);
					break;					
		}
		exit;
	}
	
	/**
	 * Item added to cart
	 *
	 * @return array
	 */
	public function item_added_to_cart( $postdata ) {
		try {
			WC()->cart->empty_cart();
			WC()->cart->add_to_cart( $this->product_id, 1, '', array(), array( 'woo_post_data' => $postdata ) );
			
			wp_send_json_success();
	
		} catch(Exception $e) {
			$response = array(
				'message'   => $e->getMessage()
			);
			wp_send_json_error($response);
		}
	}
	
	public function cart_item_name_update( $productname, $item ) {
	   
	   if(intval($item['product_id']) === intval($this->product_id)) {
			return false;	   
	   } else {
	   		return $productname;
	   }
	}
	
	public function order_item_name_update( $productname, $item ) {
	   
	   if(intval($item['product_id']) === intval($this->product_id)) {
			return false;	   
	   } else {
	   		return $productname;
	   }
	}
	
	public function empty_cart_before_add( $types ) {
		$cart_items = WC()->cart->get_cart();
		$total_cart_item = count($cart_items);
		$products_in_cart = array();
		
		$appointy_item_key = '';
		
		foreach ( $cart_items as $wc_key => $wc_item ) {
			$products_in_cart[] = $wc_item['product_id'];
			
			if(intval($wc_item['product_id']) === intval($this->product_id)) {
				$appointy_item_key = $wc_key;
			}
		}

		$product_id = ( isset($_REQUEST['product_id']) ) ? intval( $_REQUEST['product_id'] ) : 0;
		if($product_id != $this->product_id && $product_id > 0 && in_array($this->product_id,$products_in_cart)) {
			WC()->cart->remove_cart_item($appointy_item_key);
		}
	}
	
	/* Update woocommrce meta data */
	public function update_woo_meda_data( $item_id, $values, $wc_key ) {
        if ( isset ( $values['woo_post_data'] ) ) {
            wc_update_order_item_meta( $item_id, 'woo_post_data', $values['woo_post_data'] );
        }
    }
	
	/* Update woocommrce cart meta item */
	public function update_woo_cart_item( $item_id ) {
        $data = wc_get_order_item_meta( $item_id, 'woo_post_data' );
        if ( $data ) {
            $other_data = $this->update_cart_summary_meta_item( array(), array( 'woo_post_data' => $data ) );
			if(!empty($other_data)) {
            echo '<br/>' . $other_data[0]['name'] . '<br/>' . nl2br( $other_data[0]['value'] );
			}
        }
    }
	
	public function update_billing_info( $null, $field_name )
    {
	
       if ( empty( $this->checkout_info ) && function_exists( 'WC' ) && WC() && WC()->cart ) {
            foreach ( WC()->cart->get_cart() as $wc_key => $wc_item ) {
                if ( array_key_exists( 'woo_post_data', $wc_item ) ) {
				
                    $wootype = sanitize_text_field($wc_item['woo_post_data']['wootype']);
					switch($wootype){
					case 'appointment':
							$this->checkout_info = array(
								'billing_first_name' => Appointy_Router_Helper::get_request_data($wc_item['woo_post_data'],'first_name'),
								'billing_last_name'  => Appointy_Router_Helper::get_request_data($wc_item['woo_post_data'],'last_name'),
								'billing_email'      => Appointy_Router_Helper::get_request_data($wc_item['woo_post_data'],'email'),
								'billing_phone'      => Appointy_Router_Helper::get_request_data($wc_item['woo_post_data'],'phone'),
								'billing_address_1'  => Appointy_Router_Helper::get_request_data($wc_item['woo_post_data'],'address'),
							);
							break;
					case 'giftcard':
						$this->checkout_info = array(
								'billing_first_name' => Appointy_Router_Helper::get_request_data($wc_item['woo_post_data'],'first_name'),
								'billing_last_name'  => Appointy_Router_Helper::get_request_data($wc_item['woo_post_data'],'last_name'),
								'billing_email'      => Appointy_Router_Helper::get_request_data($wc_item['woo_post_data'],'email'),
								'billing_phone'      => Appointy_Router_Helper::get_request_data($wc_item['woo_post_data'],'phone'),
								'billing_address_1'  => Appointy_Router_Helper::get_request_data($wc_item['woo_post_data'],'address'),
							);
							break;
					case 'invoice':
						$this->checkout_info = array(
								'billing_first_name' => Appointy_Router_Helper::get_request_data($wc_item['woo_post_data'],'first_name'),
								'billing_last_name'  => Appointy_Router_Helper::get_request_data($wc_item['woo_post_data'],'last_name'),
								'billing_email'      => Appointy_Router_Helper::get_request_data($wc_item['woo_post_data'],'email'),
								'billing_phone'      => Appointy_Router_Helper::get_request_data($wc_item['woo_post_data'],'phone'),
								'billing_address_1'  => Appointy_Router_Helper::get_request_data($wc_item['woo_post_data'],'address'),
							);
							break;
					case 'depositfullpayment':
						$appointment_id = Appointy_Router_Helper::get_request_data($wc_item['woo_post_data'],'appointment_id');
						
						$first_name = get_post_meta($appointment_id,'first_name',true);
						$last_name = get_post_meta($appointment_id,'last_name',true);
						$email = get_post_meta($appointment_id,'email',true);
						$phone = get_post_meta($appointment_id,'phone',true);
						$address = get_post_meta($appointment_id,'address',true);
						
						$this->checkout_info = array(
								'billing_first_name' => $first_name,
								'billing_last_name'  => $last_name,
								'billing_email'      => $email,
								'billing_phone'      => $phone,
								'billing_address_1'  => $address
							);
							break;
					case 'payrepeatpayment':
						$appointment_id = Appointy_Router_Helper::get_request_data($wc_item['woo_post_data'],'appointment_id');
						
						$first_name = get_post_meta($appointment_id,'first_name',true);
						$last_name = get_post_meta($appointment_id,'last_name',true);
						$email = get_post_meta($appointment_id,'email',true);
						$phone = get_post_meta($appointment_id,'phone',true);
						$address = get_post_meta($appointment_id,'address',true);
						
						$this->checkout_info = array(
								'billing_first_name' => $first_name,
								'billing_last_name'  => $last_name,
								'billing_email'      => $email,
								'billing_phone'      => $phone,
								'billing_address_1'  => $address
							);
							break;			
					}
                }
            }
        }
        if ( array_key_exists( $field_name, $this->checkout_info ) ) {
            return $this->checkout_info[ $field_name ];
        }

        return null;
    }
	
	/* Update woocommrce cart summary item */
	public function update_cart_summary_meta_item( $other_data, $wc_item ) {
		if ( isset( $wc_item['woo_post_data'] )) {
			
			$wootype = sanitize_text_field($wc_item['woo_post_data']['wootype']);
			$this->wooaction = $wootype;
			switch($wootype)
			{
				case 'appointment':
					$other_data = array();
					
					$booked_services = $wc_item['woo_post_data']['booked_services'];
					$summary = self::appointment_checkout_summary($booked_services);
					if (is_order_received_page() ) {
					$other_data[] = array('name' => esc_html__('Request','appointy'), 'value' => esc_html__('Services Booked','appointy'));
					}else{
					$other_data[] = array('name' => esc_html__('Services Booked','appointy'), 'value' => $summary);		
					}
					break;
				case 'giftcard':
					if( isset($wc_item['woo_post_data']) ) {
						$other_data[] = array('name' => esc_html__('Request','appointy'), 'value' => esc_html__('Giftcard Payment','appointy'));
					}
					break;	
				case 'invoice':
					if( isset($wc_item['woo_post_data']) ) {
						$other_data[] = array('name' => esc_html__('Request','appointy'), 'value' => esc_html__('Invoice Payment','appointy'));
					}
					break;
				case 'depositfullpayment':
					if( isset($wc_item['woo_post_data']) ) {
						$other_data[] = array('name' => esc_html__('Request','appointy'), 'value' => esc_html__('Deposit Full Payment','appointy'));
					}
					break;
				case 'payrepeatpayment':
					if( isset($wc_item['woo_post_data']) ) {
						$other_data[] = array('name' => esc_html__('Request','appointy'), 'value' => esc_html__('Payment for Repeat Service','appointy'));
					}
					break;			
				default:
					break;	
			}
		}

        return $other_data;
    }
	
	public static function appointment_cart_summary($booked_services = array()) {
		$html = '';
		if(!empty($booked_services)){
			$html = '<div class="table-responsive">          
				  <table class="table">
					<thead>
					  <tr>
						<th>'.esc_html__( 'Service Name', 'appointy' ).'</th>
						<th>'.esc_html__( 'Date', 'appointy' ).'</th>
						<th>'.esc_html__( 'Time', 'appointy' ).'</th>
						<th>'.esc_html__( 'Price', 'appointy' ).'</th>
					  </tr>
					</thead>
					<tbody>';
					
			foreach($booked_services as $key => $service) {
				if(!empty($service)) {
					
					$serviceid = Appointy_Router_Helper::get_request_data( $service, 'serviceid', 0 );
					$service_name = Appointy_Router_Helper::get_request_data( $service, 'service_name', '-' );
					$servicetype = Appointy_Router_Helper::get_request_data( $service, 'servicetype', '-' );
					$service_period = Appointy_Router_Helper::get_request_data( $service, 'service_period', '-' );
					$date = Appointy_Router_Helper::get_request_data( $service, 'booking_date', '-' );
					$start_time = Appointy_Router_Helper::get_request_data( $service, 'booking_start_time', '-' );
					$end_time = Appointy_Router_Helper::get_request_data( $service, 'booking_end_time', '-' );
					$service_price = Appointy_Router_Helper::get_request_data( $service, 'service_price', '-' );
					$memberid = Appointy_Router_Helper::get_request_data( $service, 'member_id', 0 );
					
					if(intval($memberid) > 0) {
						$membername = '<span class="sf-checkout-membername"><i class="feather-user"></i> '.Appointy_Misc_Helper::get_fullname_by_user_id( $memberid ).'</span>';
					} else {
						$membername = '';
					}
					
					$html .= '<tr>
								<td><i class="fa fa-cog"></i> '.$service_name.' <span class="sf-cart-servicehours"><i class="fa fa-clock-o"></i> '.Appointy_Booking_Form_Helper::convert_minutes_to_hours($service_period).'</span>'.$membername.'</td>
								<td>'.Appointy_Misc_Helper::get_date_format($date).'</td>
								<td>'.Appointy_Misc_Helper::get_time_format( $start_time ).' - '.Appointy_Misc_Helper::get_time_format( $end_time ).'</td>
								<td>'.Appointy_Misc_Helper::get_price_format($service_price).'</td>
							  </tr>';
				}		  
						
			}
			
			$html .= '</tbody>
				  </table>
				  </div>';	
		}
		
		return $html; 	
	}
	
	public static function appointment_checkout_summary($booked_services = array()) {

		$html = '';

		if(!empty($booked_services)){

			foreach($booked_services as $key => $service) {

				if(!empty($service)) {

					

					$serviceid = Appointy_Router_Helper::get_request_data( $service, 'serviceid', 0 );

					$service_name = Appointy_Router_Helper::get_request_data( $service, 'service_name', '-' );

					$servicetype = Appointy_Router_Helper::get_request_data( $service, 'servicetype', '-' );

					$service_period = Appointy_Router_Helper::get_request_data( $service, 'service_period', '-' );

					$date = Appointy_Router_Helper::get_request_data( $service, 'booking_date', '-' );

					$start_time = Appointy_Router_Helper::get_request_data( $service, 'booking_start_time', '-' );

					$end_time = Appointy_Router_Helper::get_request_data( $service, 'booking_end_time', '-' );

					$service_price = Appointy_Router_Helper::get_request_data( $service, 'service_price', '-' );

					$memberid = Appointy_Router_Helper::get_request_data( $service, 'member_id', 0 );
					
					
					$variation_name = Appointy_Router_Helper::get_request_data($service,'variation_name');

					$service_name = ($servicetype === 'hourly') ? $variation_name : $service_name;

					

					if(intval($memberid) > 0) {

						$membername = '<span class="sf-checkout-membername"><i class="feather-user"></i> '.Appointy_Misc_Helper::get_fullname_by_user_id( $memberid ).'</span>';

					} else {

						$membername = '';

					}
					
					$srvarr = array();
			
					if($service_name != '') {
						$srvarr[] = $service_name;	
					}

					$srvarr[] = Appointy_Booking_Form_Helper::convert_minutes_to_hours($service_period);	

					if($membername != '') {
						$srvarr[] =  $membername;	
					}
					
					$srvarr[] =  Appointy_Misc_Helper::get_date_format($date);
					$srvarr[] =  Appointy_Misc_Helper::get_time_format( $start_time ).' - '.Appointy_Misc_Helper::get_time_format( $end_time );
					$srvarr[] =  Appointy_Misc_Helper::get_price_format($service_price);
					
					if(!empty($srvarr)) {
						$html .= implode(', ',$srvarr);
					}
					
				}		  

						

			}

		}

		

		return $html; 	

	}
	
	/* Update woocommrce cart amount */
	public function set_amount( $cart_object ) {
        global $wpdb;
		
		foreach ( $cart_object->cart_contents as $wc_key => $wc_item ) {
            if ( isset ( $wc_item['woo_post_data'] ) ) {
				$wootype = sanitize_text_field($wc_item['woo_post_data']['wootype']);
				switch($wootype) {
					case 'appointment':
							
							$totalamount = (isset($wc_item['woo_post_data']['totalamount'])) ? sanitize_text_field($wc_item['woo_post_data']['totalamount']) : 0;
							
							$deposit_options = (isset($wc_item['woo_post_data']['deposit_options'])) ? sanitize_text_field($wc_item['woo_post_data']['deposit_options']) : '';
							$deposit_type = (isset($wc_item['woo_post_data']['deposit_type'])) ? sanitize_text_field($wc_item['woo_post_data']['deposit_type']) : '';
							$deposit_amount = (isset($wc_item['woo_post_data']['deposit_amount'])) ? sanitize_text_field($wc_item['woo_post_data']['deposit_amount']) : 0;
							$due_amount = (isset($wc_item['woo_post_data']['due_amount'])) ? sanitize_text_field($wc_item['woo_post_data']['due_amount']) : 0;
							
							if($deposit_options === 'deposit_only') {
								$wc_item['data']->set_price( $deposit_amount );
							}else{
								$wc_item['data']->set_price( $totalamount );
							}
							
							
							break;
					case 'giftcard':
							
							$totalamount = (isset($wc_item['woo_post_data']['amount'])) ? sanitize_text_field($wc_item['woo_post_data']['amount']) : 0;
							
							$wc_item['data']->set_price( $totalamount );
							break;		
					case 'invoice':
							
							$amount = get_post_meta($wc_item['woo_post_data']['invoiceid'],'grand_total',true);
							
							$wc_item['data']->set_price( $amount );
							break;				
					case 'depositfullpayment':
							
							$appointment_id = Appointy_Router_Helper::get_request_data($wc_item['woo_post_data'],'appointment_id');
							$due_amount = get_post_meta($appointment_id,'due_amount',true);
							
							$amount = $due_amount;
							
							$wc_item['data']->set_price( $amount );
							break;
					case 'payrepeatpayment':
							
							$repeat_service_id = Appointy_Router_Helper::get_request_data($wc_item['woo_post_data'],'repeat_service_id');
							
							$row = $wpdb->get_row($wpdb->prepare('SELECT `total_amount` FROM `'.$wpdb->prefix.'appointy_repeat_schedule` WHERE `id` = %d',$repeat_service_id));
							$total_amount = Appointy_Router_Helper::get_sanitize_data( $row, 'total_amount' );
							
							$amount = $total_amount;
							
							$wc_item['data']->set_price( $amount );
							break;				
				}
                
            }
        }
    }
	
	/* Update customer account info at the time of checkout */
	public function woo_checkout_update_customer( $customer, $data ) {

		if ( ! is_user_logged_in() || is_admin() ) return;
	
		// Get the user ID
		$user_id = $customer->get_id();
	
		// Get the default wordpress first name and last name (if they exist)
		$user_first_name = get_user_meta( $user_id, 'first_name', true );
		$user_last_name = get_user_meta( $user_id, 'last_name', true );
	
		if( empty( $user_first_name ) || empty( $user_last_name ) ) return;
	
		// We set the values by defaul worpress ones, before it's saved to DB
		$customer->set_first_name( $user_first_name );
		$customer->set_last_name( $user_last_name );
	}
	
	/* Action perform on cancel order */
	public function cancel_order( $order_id ) {
		global $wpdb;
        $order = new \WC_Order( $order_id );
		if ( $order->get_status() != 'failed' ) {
        foreach ( $order->get_items() as $item_id => $order_item ) {
            $woopostdata = wc_get_order_item_meta( $item_id, 'woo_post_data' );
			$wootype = (isset($woopostdata['wootype'])) ? sanitize_text_field($woopostdata['wootype']) : '';
			switch($wootype){
				case 'appointment':
					$this->appointment_payment_cancel($woopostdata,$order_id,$item_id);
					break;
				case 'giftcard':
					$this->giftcard_payment_cancel($woopostdata,$order_id,$item_id);
					break;	
				case 'invoice':
					$this->invoice_payment_cancel($woopostdata,$order_id,$item_id);
					break;
				case 'depositfullpayment':
					//$this->depositfullpayment_cancel($woopostdata,$order_id,$item_id);
					break;
				case 'payrepeatpayment':
					//$this->depositfullpayment_cancel($woopostdata,$order_id,$item_id);
					break;			
			}
			
        }
		}
    }
	
	/* Action perform on booking payment cancel */
	public function appointment_payment_cancel( $woopostdata = array(),$order_id = 0,$item_id = 0 ) {
		global $wpdb; 
		$order = new \WC_Order( $order_id );
		
		$payment_method = $order->get_payment_method();
		$order_status = $order->get_status();
		
		if ( $woopostdata && ! isset ( $woopostdata['completed'] ) ) {
		
			$existingbooking = $wpdb->get_row($wpdb->prepare('SELECT `post_id` FROM '.$wpdb->prefix.'postmeta WHERE `meta_key` = "order_id" AND `meta_value` = %s',$order_id));
			if(!empty($existingbooking)){
				
				$appointment_id = Appointy_Router_Helper::get_request_data( $existingbooking, 'post_id' );
				
				$booking_post = array(
					'ID'           => $appointment_id,
					'post_status'  => 'cancelled',
				);
				wp_update_post( $booking_post );
				
				$wpdb->query($wpdb->prepare('DELETE FROM `'.$wpdb->prefix.'appointy_blocked_schedule` WHERE `appointment_id` = %d',$appointment_id));
				
				$woopostdata['cancelled'] = true;	
				wc_update_order_item_meta( $item_id, 'woo_post_data', $woopostdata );
			}
		}

	}
	
	/* Action perform on invoice payment cancel */
	public function giftcard_payment_cancel( $woopostdata = array(),$order_id = 0,$item_id = 0 ) {
		global $wpdb; 
		$order = new \WC_Order( $order_id );
		
		$payment_method = $order->get_payment_method();
		$order_status = $order->get_status();
		
		if ( $woopostdata && ! isset ( $woopostdata['completed'] ) ) {
		
			$existinggiftcardid = $wpdb->get_row($wpdb->prepare('SELECT `post_id` FROM '.$wpdb->prefix.'postmeta WHERE `meta_key` = "order_id" AND `meta_value` = %s',$order_id));
			if(!empty($existinggiftcardid)){
				
				$giftcardid = Appointy_Router_Helper::get_request_data( $existinggiftcardid, 'post_id' );
				
				$giftcard_post = array(
					'ID'           => $giftcardid,
					'post_status'  => 'invoice-payment-cancelled'
				);
				wp_update_post( $giftcard_post );
				
				$woopostdata['cancelled'] = true;	
				wc_update_order_item_meta( $item_id, 'woo_post_data', $woopostdata );
			}
		}
	}
	
	/* Action perform on invoice payment cancel */
	public function invoice_payment_cancel( $woopostdata = array(),$order_id = 0,$item_id = 0 ) {
		global $wpdb; 
		$order = new \WC_Order( $order_id );
		
		$payment_method = $order->get_payment_method();
		$order_status = $order->get_status();
		
		if ( $woopostdata && ! isset ( $woopostdata['completed'] ) ) {
		
			$existinginvoice = $wpdb->get_row($wpdb->prepare('SELECT `post_id` FROM '.$wpdb->prefix.'postmeta WHERE `meta_key` = "order_id" AND `meta_value` = %s',$order_id));
			if(!empty($existinginvoice)){
				
				$invoiceid = Appointy_Router_Helper::get_request_data( $existinginvoice, 'post_id' );
				
				$invoice_post = array(
					'ID'           => $invoiceid,
					'post_status'  => 'invoice-payment-cancelled'
				);
				wp_update_post( $invoice_post );
				
				$woopostdata['cancelled'] = true;	
				wc_update_order_item_meta( $item_id, 'woo_post_data', $woopostdata );
			}
		}
	}
	
	/* Action perform on payment complete */
	public function woo_payment_complete( $order_id ) {
		global $wpdb;
        $order = new \WC_Order( $order_id );
		$order_status = $order->get_status();
		if ( $order->get_status() != 'failed' ) {
        foreach ( $order->get_items() as $item_id => $order_item ) {
            $woopostdata = wc_get_order_item_meta( $item_id, 'woo_post_data' );
			$wootype = (isset($woopostdata['wootype'])) ? sanitize_text_field($woopostdata['wootype']) : '';
			switch($wootype){
				case 'appointment':
					Appointy_Booking_Form_Helper::save_appointment($woopostdata,$order_id,$item_id);
					$woopostdata['processed'] = true;	
					wc_update_order_item_meta( $item_id, 'woo_post_data', $woopostdata );
					
					if($order_status === 'completed'){
						$woopostdata['completed'] = true;	
						wc_update_order_item_meta( $item_id, 'woo_post_data', $woopostdata );
					}
					break;
				case 'giftcard':
				
					Appointy_Gift_Cards_Helper::send_giftcard($woopostdata,$order_id,$item_id);
					$woopostdata['processed'] = true;	
					wc_update_order_item_meta( $item_id, 'woo_post_data', $woopostdata );
					
					if($order_status === 'completed'){
						$woopostdata['completed'] = true;	
						wc_update_order_item_meta( $item_id, 'woo_post_data', $woopostdata );
					}
					break;	
				case 'invoice':
					Appointy_Invoice_Helper::update_invoice_payment($woopostdata,$order_id,$item_id);
					$woopostdata['processed'] = true;	
					wc_update_order_item_meta( $item_id, 'woo_post_data', $woopostdata );
					if($order_status === 'completed'){
						$woopostdata['completed'] = true;	
						wc_update_order_item_meta( $item_id, 'woo_post_data', $woopostdata );
					}
					break;
				case 'depositfullpayment':
					Appointy_Appointments_Helper::update_deposit_full_payment($woopostdata,$order_id,$item_id);
					$woopostdata['processed'] = true;	
					wc_update_order_item_meta( $item_id, 'woo_post_data', $woopostdata );
					if($order_status === 'completed'){
						$woopostdata['completed'] = true;	
						wc_update_order_item_meta( $item_id, 'woo_post_data', $woopostdata );
					}
					break;
				case 'payrepeatpayment':
					Appointy_Appointments_Helper::update_repeat_service_payment($woopostdata,$order_id,$item_id);
					$woopostdata['processed'] = true;	
					wc_update_order_item_meta( $item_id, 'woo_post_data', $woopostdata );
					if($order_status === 'completed'){
						$woopostdata['completed'] = true;	
						wc_update_order_item_meta( $item_id, 'woo_post_data', $woopostdata );
					}
					break;					
			}
			
        }
		}
    }

	public function redirect_after_payment($order_id) {
		global $wp, $wpdb, $current_user;
		
		if ( is_checkout() ) {
        $order = new \WC_Order( $order_id );
		if ( $order->get_status() != 'failed' ) {
        foreach ( $order->get_items() as $item_id => $order_item ) {
            $woopostdata = wc_get_order_item_meta( $item_id, 'woo_post_data' );
			
			$wootype = (isset($woopostdata['wootype'])) ? sanitize_text_field($woopostdata['wootype']) : '';
			switch($wootype)
			{
				case 'appointment':
						$pageid = Appointy_Misc_Helper::get_settings( 'booking_settings', 'redirect_after_booking', 'no' );
						$displaymessage = esc_html__('Appointment done successfully.','appointy');
						break;
				case 'giftcard':
						$pageid = Appointy_Misc_Helper::get_settings( 'booking_settings', 'redirect_after_giftcard_payment', 'no' );
						$displaymessage = esc_html__('Giftcard purchased successfully.','appointy');
						break;		
				case 'invoice':
						$pageid = Appointy_Misc_Helper::get_settings( 'booking_settings', 'redirect_after_invoice_payment', 'no' );
						$displaymessage = esc_html__('Invoice payment done successfully.','appointy');
						break;
				case 'depositfullpayment':
						$pageid = Appointy_Misc_Helper::get_settings( 'booking_settings', 'redirect_after_depositfullpayment_payment', 'no' );
						$displaymessage = esc_html__('Deposit full payment done successfully.','appointy');
						break;
				case 'payrepeatpayment':
						$pageid = Appointy_Misc_Helper::get_settings( 'booking_settings', 'redirect_after_payrepeatpayment_payment', 'no' );
						$displaymessage = esc_html__('Payment for repeat service done successfully.','appointy');
						break;								
				default:
						$pageid = 'no';
			}
			
			if($pageid != 'no' && $pageid > 0) {
				$redirectlink = add_query_arg( array('order_id' => $order_id), get_permalink($pageid) );
				wp_redirect($redirectlink);
				exit;
			}
        }
		}
		}
    
    }
	
	/* Remove quantity field from cart and checkout */
	public function remove_quantity_field( $args, $product ) {
        
		if ( intval($product->get_id()) === intval($this->product_id) ) {
            $args['max_value'] = $args['input_value'];
            $args['min_value'] = $args['input_value'];
        }

        return $args;
    }
	
	/* Add a class to body in checkout page for appointment */
	public function body_classes($classes) {
		
		$cart_items = WC()->cart->get_cart();
		$total_cart_item = count($cart_items);
		$products_in_cart = array();
		
		foreach ( $cart_items as $wc_key => $wc_item ) {
			$products_in_cart[] = $wc_item['product_id'];
		}
		
		if($total_cart_item === 1 && in_array($this->product_id,$products_in_cart)) {
			  $classes[] = 'appointment-checkout';
		}
		return $classes;
    }
	
	/* disable biiling info from checkout */
	public function disable_checkout_fields($fields) {
		
		$cart_items = WC()->cart->get_cart();
		$total_cart_item = count($cart_items);
		$products_in_cart = array();
		
		foreach ( $cart_items as $wc_key => $wc_item ) {
			$products_in_cart[] = (!empty($wc_item['wootype'])) ? sanitize_text_field($wc_item['wootype']) : '';
		}
		
		if($total_cart_item === 1 && in_array($this->product_id,$products_in_cart)) {
			unset($fields['billing']['billing_first_name']);
			unset($fields['billing']['billing_last_name']);
			unset($fields['billing']['billing_company']);
			unset($fields['billing']['billing_email']);
			unset($fields['billing']['billing_address_1']);
			unset($fields['billing']['billing_address_2']);
			unset($fields['billing']['billing_city']);
			unset($fields['billing']['billing_postcode']);
			unset($fields['billing']['billing_country']);
			unset($fields['billing']['billing_state']);
			unset($fields['billing']['billing_phone']);
			unset($fields['order']['order_comments']);
		}
		return $fields;
    }
	
	/*Add service info on order deatails page (Thank you page)*/
	public function service_info_after_order_details( $order ) {
		
		foreach ( $order->get_items() as $item_id => $order_item ) {
            $woopostdata = wc_get_order_item_meta( $item_id, 'woo_post_data' );
			
			$appointment_id = Appointy_Router_Helper::get_request_data($woopostdata,'appointment_id');
			
			$wootype = (!empty($woopostdata['wootype'])) ? sanitize_text_field($woopostdata['wootype']) : '';
			switch($wootype){
				case 'appointment':
						echo wp_kses('<h2 class="woocommerce-order-details__title">'.esc_html__( 'Appointment details', 'appointy' ).'</h2>',Appointy_Misc_Helper::get_allowed_tags());
						echo self::appointment_summary($woopostdata['booked_services'],$appointment_id);
						
						break;
			}
		}				
	}
	
	public static function appointment_summary($booked_services = array(),$appointment_id = 0) {
		$html = '';
		if(!empty($booked_services)){
			$html = '<div class="table-responsive">          
				  <table class="table">
					<thead>
					  <tr>
						<th>'.esc_html__( 'Service Name', 'appointy' ).'</th>
						<th>'.esc_html__( 'Service Type', 'appointy' ).'</th>
						<th>'.esc_html__( 'Service Period', 'appointy' ).'</th>
						<th>'.esc_html__( 'Date', 'appointy' ).'</th>
						<th>'.esc_html__( 'Start Time', 'appointy' ).'</th>
						<th>'.esc_html__( 'End Time', 'appointy' ).'</th>
						<th>'.esc_html__( 'Price', 'appointy' ).'</th>
					  </tr>
					</thead>
					<tbody>';
			foreach($booked_services as $key => $service)
			{
				if(!empty($service))
				{
					$service_id	= Appointy_Router_Helper::get_request_data( $service, 'service_id', 0 );
					$service_name	= Appointy_Router_Helper::get_request_data( $service, 'service_name' );
					$servicetype	= Appointy_Router_Helper::get_request_data( $service, 'servicetype' );
					$variation_name = Appointy_Router_Helper::get_request_data($service,'variation_name');
					$service_name = ($servicetype === 'hourly') ? $variation_name : $service_name;
					$service_period	= Appointy_Router_Helper::get_request_data( $service, 'service_period' );
					$date	= Appointy_Router_Helper::get_request_data( $service, 'booking_date' );
					$start_time	= Appointy_Router_Helper::get_request_data( $service, 'booking_start_time' );
					$end_time	= Appointy_Router_Helper::get_request_data( $service, 'booking_end_time' );
					$service_price	= Appointy_Router_Helper::get_request_data( $service, 'service_price','-' );
					$memberid = Appointy_Router_Helper::get_request_data( $service, 'member_id', 0 );
					
					$multidate_service	= Appointy_Router_Helper::get_request_data( $service, 'multidate_service' );
					
					$hours = Appointy_Router_Helper::get_request_data($service,'hours');
					$minutes = Appointy_Router_Helper::get_request_data($service,'minutes');
					
					$duration = Appointy_Booking_Form_Helper::get_duration($hours,$minutes);
					
					$booking_end_time = date(Appointy_Misc_Helper::get_wp_time_format(), strtotime($date.' '.$start_time." +".sanitize_text_field($duration)." minutes"));
					
					if($memberid > 0) {
						$membername = '<span class="sf-orderdetail-membername">('.Appointy_Misc_Helper::get_fullname_by_user_id( $memberid ).')</span>';
					} else {
						$membername = '';
					}
					
					$html .= '<tr>
								<td>'.$service_name.' '.$membername.'</td>
								<td>'.Appointy_Misc_Helper::translate_string($servicetype).'</td>
								<td>'.Appointy_Booking_Form_Helper::convert_minutes_to_hours($service_period).'</td>';
								if($multidate_service === 'yes') { 
								$multidatedates = Appointy_Appointments_Helper::get_multidate_booking_dates($appointment_id,$service_id);
								$html .= '<td>'.$multidatedates.'</td>';
								}else{
								$html .= '<td>'.Appointy_Misc_Helper::get_date_format($date).'</td>';									
								}
					$html .= '<td>'.Appointy_Misc_Helper::get_time_format( $start_time ).'</td>
								<td>'.Appointy_Misc_Helper::get_time_format( $booking_end_time ).'</td>
								<td>'.Appointy_Misc_Helper::get_price_format($service_price).'</td>
							  </tr>';
				}		  
						
			}
				
				$html .= '</tbody>
					  </table>
					  </div>';	
			}
			return $html; 	
	}
}
new Appointy_Payment_Helper();