<?php 
class Appointy_Permission_Helper {

	/**
     * Initialize the class
     *
     * @since     1.0.0
     */
    public function __construct() {
		add_action('wp_ajax_save_permission', array($this, 'save_permission'));
    }
	
	/**
	 * Save permission
	 *
	 * @return array
	 */
	public function save_permission() {
		global $wpdb;
        
		if( ! wp_verify_nonce( $_POST['_nonce'], 'appointy_ajax_nonce' ) || !current_user_can('manage_options') ) {
			wp_send_json_error();
			die();
		}
		
		$permissionid = 0;
		$wpdb->query($wpdb->prepare('DELETE FROM `'.$wpdb->prefix.'appointy_permissions` WHERE `id` > %d',$permissionid));

		if(!empty($_POST['actions'])) {

			foreach($_POST['actions'] as $action){

				$data['action'] 	= $action;
				$data['admin'] 	= Appointy_Router_Helper::get_sanitize_data( $_POST, 'admin-'.$action );
				$data['member'] 	= Appointy_Router_Helper::get_sanitize_data( $_POST, 'member-'.$action );
				$data['customer'] 	= Appointy_Router_Helper::get_sanitize_data( $_POST, 'customer-'.$action );
				
				$result = $wpdb->insert($wpdb->prefix.'appointy_permissions',wp_unslash($data));

			}
		}

		$response = array('msg' => esc_html__('Permissions saved.', 'appointy'));

		wp_send_json_success($response);

        die();
    }
	
	/**
	 * Get array for actions
	 *
	 * @return array
	 */
	public static function get_actions() {
		global $wpdb;

		$actions = array(
			'new_appointment' => esc_html__( 'New appointment', 'appointy' ),
			'service_reschedule' => esc_html__( 'Service reschedule', 'appointy' ),
			'reminder_repeatpayment' => esc_html__( 'Reminder repeat payment', 'appointy' ),
			'received_repeatpayment' => esc_html__( 'Received repeat payment', 'appointy' ),
			'received_fullpayment' => esc_html__( 'Received full payment', 'appointy' ),
			'service_complete' => esc_html__( 'Service completed', 'appointy' ),
			'service_cancel' => esc_html__( 'Service cancelled', 'appointy' ),
			'update_service_staff' => esc_html__( 'Update service staff', 'appointy' ),
			'invoice_generate' => esc_html__( 'Invoice generate', 'appointy' ),
			'invoice_paid' => esc_html__( 'Invoice paid', 'appointy' ),
			'add_feedback' => esc_html__( 'Add Feedback', 'appointy' ),
			'update_feedback' => esc_html__( 'Update Feedback', 'appointy' ),
		);

		return $actions;
	}
	
	/**
	 * Check has capability
	 *
	 * @return array
	 */
	public static function has_capability($action = '',$role = ''){
		global $current_user, $wpdb;
		
		$staffid = $current_user->ID;
		
		if($role == 'admin') {
			$row = $wpdb->get_row($wpdb->prepare('SELECT * FROM '.$wpdb->prefix.'appointy_permissions WHERE `action` = %s AND `admin` = "yes"',$action));
		}elseif($role == 'member'){
			$row = $wpdb->get_row($wpdb->prepare('SELECT * FROM '.$wpdb->prefix.'appointy_permissions WHERE `action` = %s AND `member` = "yes"',$action));
		}elseif($role == 'customer'){
			$row = $wpdb->get_row($wpdb->prepare('SELECT * FROM '.$wpdb->prefix.'appointy_permissions WHERE `action` = %s AND `customer` = "yes"',$action));
		}
		
		if(!empty($row)) {
			return true;
		}else{
			return false;
		}
	}
}
new Appointy_Permission_Helper();
