<?php 
class Appointy_Service_Helper {

	/**
     * Initialize the class
     *
     * @since     1.0.0
     */
    public function __construct() {
		
		add_action('wp_ajax_appointy_load_child_category', array($this, 'load_child_category'));
		add_action('wp_ajax_appointy_save_service', array($this, 'save_service'));
		add_action('wp_ajax_appointy_get_service', array($this, 'get_service'));
		add_action('wp_ajax_appointy_delete_service', array($this, 'delete_service'));
		add_action('wp_ajax_appointy_load_member_by_location', array($this, 'load_member_by_location'));
		add_action('wp_ajax_appointy_load_hourly_prices_by_location', array($this, 'load_hourly_prices_by_location'));
		add_action('wp_ajax_appointy_load_service_slots', array($this, 'load_service_slots'));
		add_action('wp_ajax_appointy_save_service_workperiod_timeslots', array($this, 'save_service_workperiod_timeslots'));
    }
	
	/**
	 * Delete service
	 *
	 * @return array
	 */
	public static function delete_service() {
		global $wpdb;
		
		$data_ids = Appointy_Router_Helper::get_request_data( $_POST, 'data_ids' );
		
		$data_id_array = explode(",", $data_ids); 

		if(!empty($data_id_array)) {
			foreach($data_id_array as $serviceid) {
				$force_delete = true;
				wp_delete_post( $serviceid, $force_delete );
				
				$wpdb->delete($wpdb->prefix.'services',array( 'service_id' => $serviceid ));
			}
		}
		
		wp_send_json_success();
		die();
	}
	
	/**
	 * Get service
	 *
	 * @return void
	 */
	public static function get_service() {
	    global $wpdb;
		
		$args = array(
            'post_type' => 'appointy_services',
            'post_status' => 'publish',
            'posts_per_page' => -1,
            'orderby' => 'ID',
            'order' => 'DESC',
        );
		
        $the_query = new \WP_Query($args);
		
		$data = array();
		if ( $the_query->have_posts() ) {
			$nestedData = array();
			while ( $the_query->have_posts() ) : $the_query->the_post();
				$serviceid = get_the_id();
				
				$nestedData['delete'] = '<div class="checkbox sf-radio-checkbox">
											<input type="checkbox" id="service-'.esc_attr($serviceid).'" value="'.esc_attr($serviceid).'" class="delete_row delete_service">
											<label for="service-'.esc_attr($serviceid).'"></label>
										</div>';
				$nestedData['title'] =  get_the_title();
				$nestedData['category'] =  self::get_saved_service_categories($serviceid);
				$nestedData['type'] =  Appointy_Misc_Helper::translate_string(get_post_meta($serviceid,'_servicetype',true));
				
				$params['serviceid'] = $serviceid;
				
				$editservideurl = Appointy_Router_Helper::generate_link( ['services', 'add'],$params );
				
				$actions = '<div class="dropdown action-dropdown dropdown-left">
							  <button class="action-button btn btn-primary dropdown-toggle" type="button" data-bs-toggle="dropdown"><i class="fa fa-ellipsis-v"></i></button>
							  <ul class="dropdown-menu">
								<li><a href="'.esc_url($editservideurl).'" class="dropdown-item"><i class="fa fa-pencil"></i> '.esc_html__( 'Edit','appointy' ).'</a></li>
							  </ul>
							</div>';
				
				$nestedData['action'] = $actions;
				
				$data[] = $nestedData;	
			endwhile;
		}
		
		$json_data = array( 'data' => $data );
		
		echo json_encode( $json_data );
		die();
	}
	
	public static function get_saved_service_categories($serviceid) {
		$servicecats = array();
		$categories = get_the_terms($serviceid,'appointy_service_category');
		if(!empty($categories)) {
			foreach( $categories as $category ) {
				$servicecats[] = $category->name;
			}
		}
		
		return implode(', ',$servicecats);
	}
	
	/**
     * Save service
     *
     * @since    1.0.0
     */
    public function save_service() {
		global $current_user;
        if( ! wp_verify_nonce( $_POST['_nonce'], 'appointy_ajax_nonce' ) || !current_user_can('manage_options') ) {
			wp_send_json_error();
			die();
		}
		
		$serviceid = Appointy_Router_Helper::get_sanitize_data( $_POST, 'serviceid' );
		
		if( !empty($serviceid) && $serviceid > 0 ) {
			$postid = self::update_service_post( $_POST, $serviceid );		
		} else {
			$postid = self::insert_service_post( $_POST );
		}
		
		$redirecturl = add_query_arg( array( 'page' => 'appointment','menu_item' => 'services__index' ), admin_url( 'admin.php' ) );
		
		$response = array( 'msg' => esc_html__('Service saved.', 'appointy'), 'redirect' => $redirecturl );
        wp_send_json_success($response);
        die();
    }
	
	public static function insert_service_post( $data = array() ) {
		global $wpdb, $current_user;
		
		$categories = array();
		
		if( !empty( Appointy_Router_Helper::get_sanitize_data( $data, 'category' ) ) ) {
			$categories[] = Appointy_Router_Helper::get_sanitize_data( $data, 'category' );
		}
		
		if( !empty( Appointy_Router_Helper::get_sanitize_data( $data, 'childcategory' ) ) ) {
			$categories[] = Appointy_Router_Helper::get_sanitize_data( $data, 'childcategory' );
		}
		
		$meta_fields = array();
		
		$service_availability = Appointy_Router_Helper::get_sanitize_data( $data, 'service_availability', false );
		$servicetype = Appointy_Router_Helper::get_sanitize_data( $data, 'servicetype' );
		
		$service_availability_status = ( isset( $service_availability ) ) ? true : false;
		$meta_fields['_service_availability_status'] = ( isset( $data['service_availability'] ) ) ? 'on' : 'off';
		
		$meta_fields['_service_staff'] = ( isset( $data['staff_id'] ) ) ? $data['staff_id'] : array();
		
		if( $service_availability_status ) {
			$service_availability = array();
		
			$weekdays = self::get_weekdays();
			if( !empty($weekdays) )	{
				$i = 0;
				foreach( $weekdays as $key => $value ) {
					$status = (!empty($data['status'])) ? $data['status'] : array();
					if ((bool) $status === false) {
						$status = array();
					}
					$status[$key] = ( isset( $status[$key] ) ) ? true : false;
					if( $status[$key] )	{
					$arraymap = array_map(null,$data['start_time'],$data['end_time'],$data['status']);
					if( !empty($arraymap) )	{
						$k = 0;
						foreach ($arraymap as $arrkey => $arrvalue) {
							if( $i === $k && ($arrvalue[0] != '' || $arrvalue[1])) {
							$service_availability[$key][] = $arrvalue[0];
							$service_availability[$key][] = $arrvalue[1];
							$service_availability[$key][] = true;
							}
							$k++;
						}
					}
					}
				$i++;
				}
			}	
			
			$meta_fields['_service_availability'] = $service_availability;
		}
		
		if( $servicetype === 'hourly' ) {
			$service_variations = array();
			
			
			$arraymap = array_map(null,$data['service_variation_name'],$data['service_variation_hours'],$data['service_variation_minutes'],$data['service_variation_price'],$data['service_variation_regular_price']);
			if( !empty($arraymap) ) {
				foreach ($arraymap as $key => $value) {
					$service_variations[] = $value;
				}
			}
		
			$meta_fields['_servicetype'] = Appointy_Router_Helper::get_sanitize_data( $data, 'servicetype' );
			$meta_fields['_service_variations'] = $service_variations;
		
		} elseif( $servicetype === 'fix' ) {
			$servicetype = Appointy_Router_Helper::get_sanitize_data( $data, 'servicetype' );
			$service_fixed_minutes = Appointy_Router_Helper::get_sanitize_data( $data, 'service_fixed_minutes' );
			$service_fixed_hours = Appointy_Router_Helper::get_sanitize_data( $data, 'service_fixed_hours' );
			$service_fixed_price = Appointy_Router_Helper::get_sanitize_data( $data, 'service_fixed_price' );
			$service_fixed_regualr_price = Appointy_Router_Helper::get_sanitize_data( $data, 'service_fixed_regualr_price' );
			$service_fixed_hours = Appointy_Router_Helper::get_sanitize_data( $data, 'service_fixed_hours' );
			$service_fixed_minutes = Appointy_Router_Helper::get_sanitize_data( $data, 'service_fixed_minutes' );
			$service_fixed_duration = Appointy_Router_Helper::get_sanitize_data( $data, 'service_fixed_duration' );
			
			$service_fixed_duration = intval($service_fixed_minutes) + (intval($service_fixed_hours) * 60);
			
			$meta_fields['_servicetype'] = $servicetype;
			$meta_fields['_service_fixed_price'] = $service_fixed_price;
			$meta_fields['_service_fixed_regular_price'] = $service_fixed_regualr_price;
			$meta_fields['_service_fixed_hours'] = $service_fixed_hours;
			$meta_fields['_service_fixed_minutes'] = $service_fixed_minutes;
			$meta_fields['_service_fixed_duration'] = $service_fixed_duration;
			
			$serviceprice = (!empty($service_fixed_price) && $service_fixed_price > 0) ? $service_fixed_price : $service_fixed_regualr_price;
			
		} elseif( $servicetype === 'package' ) {
			$servicetype = Appointy_Router_Helper::get_sanitize_data( $data, 'servicetype' );
			$package_minutes = Appointy_Router_Helper::get_sanitize_data( $data, 'package_minutes' );
			$package_hours = Appointy_Router_Helper::get_sanitize_data( $data, 'package_hours' );
			$package_price = Appointy_Router_Helper::get_sanitize_data( $data, 'package_price' );
			$package_regualr_price = Appointy_Router_Helper::get_sanitize_data( $data, 'package_regualr_price' );
			$package_hours = Appointy_Router_Helper::get_sanitize_data( $data, 'package_hours' );
			$package_minutes = Appointy_Router_Helper::get_sanitize_data( $data, 'package_minutes' );
			$package_duration = Appointy_Router_Helper::get_sanitize_data( $data, 'package_duration' );
			
			$package_duration = intval($package_minutes) + (intval($package_hours) * 60);
			
			$meta_fields['_servicetype'] = $servicetype;
			$meta_fields['_package_price'] = $package_price;
			$meta_fields['_package_regular_price'] = $package_regualr_price;
			$meta_fields['_package_hours'] = $package_hours;
			$meta_fields['_package_minutes'] = $package_minutes;
			$meta_fields['_package_duration'] = $package_duration;
			
			$serviceprice = (!empty($package_price) && $package_price > 0) ? $package_price : $package_regualr_price;
		}
		
		$category = Appointy_Router_Helper::get_sanitize_data( $data, 'category',0 );
		$childcategory = Appointy_Router_Helper::get_sanitize_data( $data, 'childcategory', 0 );
		$attachment_id = Appointy_Router_Helper::get_sanitize_data( $data, 'image_id' );
		
		$service_title = Appointy_Router_Helper::get_sanitize_data( $data, 'service_title' );
		$service_description = Appointy_Router_Helper::get_sanitize_data( $data, 'service_description' );
		
		$meta_fields['category'] = (!empty($category)) ? $category : 0;
		$meta_fields['childcategory'] = (!empty($childcategory)) ? $childcategory : 0;
		$meta_fields['image_id'] 	= $attachment_id;
		
		$repeat = Appointy_Router_Helper::get_sanitize_data( $data, 'repeat','no' );
		$frequencies = (!empty($data['frequencies'])) ? implode(',',$data['frequencies']) : '';
		
		$meta_fields['repeat'] = $repeat;
		$meta_fields['frequencies'] = $frequencies;
		
		$extra_service = Appointy_Router_Helper::get_sanitize_data( $data, 'extra_service','no' );
		$parent_service = Appointy_Router_Helper::get_sanitize_data( $data, 'parent_service' );
		
		$meta_fields['extra_service'] = $extra_service;
		$meta_fields['parent_service'] = ($extra_service === 'yes') ? $parent_service : '';
		
		$multidate_service = Appointy_Router_Helper::get_sanitize_data( $data, 'multidate_service','no' );
		$multidate_service_type = Appointy_Router_Helper::get_sanitize_data( $data, 'multidate_service_type' );
		$number_of_dates = Appointy_Router_Helper::get_sanitize_data( $data, 'number_of_dates' );
		$fullday_timeslots = Appointy_Router_Helper::get_sanitize_data( $data, 'fullday_timeslots' );
		
		$meta_fields['multidate_service'] = $multidate_service;
		$meta_fields['multidate_service_type'] = ($multidate_service === 'yes') ? $multidate_service_type : '';
		$meta_fields['number_of_dates'] = ($multidate_service === 'yes') ? $number_of_dates : '';
		$meta_fields['fullday_timeslots'] = ($multidate_service === 'yes') ? $fullday_timeslots : '';
		
		$service_post = array(
			'post_title' => $service_title,
			'post_status' => 'publish',
			'post_type' => 'appointy_services',
			'post_author' => $current_user->ID,
			'post_content' => $service_description,
			'meta_input'   => $meta_fields
		);
		$postid = wp_insert_post( $service_post );
		
		if( $servicetype === 'fix' || $servicetype === 'package' ) {
			$servicedata['service_id'] 	= $postid;
			$servicedata['service_title'] 	= $service_title;
			$servicedata['description'] 	= $service_description;
			$servicedata['category'] 	= Appointy_Misc_Helper::get_category_name($category,'appointy_service_category');
			$servicedata['childcategory'] 	= Appointy_Misc_Helper::get_category_name($childcategory,'appointy_service_category');
			$servicedata['price'] 	= $serviceprice;
			
			$wpdb->insert($wpdb->prefix.'services',wp_unslash($servicedata));
		} elseif( $servicetype === 'hourly' ) {
			if( !empty($service_variations) ) {
				foreach( $service_variations as $variationkey => $variationvalue ) {
					$servicedata['service_id'] 	= $postid;
					$servicedata['service_title'] 	= $service_title;
					$servicedata['description'] 	= $service_description;
					$servicedata['category'] 	= Appointy_Misc_Helper::get_category_name($category,'appointy_service_category');
					$servicedata['childcategory'] 	= Appointy_Misc_Helper::get_category_name($childcategory,'appointy_service_category');
					$servicedata['hourly_service'] 	= $variationvalue[0];
					
					$serviceprice = (!empty($variationvalue[3]) && $variationvalue[3] > 0) ? $variationvalue[3] : $variationvalue[4];
					
					$servicedata['price'] 	= $serviceprice;
					
					$wpdb->insert($wpdb->prefix.'services',wp_unslash($servicedata));
				}
			}
		}
		
		$locationstaffs = stripslashes(Appointy_Router_Helper::get_sanitize_data( $_POST, 'locationstaffarray' ));
		$locationstaffs = json_decode($locationstaffs, true);
		
		if(!empty($locationstaffs)) {
			$locationstaffdata['service_id'] 	= $postid;
			foreach($locationstaffs as $locationstaff){
				$locationId = Appointy_Router_Helper::get_sanitize_data( $locationstaff, 'locationId' );
				$locationstaffdata['location_id'] 	= $locationId;
				$staffMembers = (!empty($locationstaff['staffMembers'])) ? $locationstaff['staffMembers'] : array(); 
				
				if(!empty($staffMembers)) {
					foreach($staffMembers as $staffMemberId){
						$locationstaffdata['staff_id'] 	= $staffMemberId;
						$wpdb->insert($wpdb->prefix.'appointy_service_location_satff',wp_unslash($locationstaffdata));
					}
				}
			}
		}
		
		$locationprices = stripslashes(Appointy_Router_Helper::get_sanitize_data( $_POST, 'locationpricearray' ));
		$locationprices = json_decode($locationprices, true);
		
		if(!empty($locationprices) && ($servicetype == 'fix' || $servicetype == 'package')) {
			$locationpricedata['service_id'] 	= $postid;
			$locationpricedata['service_type'] 	= $servicetype;
			
			foreach($locationprices as $locationprice){
				$locationId = Appointy_Router_Helper::get_sanitize_data( $locationprice, 'locationId' );
				$salePrice = Appointy_Router_Helper::get_sanitize_data( $locationprice, 'salePrice' );
				$regularPrice = Appointy_Router_Helper::get_sanitize_data( $locationprice, 'regularPrice' );
				
				$locationpricedata['location_id'] 	= $locationId;
				$locationpricedata['sale_price'] 	= $salePrice;
				$locationpricedata['regular_price'] 	= $regularPrice;
				
				$finalPrice = (!empty($salePrice) && $salePrice > 0) ? $salePrice : $regularPrice;
				
				$locationpricedata['final_price'] 	= $finalPrice;
				
				$wpdb->insert($wpdb->prefix.'appointy_service_location_prices',wp_unslash($locationpricedata));
			}
		}
		
		$locationhourlyprices = stripslashes(Appointy_Router_Helper::get_sanitize_data( $_POST, 'locationhourlypricearray' ));
		$locationhourlyprices = json_decode($locationhourlyprices, true);
		
		if(!empty($locationhourlyprices) && $servicetype == 'hourly') {
			$locationhourlypricedata['service_id'] 	= $postid;
			$locationhourlypricedata['service_type'] 	= $servicetype;
			
			foreach($locationhourlyprices as $locationhourlyprice){
				$locationId = Appointy_Router_Helper::get_sanitize_data( $locationhourlyprice, 'locationId' );
				$variationId = Appointy_Router_Helper::get_sanitize_data( $locationhourlyprice, 'variationId' );
				$salePrice = Appointy_Router_Helper::get_sanitize_data( $locationhourlyprice, 'salePrice' );
				$regularPrice = Appointy_Router_Helper::get_sanitize_data( $locationhourlyprice, 'regularPrice' );
				
				$locationhourlypricedata['location_id'] 	= $locationId;
				$locationhourlypricedata['variation_id'] 	= $variationId;
				$locationhourlypricedata['sale_price'] 		= $salePrice;
				$locationhourlypricedata['regular_price'] 	= $regularPrice;
				
				$finalPrice = (!empty($salePrice) && $salePrice > 0) ? $salePrice : $regularPrice;
				
				$locationhourlypricedata['final_price'] 	= $finalPrice;
				
				$wpdb->insert($wpdb->prefix.'appointy_service_location_prices',wp_unslash($locationhourlypricedata));
			}
		}
		
		if( !empty($attachment_id) && $attachment_id > 0 )	{
			set_post_thumbnail( $postid, $attachment_id );
		}
		
		wp_set_post_terms( $postid, $categories, 'appointy_service_category' );
		
		return $postid;

	}
	
	public static function update_service_post( $data = array(), $serviceid = 0 ) {
		global $wpdb, $current_user;
		
		$categories = array();
		
		if( !empty( Appointy_Router_Helper::get_sanitize_data( $data, 'category' ) ) ) {
			$categories[] = Appointy_Router_Helper::get_sanitize_data( $data, 'category' );
		}
		
		if( !empty( Appointy_Router_Helper::get_sanitize_data( $data, 'childcategory' ) ) ) {
			$categories[] = Appointy_Router_Helper::get_sanitize_data( $data, 'childcategory' );
		}
		
		$meta_fields = array();
		
		$service_availability = Appointy_Router_Helper::get_sanitize_data( $data, 'service_availability', false );
		
		
		$servicetype = Appointy_Router_Helper::get_sanitize_data( $data, 'servicetype' );
		
		$service_availability_status = ( isset( $service_availability ) ) ? true : false;
		$meta_fields['_service_availability_status'] = ( isset( $data['service_availability'] ) ) ? 'on' : 'off';
		$meta_fields['_service_staff'] = ( isset( $data['staff_id'] ) ) ? $data['staff_id'] : array();
		
		if( $service_availability_status ) {
			$service_availability = array();
		
			$weekdays = self::get_weekdays();
			if( !empty($weekdays) ) {
				$i = 0;
				foreach( $weekdays as $key => $value ) {
					$status = (!empty($data['status'])) ? $data['status'] : array();
					if ($status === false) {
						$status = array();
					}
					$status[$key] = ( isset( $status[$key] ) ) ? true : false;
					
					if( $status[$key] )	{
					$arraymap = array_map(null,$data['start_time'],$data['end_time'],$data['status']);
					if( !empty($arraymap) )	{
						$k = 0;
						foreach ($arraymap as $arrkey => $arrvalue) {
							if( $i === $k && ($arrvalue[0] != '' || $arrvalue[1])) {
							$service_availability[$key][] = $arrvalue[0];
							$service_availability[$key][] = $arrvalue[1];
							$service_availability[$key][] = true;
							}
							$k++;
						}
					}
					}
				$i++;
				}
			}	
			$meta_fields['_service_availability'] = $service_availability;
		}
		
		if( $servicetype === 'hourly' ) {
			$service_variations = array();
			
			$arraymap = array_map(null,$data['service_variation_name'],$data['service_variation_hours'],$data['service_variation_minutes'],$data['service_variation_price'],$data['service_variation_regular_price']);
			if( !empty($arraymap) )	{
				foreach ($arraymap as $key => $value) {
					$service_variations[] = $value;
				}
			}
		
			$meta_fields['_servicetype'] = Appointy_Router_Helper::get_sanitize_data( $data, 'servicetype' );
			$meta_fields['_service_variations'] = $service_variations;
		
		} elseif( $servicetype === 'fix' ) {
			$servicetype = Appointy_Router_Helper::get_sanitize_data( $data, 'servicetype' );
			$service_fixed_minutes = Appointy_Router_Helper::get_sanitize_data( $data, 'service_fixed_minutes' );
			$service_fixed_hours = Appointy_Router_Helper::get_sanitize_data( $data, 'service_fixed_hours' );
			$service_fixed_price = Appointy_Router_Helper::get_sanitize_data( $data, 'service_fixed_price' );
			$service_fixed_regualr_price = Appointy_Router_Helper::get_sanitize_data( $data, 'service_fixed_regualr_price' );
			$service_fixed_hours = Appointy_Router_Helper::get_sanitize_data( $data, 'service_fixed_hours' );
			$service_fixed_minutes = Appointy_Router_Helper::get_sanitize_data( $data, 'service_fixed_minutes' );
			$service_fixed_duration = Appointy_Router_Helper::get_sanitize_data( $data, 'service_fixed_duration' );
			
			$service_fixed_duration = intval($service_fixed_minutes) + (intval($service_fixed_hours) * 60);
			
			$meta_fields['_servicetype'] = $servicetype;
			$meta_fields['_service_fixed_price'] = $service_fixed_price;
			$meta_fields['_service_fixed_regular_price'] = $service_fixed_regualr_price;
			$meta_fields['_service_fixed_hours'] = $service_fixed_hours;
			$meta_fields['_service_fixed_minutes'] = $service_fixed_minutes;
			$meta_fields['_service_fixed_duration'] = $service_fixed_duration;
			
			$serviceprice = (!empty($service_fixed_price) && $service_fixed_price > 0) ? $service_fixed_price : $service_fixed_regualr_price;
			
		} elseif( $servicetype === 'package' ) {
			$servicetype = Appointy_Router_Helper::get_sanitize_data( $data, 'servicetype' );
			$package_minutes = Appointy_Router_Helper::get_sanitize_data( $data, 'package_minutes' );
			$package_hours = Appointy_Router_Helper::get_sanitize_data( $data, 'package_hours' );
			$package_price = Appointy_Router_Helper::get_sanitize_data( $data, 'package_price' );
			$package_regualr_price = Appointy_Router_Helper::get_sanitize_data( $data, 'package_regualr_price' );
			$package_hours = Appointy_Router_Helper::get_sanitize_data( $data, 'package_hours' );
			$package_minutes = Appointy_Router_Helper::get_sanitize_data( $data, 'package_minutes' );
			$package_duration = Appointy_Router_Helper::get_sanitize_data( $data, 'package_duration' );
			
			$package_duration = intval($package_minutes) + (intval($package_hours) * 60);
			
			$meta_fields['_servicetype'] = $servicetype;
			$meta_fields['_package_price'] = $package_price;
			$meta_fields['_package_regular_price'] = $package_regualr_price;
			$meta_fields['_package_hours'] = $package_hours;
			$meta_fields['_package_minutes'] = $package_minutes;
			$meta_fields['_package_duration'] = $package_duration;
			
			$serviceprice = (!empty($package_price) && $package_price > 0) ? $package_price : $package_regualr_price;
		}
		
		$category = Appointy_Router_Helper::get_sanitize_data( $data, 'category',0 );
		$childcategory = Appointy_Router_Helper::get_sanitize_data( $data, 'childcategory', 0 );
		$attachment_id = Appointy_Router_Helper::get_sanitize_data( $data, 'image_id' );
		
		$service_title = Appointy_Router_Helper::get_sanitize_data( $data, 'service_title' );
		$service_description = Appointy_Router_Helper::get_sanitize_data( $data, 'service_description' );
		
		$meta_fields['category'] = (!empty($category)) ? $category : 0;
		$meta_fields['childcategory'] = (!empty($childcategory)) ? $childcategory : 0;
		$meta_fields['image_id'] 	= $attachment_id;
		
		$repeat = Appointy_Router_Helper::get_sanitize_data( $data, 'repeat','no' );
		$frequencies = (!empty($data['frequencies'])) ? implode(',',$data['frequencies']) : '';
		
		$meta_fields['repeat'] = $repeat;
		$meta_fields['frequencies'] = $frequencies;
		
		$extra_service = Appointy_Router_Helper::get_sanitize_data( $data, 'extra_service','no' );
		$parent_service = Appointy_Router_Helper::get_sanitize_data( $data, 'parent_service' );
		
		$meta_fields['extra_service'] = $extra_service;
		$meta_fields['parent_service'] = ($extra_service === 'yes') ? $parent_service : '';
		
		$multidate_service = Appointy_Router_Helper::get_sanitize_data( $data, 'multidate_service','no' );
		$multidate_service_type = Appointy_Router_Helper::get_sanitize_data( $data, 'multidate_service_type' );
		$number_of_dates = Appointy_Router_Helper::get_sanitize_data( $data, 'number_of_dates' );
		$fullday_timeslots = Appointy_Router_Helper::get_sanitize_data( $data, 'fullday_timeslots' );
		
		$meta_fields['multidate_service'] = $multidate_service;
		$meta_fields['multidate_service_type'] = ($multidate_service === 'yes') ? $multidate_service_type : '';
		$meta_fields['number_of_dates'] = ($multidate_service === 'yes') ? $number_of_dates : '';
		$meta_fields['fullday_timeslots'] = ($multidate_service === 'yes') ? $fullday_timeslots : '';
		
		if( $serviceid > 0 ) {
			if($servicetype === 'hourly') {
				delete_post_meta($serviceid,'_service_fixed_price');
				delete_post_meta($serviceid,'_service_fixed_regular_price');
				delete_post_meta($serviceid,'_service_fixed_hours');
				delete_post_meta($serviceid,'_service_fixed_minutes');
				delete_post_meta($serviceid,'_service_fixed_duration');
				
				delete_post_meta($serviceid,'_package_price');
				delete_post_meta($serviceid,'_package_regular_price');
				delete_post_meta($serviceid,'_package_hours');
				delete_post_meta($serviceid,'_package_minutes');
				delete_post_meta($serviceid,'_package_duration');
			
			} elseif($servicetype === 'fix')	{
				delete_post_meta($serviceid,'_service_variations');
				
				delete_post_meta($serviceid,'_package_price');
				delete_post_meta($serviceid,'_package_regular_price');
				delete_post_meta($serviceid,'_package_hours');
				delete_post_meta($serviceid,'_package_minutes');
				delete_post_meta($serviceid,'_package_duration');
			
			} elseif($servicetype === 'package')	{
				delete_post_meta($serviceid,'_service_fixed_price');
				delete_post_meta($serviceid,'_service_fixed_regular_price');
				delete_post_meta($serviceid,'_service_fixed_hours');
				delete_post_meta($serviceid,'_service_fixed_minutes');
				delete_post_meta($serviceid,'_service_fixed_duration');
				
				delete_post_meta($serviceid,'_service_variations');
			}
		}
		
		$service_post = array(
			'ID'           => $serviceid,
			'post_title' => $service_title,
			'post_status' => 'publish',
			'post_type' => 'appointy_services',
			'post_author' => $current_user->ID,
			'post_content' => $service_description,
			'meta_input'   => $meta_fields
		);
		$postid = wp_update_post( $service_post );
		
		$wpdb->delete($wpdb->prefix.'services',array( 'service_id' => $serviceid ));
		
		if( $servicetype === 'fix' || $servicetype === 'package' ) {

			$servicedata['service_id'] 	= $postid;
			$servicedata['service_title'] 	= $service_title;
			$servicedata['description'] 	= $service_description;
			$servicedata['category'] 	= Appointy_Misc_Helper::get_category_name($category,'appointy_service_category');
			$servicedata['childcategory'] 	= Appointy_Misc_Helper::get_category_name($childcategory,'appointy_service_category');
			$servicedata['price'] 	= $serviceprice;
			
			$wpdb->insert($wpdb->prefix.'services',wp_unslash($servicedata));
		
		} elseif( $servicetype === 'hourly' ) {
			if( !empty($service_variations) ) {
				foreach( $service_variations as $variationkey => $variationvalue ) {
					$servicedata['service_id'] 	= $postid;
					$servicedata['service_title'] 	= $service_title;
					$servicedata['description'] 	= $service_description;
					$servicedata['category'] 	= Appointy_Misc_Helper::get_category_name($category,'appointy_service_category');
					$servicedata['childcategory'] 	= Appointy_Misc_Helper::get_category_name($childcategory,'appointy_service_category');
					$servicedata['hourly_service'] 	= $variationvalue[0];
					
					$serviceprice = (!empty($variationvalue[3]) && $variationvalue[3] > 0) ? $variationvalue[3] : $variationvalue[4];
					
					$servicedata['price'] 	= $serviceprice;
					
					$wpdb->insert($wpdb->prefix.'services',wp_unslash($servicedata));
					
				}
			}
		}
		
		$wpdb->delete($wpdb->prefix.'appointy_service_location_satff',array( 'service_id' => $serviceid ));
		
		$locationstaffs = stripslashes(Appointy_Router_Helper::get_sanitize_data( $_POST, 'locationstaffarray' ));
		$locationstaffs = json_decode($locationstaffs, true);
		
		if(!empty($locationstaffs)) {
			$locationstaffdata['service_id'] 	= $postid;
			foreach($locationstaffs as $locationstaff){
				$locationId = Appointy_Router_Helper::get_sanitize_data( $locationstaff, 'locationId' );
				$locationstaffdata['location_id'] 	= $locationId;
				$staffMembers = (!empty($locationstaff['staffMembers'])) ? $locationstaff['staffMembers'] : array(); 
				
				$locationstaffdata['staff_id'] 	= array();
				if(!empty($staffMembers)) {
					foreach($staffMembers as $staffMemberId){
						$locationstaffdata['staff_id'] 	= $staffMemberId;
						$wpdb->insert($wpdb->prefix.'appointy_service_location_satff',wp_unslash($locationstaffdata));
					}
				}
			}
		}
		
		$wpdb->delete($wpdb->prefix.'appointy_service_location_prices',array( 'service_id' => $serviceid ));
		
		$locationprices = stripslashes(Appointy_Router_Helper::get_sanitize_data( $_POST, 'locationpricearray' ));
		$locationprices = json_decode($locationprices, true);
		
		if(!empty($locationprices) && ($servicetype == 'fix' || $servicetype == 'package')) {
			$locationpricedata['service_id'] 	= $postid;
			$locationpricedata['service_type'] 	= $servicetype;
			
			foreach($locationprices as $locationprice){
				$locationId = Appointy_Router_Helper::get_sanitize_data( $locationprice, 'locationId' );
				$salePrice = Appointy_Router_Helper::get_sanitize_data( $locationprice, 'salePrice' );
				$regularPrice = Appointy_Router_Helper::get_sanitize_data( $locationprice, 'regularPrice' );
				
				$locationpricedata['location_id'] 	= $locationId;
				$locationpricedata['sale_price'] 	= $salePrice;
				$locationpricedata['regular_price'] 	= $regularPrice;
				
				$finalPrice = (!empty($salePrice) && $salePrice > 0) ? $salePrice : $regularPrice;
				
				$locationpricedata['final_price'] 	= $finalPrice;
				
				$wpdb->insert($wpdb->prefix.'appointy_service_location_prices',wp_unslash($locationpricedata));
			}
		}
		
		$locationhourlyprices = stripslashes(Appointy_Router_Helper::get_sanitize_data( $_POST, 'locationhourlypricearray' ));
		$locationhourlyprices = json_decode($locationhourlyprices, true);
		
		if(!empty($locationhourlyprices) && $servicetype == 'hourly') {
			$locationhourlypricedata['service_id'] 	= $postid;
			$locationhourlypricedata['service_type'] 	= $servicetype;
			//echo '<pre>';print_r($locationhourlyprices);echo '</pre>';
			usort($locationhourlyprices, 'self::sortByVariationId');
			//echo '<pre>';print_r($locationhourlyprices);echo '</pre>';
			
			$groupedArray = array();

			foreach ($locationhourlyprices as $item) {
				$variationId = $item['variationId'];
				if (!isset($groupedArray[$variationId])) {
					$groupedArray[$variationId] = array();
				}
				$groupedArray[$variationId][] = $item;
			}
			
			if(!empty($groupedArray)) {
				$groupedArray = array_values($groupedArray);
				
				//echo '<pre>';print_r($groupedArray);echo '</pre>';
				
				foreach($groupedArray as $key => $locationhourlyprices){
					if(!empty($locationhourlyprices)) {
						foreach($locationhourlyprices as $locationhourlyprice){
							$locationId = Appointy_Router_Helper::get_sanitize_data( $locationhourlyprice, 'locationId' );
							//$variationId = Appointy_Router_Helper::get_sanitize_data( $locationhourlyprice, 'variationId' );
							$variationId = $key;
							$salePrice = Appointy_Router_Helper::get_sanitize_data( $locationhourlyprice, 'salePrice' );
							$regularPrice = Appointy_Router_Helper::get_sanitize_data( $locationhourlyprice, 'regularPrice' );
							
							$locationhourlypricedata['location_id'] 	= $locationId;
							$locationhourlypricedata['variation_id'] 	= $variationId;
							$locationhourlypricedata['sale_price'] 		= $salePrice;
							$locationhourlypricedata['regular_price'] 	= $regularPrice;
							
							$finalPrice = (!empty($salePrice) && $salePrice > 0) ? $salePrice : $regularPrice;
							
							$locationhourlypricedata['final_price'] 	= $finalPrice;
							
							$wpdb->insert($wpdb->prefix.'appointy_service_location_prices',wp_unslash($locationhourlypricedata));
						}					
					}
				}
			}
		}
		
		if( !empty($attachment_id) && $attachment_id > 0 )	{
			set_post_thumbnail( $postid, $attachment_id );
		}
		
		wp_set_post_terms( $postid, $categories, 'appointy_service_category' );
		
		return $postid;

	}
	
	public static function sortByVariationId($a, $b) {
		return $a['variationId'] - $b['variationId'];
	}

	public static function load_child_category() {
		$args = array(
			'child'					=>	true,
			'parent_category_id'	=>	Appointy_Router_Helper::get_request_data( $_POST, 'category_id' )
		);
		
		$categories = Appointy_Service_Helper::get_service_categories( 'appointy_service_category', $args );
		
		$options = '';
		if( !empty($categories) ) {
			foreach( $categories  as $category ) {
				$term_id = Appointy_Router_Helper::get_request_data( $category, 'term_id' );
				$term_name = Appointy_Router_Helper::get_request_data( $category, 'name' );
				
				$options .= '<option value="'.esc_attr($term_id).'">'.trim($term_name).'</option>';
			}
		} else {
			$options .= '<option value="">'.__('Not available','appointy').'</option>';
		}
		
		$response = array(
			'options'   => $options,
		);
		
		wp_send_json_success($response);
		exit;
	}
	
	public function load_hourly_prices_by_location() {
		global $wpdb;
		
		$serviceid = Appointy_Router_Helper::get_sanitize_data( $_POST, 'serviceId' );
		$variationid = Appointy_Router_Helper::get_sanitize_data( $_POST, 'variationId' );
		
		$appointyLocationHourlyPricesArray = (!empty($_POST['appointyLocationHourlyPricesArray'])) ? $_POST['appointyLocationHourlyPricesArray'] : array();
		
		//echo '<pre>';print_r($appointyLocationHourlyPricesArray);echo '</pre>';
		
		$result = array_filter($appointyLocationHourlyPricesArray, function($item) use ($serviceid, $variationid) {
			return (intval($item['variationId']) === intval($variationid));
		});
		
		//echo '<pre>';print_r($result);echo '</pre>';

		
		ob_start();
		if( !empty($serviceid) && $serviceid > 0 ) { 
			
			$addedHourlyPriceLocations = array();
			$locationHourlyPriceArray = array();
			//$service_locations = $wpdb->get_results($wpdb->prepare('SELECT `id`,`service_id`,`variation_id`,`location_id`,`sale_price`,`regular_price` FROM `'.$wpdb->prefix.'appointy_service_location_prices` WHERE `service_type` = "hourly" AND `service_id` = %d AND `variation_id` = %d',$serviceid,$variationid));
			
			echo '<ul id="resultHourlyPriceList">';
			
			if(!empty($result)) {
				foreach($result as $key => $row){
					$location_id = Appointy_Router_Helper::get_sanitize_data( $row, 'locationId' );
					$variation_id = Appointy_Router_Helper::get_sanitize_data( $row, 'variationId' );
					$location_id = ($location_id == '') ? 0 : intval($location_id);
					$variation_id = ($variation_id == '') ? 0 : intval($variation_id);
					
					$sale_price = Appointy_Router_Helper::get_sanitize_data( $row, 'salePrice' );
					$regular_price = Appointy_Router_Helper::get_sanitize_data( $row, 'regularPrice' );
					
					$locationHourlyPriceArray[$key]['variationId'] = $variation_id;
					$locationHourlyPriceArray[$key]['locationId'] = $location_id;
					$locationHourlyPriceArray[$key]['locationName'] = get_the_title($location_id);
					$locationHourlyPriceArray[$key]['salePrice'] = $sale_price;
					$locationHourlyPriceArray[$key]['regularPrice'] = $regular_price;
					
					echo '<li id="hourlypricelist'.esc_attr($location_id).'-'.$variation_id.'"><div class="ap-location-label-listing"><strong><i class="feather-map-pin"></i> '.esc_html__( 'Location', 'appointy' ).': </strong> <span> ' . get_the_title($location_id) . '</span> </div><div class="ap-price-label-listing"><strong><i class="feather-tag"></i> '.esc_html__( 'Sale Price', 'appointy' ).':</strong> <span> ' . Appointy_Misc_Helper::get_price_format($sale_price) . '</span> <strong><i class="feather-tag"></i> '.esc_html__( 'Regular Price', 'appointy' ).': </strong> <span>' . Appointy_Misc_Helper::get_price_format($regular_price) . '</span></div><div class="ap-location-price-btns"><button type="button" class="btn btn-danger btn-sm remove-price-icon removeHourlyPriceLocation" data-locationid="'.esc_attr($location_id).'" data-variationid="'.esc_attr($variation_id).'"><i class="fa fa-close"></i></button> <button type="button" class="btn btn-warning btn-sm edit-price-icon editHourlyPriceLocation" data-locationid="'.esc_attr($location_id).'" data-variationid="'.esc_attr($variation_id).'" data-saleprice="'.$sale_price.'" data-regularprice="'.$regular_price.'"><i class="fa fa-pencil"></i></button></div></li>';
				}
			}
			
			echo '</ul>';
		
			$locationHourlyPriceArray = json_encode($locationHourlyPriceArray);
			$addedHourlyPriceLocations = json_encode($addedHourlyPriceLocations);
			
			echo "<script>var locationHourlyPriceArray = $locationHourlyPriceArray;</script>";
		}else{
			echo '<ul id="resultHourlyPriceList"></ul>';
		}
			
		$locationhourlyprices = ob_get_clean();	
					
		$response = array(
			'locationhourlyprices'   => $locationhourlyprices
		);
		
		wp_send_json_success($response);
		exit;
	}
	
	public function load_service_slots() {
		global $wpdb;
		
		$user_id = Appointy_Router_Helper::get_request_data( $_POST, 'user_id' );
		
		$startTime = (!empty($_POST['startTime'])) ? $_POST['startTime'] : NULL;
		$endTime = (!empty($_POST['endTime'])) ? $_POST['endTime'] : NULL;
		$weekDay = Appointy_Router_Helper::get_sanitize_data( $_POST, 'weekDay' );
		$serviceId = Appointy_Router_Helper::get_sanitize_data( $_POST, 'serviceId' );
		$interval = 60;
		
		ob_start();
		if( $startTime != NULL && $endTime != NULL ) {
			?>
			<div class="edit-time-title"><?php echo Appointy_Misc_Helper::get_time_format( $startTime ). '-' .Appointy_Misc_Helper::get_time_format( $endTime ); ?></div>
			<?php
			echo '<ul class="edit-time-lists showhideslot">';
			$begin = new \DateTime( $startTime );
			$end = new \DateTime( $endTime );
			$intval = \DateInterval::createFromDateString( intval( $interval ).' min' );
			$available_start_times = new \DatePeriod($begin, $intval ,$end);
			foreach($available_start_times as $date){
			
			$row = $wpdb->get_row($wpdb->prepare('SELECT `id` FROM `'.$wpdb->prefix.'appointy_blocked_schedule` WHERE `member_id` = %d AND `service_id` = %d AND `dayoff_type` = "timeslot" AND `type` = "dayoff" AND `start_time` = %s AND `day` = %s',$user_id,$serviceId,$date->format("H:i:s"),$weekDay));
			?>
			<li class="<?php echo ( !empty( $row ) ) ? 'edit-time-hide active' : ''; ?>" data-timeslot="<?php echo esc_attr( $date->format("H:i:s") ); ?>" data-interval="<?php echo esc_attr( $interval ); ?>">
                <i class="<?php echo ( !empty( $row ) ) ? 'feather-eye' : 'feather-eye-off'; ?>"></i>
                <span><?php echo $date->format( Appointy_Misc_Helper::get_wp_time_format() ); ?></span>
            </li>
			<?php
			}
			echo '</ul>';
		}
        ?>
		<?php
		$html = ob_get_clean();
		
		$response = array( 'msg' => esc_html__('Slots loaded.', 'appointy'), 'html' => $html );
		wp_send_json_success($response);
		
   		die();
	}
	
	public function load_member_by_location() {
		$locationid = Appointy_Router_Helper::get_sanitize_data( $_POST, 'locationid' );
		$staffids = (!empty($_POST['staffids'])) ? $_POST['staffids'] : '';
		
		$staffids = explode(',',$staffids);
		
		$staff_flag = 0;
		ob_start();
		if($locationid != '') {
		$staffs = get_post_meta($locationid,'members',true);
		
		if($staffs != '') {
			$staffs = explode(',',$staffs);
		}else{
			$staffs = array();
		}
		if( !empty($staffs) ) {
			foreach( $staffs as $staff_id ) {
			$staff_name = Appointy_Misc_Helper::get_fullname_by_user_id($staff_id);
			$staff_flag = 1;
			
			$checked = ''; 

			$selected = '';

			if(!empty($staffids)) {

				if(in_array($staff_id,$staffids)) {

					$checked = 'checked="checked"';

					$selected = 'selected';

				}

			}
			?>

			<li class="<?php echo sanitize_html_class($selected); ?> equal-col">

				<div class="sf-team-mamber-wrap">

					<div class="sf-team-mamber-pic">

						<img src="<?php echo Appointy_Image_Helper::get_user_avatar($staff_id,'appointy-300x300'); ?>">

						<div class="sf-team-member-overlay"><span><i class="fa fa-check"></i></span></div>

					</div>

					<div class="sf-team-mamber-info">

						<h6><?php echo esc_html($staff_name); ?></h6>

					</div>

					<div class="checkbox sf-radio-checkbox collapse">

						<input <?php echo esc_attr($checked); ?> id="service_staff_id-<?php echo esc_attr($staff_id); ?>" class="staff_id" data-staffname="<?php echo esc_attr($staff_name); ?>" name="staff_id[]" value="<?php echo esc_attr($staff_id); ?>"  type="checkbox" >

						<label for="service_staff_id-<?php echo esc_attr($staff_id); ?>"></label>

					</div>

				</div>

			</li>

			<?php

			}

		}
		}else{
			$staffs = get_users( array( 'role' => 'appointy_staff', 'orderby' => 'display_name', 'order' => 'ASC' ) );

			if( !empty($staffs) ) {

				foreach( $staffs as $key => $value ) {
				$staff_id = Appointy_Router_Helper::get_request_data( $value, 'ID' );

				$staff_name = Appointy_Router_Helper::get_request_data( $value, 'display_name' );
				$staff_flag = 1;
				
				$checked = ''; 

				$selected = '';
	
				if(!empty($staffids)) {
	
					if(in_array($staff_id,$staffids)) {
	
						$checked = 'checked="checked"';
	
						$selected = 'selected';
	
					}
	
				}
				?>

				<li class="<?php echo sanitize_html_class($selected); ?> equal-col">

					<div class="sf-team-mamber-wrap">

						<div class="sf-team-mamber-pic">

							<img src="<?php echo Appointy_Image_Helper::get_user_avatar($staff_id,'appointy-300x300'); ?>">

							<div class="sf-team-member-overlay"><span><i class="fa fa-check"></i></span></div>

						</div>

						<div class="sf-team-mamber-info">

							<h6><?php echo esc_html($staff_name); ?></h6>

						</div>

						<div class="checkbox sf-radio-checkbox collapse">

							<input <?php echo esc_attr($checked); ?> id="service_staff_id-<?php echo esc_attr($staff_id); ?>" class="staff_id" data-staffname="<?php echo esc_attr($staff_name); ?>" name="staff_id[]" value="<?php echo esc_attr($staff_id); ?>"  type="checkbox" >

							<label for="service_staff_id-<?php echo esc_attr($staff_id); ?>"></label>

						</div>

					</div>

				</li>

				<?php

				}

			}
		}
		
		if($staff_flag === 0) {

			echo '<li class="no-staff-images ajax-no-staff">';

			_e('There are no staff members','appointy');

			echo '</li>';

		}
		
		$members = ob_get_clean();			
					
		$response = array(
			'members'   => $members
		);
		
		wp_send_json_success($response);
		exit;
	}
	
	public static function service_category_field($field_name = '', $service_category_id = '', $label = ''){
		?>
		<select name="<?php echo esc_attr($field_name); ?>" id="<?php echo esc_attr($service_category_id); ?>" title="<?php echo esc_attr($label); ?>">
        	<?php
            $categories = self::get_service_categories();
			
			if( !empty( $categories ) ) {
				foreach( $categories as $key => $category ){
					echo '<option value="'.esc_attr($key).'">'.$category.'</option>';
				}
			}
			?>
        </select>
		<?php
	}
	
	/**
	 * Get parent/child service categories
	 *
	 * @return array
	 */
	public static function get_service_categories( $texonomy = 'appointy_service_category', $args = array() ) {
		
		if( $texonomy != '' ) {
			$child = Appointy_Router_Helper::get_request_data( $args, 'child' );
			
			if( (bool) $child === true ) {
				$parent = Appointy_Router_Helper::get_request_data( $args, 'parent_category_id' );
			} else {
				$parent = 0;
			}
			
			if( !empty($args['search']) )	{
				$args = array(
					'orderby'           => 'name',
					'name__like'        => Appointy_Router_Helper::get_request_data( $args, 'search' ),
					'order'             => 'ASC',
					'number'            => Appointy_Router_Helper::get_request_data( $args, 'limit' ),
					'parent'            => $parent,
					'hide_empty'        => Appointy_Router_Helper::get_request_data( $args, 'hide_empty',false ),
				);		
			} else {
				$args = array(
					'orderby'           => 'name',
					'order'             => 'ASC',
					'number'            => Appointy_Router_Helper::get_request_data( $args, 'limit' ),
					'parent'            => $parent,
					'hide_empty'        => Appointy_Router_Helper::get_request_data( $args, 'hide_empty',false ),
				);		
			}
		}
		
		return $categories = get_terms( $texonomy,$args );
	}
	
	/**
	 * Get week days
	 *
	 * @return array
	 */
	public static function get_weekdays() {

		$days = array(
		'monday'	=>	__('Monday','appointy'),
		'tuesday'	=>	__('Tuesday','appointy'),
		'wednesday'	=>	__('Wednesday','appointy'),
		'thursday'	=>	__('Thursday','appointy'),
		'friday'	=>	__('Friday','appointy'),
		'saturday'	=>	__('Saturday','appointy'),
		'sunday'	=>	__('Sunday','appointy')
		);
		
		return $days;
	}
	
	/**
	 * Get week days color code
	 *
	 * @return array
	 */
	public static function get_weekdays_color_code() {

		$days = array(
		'monday'	=>	'green',
		'tuesday'	=>	'orange',
		'wednesday'	=>	'brown',
		'thursday'	=>	'pink',
		'friday'	=>	'blue',
		'saturday'	=>	'gray',
		'sunday'	=>	'purple'
		);
		
		return $days;
	}
	
	/**
	 * Get service dropdown array
	 *
	 * @return void
	 */
	public static function get_service_array() {
	    global $wpdb;
		
		$args = array(
            'post_type' => 'appointy_services',
            'post_status' => 'publish',
            'posts_per_page' => -1,
            'orderby' => 'ID',
            'order' => 'DESC',
        );
		
        $the_query = new \WP_Query($args);
		
		$has_service = false;
		
		if ( $the_query->have_posts() ) {
			$nestedData = array();
			while ( $the_query->have_posts() ) : $the_query->the_post();
				$serviceid = get_the_id();
				
				$has_service = true;
				$servicearray[$serviceid] = get_the_title();
			endwhile;
		}
		
		if( (bool) $has_service === true ) {
			return $servicearray;
		} else {
			$servicearray[''] = esc_html__( 'Not available', 'appointy' );
			return $servicearray;
		}
	}
	
	/**
	 * Get parent services
	 *
	 * @return void
	 */
	public static function get_parent_services() {
	    global $wpdb;
		
		$args = array(
            'post_type' => 'appointy_services',
            'post_status' => 'publish',
            'posts_per_page' => -1,
            'orderby' => 'ID',
            'order' => 'DESC',
			'meta_query' => array(
				'relation' => 'OR',
				array(
					'key' => 'extra_service',
					'value' => 'no',
					'compare' => '='
				),
				array(
					'key' => 'extra_service',
					'compare' => 'NOT EXISTS'
				),
			)
        );
		
        $the_query = new \WP_Query($args);
		
		return $the_query;
	}
	
	/**
	 * Process save service work period slots
	 *
	 * @return array
	 */
	public static function save_service_workperiod_timeslots( ) {
		global $wpdb;
		
        if( ! wp_verify_nonce( $_POST['_nonce'], 'appointy_ajax_nonce' ) ) {
			wp_send_json_error();
			die();
		}
		
		$user_id = Appointy_Router_Helper::get_request_data( $_POST, 'user_id' );
		$data['member_id'] = $user_id;
		
		$timeslots = (!empty($_POST['timeslots'])) ? $_POST['timeslots'] : array();
		$interval = Appointy_Router_Helper::get_sanitize_data( $_POST, 'interval' );
		$day = Appointy_Router_Helper::get_sanitize_data( $_POST, 'day' );
		$service_id = Appointy_Router_Helper::get_sanitize_data( $_POST, 'service_id' );
		
		if( !empty( $timeslots ) ) {
			$wpdb->query($wpdb->prepare('DELETE FROM `'.$wpdb->prefix.'appointy_blocked_schedule` WHERE `member_id` = %d AND `service_id` = %d AND `dayoff_type` = "timeslot" AND `type` = "dayoff" AND `day` = %s',$user_id,$service_id,$day));
			foreach( $timeslots as $timeslot ) {
				$data['day'] 	= ( isset( $day ) ) ? sanitize_text_field( $day ) : '';
				$data['start_time'] 	= ( !empty( $timeslot ) ) ? date( 'H:i:s',strtotime( sanitize_text_field( $timeslot ) ) ) : NULL;
				$end_time = date('H:i:s', strtotime($timeslot." +".$interval." minutes"));
				$data['end_time'] 	= ( !empty( $timeslot ) ) ? $end_time : NULL;
				$data['dayoff_type'] 	= 'timeslot';
				$data['type'] 	= 'dayoff';
				$data['service_id'] = $service_id;
				
				$result = $wpdb->insert( $wpdb->prefix.'appointy_blocked_schedule',wp_unslash( $data ) );
			}
		}
		
		if ( $result === false ){
			$response = array('msg' => $wpdb->print_error());
			wp_send_json_error($response);
	    } else {
			$response = array( 'msg' => esc_html__('Information saved.', 'appointy') );
			wp_send_json_success($response);
	    }
		
   		die();
	}
	
	/**
	 * Process save service work period slots
	 *
	 * @return array
	 */
	public static function get_weekday_interval($weekday = '') {
		global $wpdb;

		$row = $wpdb->get_row($wpdb->prepare('SELECT `interval` FROM `'.$wpdb->prefix.'appointy_work_periods` WHERE `weekday` = %s',strtolower($weekday)));
		
		$interval = (!empty($row)) ? Appointy_Router_Helper::get_sanitize_data( $row, 'interval' ) : 60;
		
		return $interval;
	}	
}
new Appointy_Service_Helper();
