<?php 
require_once APPOINTY_PLUGIN_DIR . '/library/Twilio/autoload.php';
use Twilio\Rest\Client;

class Appointy_Sms_Helper {

	/**
     * Initialize the class
     *
     * @since     1.0.0
     */
    public function __construct() {
		
		add_action('admin_init', array($this, 'sms_template_default_fields'));
		add_action('admin_init', array($this, 'sms_template_fields'));
		
		add_action('wp_ajax_appointy_get_sms_templates', array($this, 'get_sms_templates'));
		add_action('wp_ajax_appointy_save_sms_templates', array($this, 'save_sms_templates'));
		
    }
	
	/**
	 * Get sms notification
	 *
	 * @return array
	 */
	public static function send_sms( $phone = '', $message = '' ) {
		global $wpdb;
	
		$sid = Appointy_Misc_Helper::get_settings( 'sms_settings', 'twillio_sid' );
		$token = Appointy_Misc_Helper::get_settings( 'sms_settings', 'twillio_token' );
		$twiliosenderid = Appointy_Misc_Helper::get_settings( 'sms_settings', 'twillio_senderid' );
	
		if($phone != '') {
			try {
				$tonumber = $phone;
				$client = new Client($sid, $token);
				
				/*Send SMS*/
				$message = $client->messages->create(
					$tonumber,
					array(
						"body" => $message,
						"from" => $twiliosenderid,
					)
				);
				
				return $message;
				
			}catch(Exception $e){
				return $e->getMessage();
			}
		}
	}
	
	/**
	 * Get whatsapp notification
	 *
	 * @return array
	 */
	public static function send_whatsapp( $phone = '', $message = '' ) {
		global $wpdb;
	
		$sid = Appointy_Misc_Helper::get_settings( 'sms_settings', 'twillio_sid' );
		$token = Appointy_Misc_Helper::get_settings( 'sms_settings', 'twillio_token' );
		$twiliosenderid = Appointy_Misc_Helper::get_settings( 'sms_settings', 'twillio_senderid' );
	
		if($phone != '') {
			try {
				$tonumber = $phone;
				$client = new Client($sid, $token);
				
				/*Send Whatsapp Notification*/
				$whatsapp_from = 'whatsapp:'.$twiliosenderid;
				$whatsapp_to = 'whatsapp:'.$tonumber;
				
				$message = $client->messages->create(
					$whatsapp_to,
					array(
						"body" => $message,
						"from" => $whatsapp_from,
					)
				);
				
				return $message;
				
			}catch(Exception $e){
				return $e->getMessage();
			}
		}
	}
	
	/**
	 * Get country codes
	 *
	 * @return array
	 */
	public static function get_country_codes() {
	
		$country_codes = array(
			'AU'=>array('name'=>'AUSTRALIA','code'=>'61'),
			'AD'=>array('name'=>'ANDORRA','code'=>'376'),
			'AE'=>array('name'=>'UNITED ARAB EMIRATES','code'=>'971'),
			'AF'=>array('name'=>'AFGHANISTAN','code'=>'93'),
			'AG'=>array('name'=>'ANTIGUA AND BARBUDA','code'=>'1268'),
			'AI'=>array('name'=>'ANGUILLA','code'=>'1264'),
			'AL'=>array('name'=>'ALBANIA','code'=>'355'),
			'AM'=>array('name'=>'ARMENIA','code'=>'374'),
			'AN'=>array('name'=>'NETHERLANDS ANTILLES','code'=>'599'),
			'AO'=>array('name'=>'ANGOLA','code'=>'244'),
			'AQ'=>array('name'=>'ANTARCTICA','code'=>'672'),
			'AR'=>array('name'=>'ARGENTINA','code'=>'54'),
			'AS'=>array('name'=>'AMERICAN SAMOA','code'=>'1684'),
			'AT'=>array('name'=>'AUSTRIA','code'=>'43'),
			'AW'=>array('name'=>'ARUBA','code'=>'297'),
			'AZ'=>array('name'=>'AZERBAIJAN','code'=>'994'),
			'BA'=>array('name'=>'BOSNIA AND HERZEGOVINA','code'=>'387'),
			'BB'=>array('name'=>'BARBADOS','code'=>'1246'),
			'BD'=>array('name'=>'BANGLADESH','code'=>'880'),
			'BE'=>array('name'=>'BELGIUM','code'=>'32'),
			'BF'=>array('name'=>'BURKINA FASO','code'=>'226'),
			'BG'=>array('name'=>'BULGARIA','code'=>'359'),
			'BH'=>array('name'=>'BAHRAIN','code'=>'973'),
			'BI'=>array('name'=>'BURUNDI','code'=>'257'),
			'BJ'=>array('name'=>'BENIN','code'=>'229'),
			'BL'=>array('name'=>'SAINT BARTHELEMY','code'=>'590'),
			'BM'=>array('name'=>'BERMUDA','code'=>'1441'),
			'BN'=>array('name'=>'BRUNEI DARUSSALAM','code'=>'673'),
			'BO'=>array('name'=>'BOLIVIA','code'=>'591'),
			'BR'=>array('name'=>'BRAZIL','code'=>'55'),
			'BS'=>array('name'=>'BAHAMAS','code'=>'1242'),
			'BT'=>array('name'=>'BHUTAN','code'=>'975'),
			'BW'=>array('name'=>'BOTSWANA','code'=>'267'),
			'BY'=>array('name'=>'BELARUS','code'=>'375'),
			'BZ'=>array('name'=>'BELIZE','code'=>'501'),
			'CA'=>array('name'=>'CANADA','code'=>'1'),
			//'CC'=>array('name'=>'COCOS (KEELING) ISLANDS','code'=>'61'),
			'CD'=>array('name'=>'CONGO, THE DEMOCRATIC REPUBLIC OF THE','code'=>'243'),
			'CF'=>array('name'=>'CENTRAL AFRICAN REPUBLIC','code'=>'236'),
			'CG'=>array('name'=>'CONGO','code'=>'242'),
			'CH'=>array('name'=>'SWITZERLAND','code'=>'41'),
			'CI'=>array('name'=>'COTE D IVOIRE','code'=>'225'),
			'CK'=>array('name'=>'COOK ISLANDS','code'=>'682'),
			'CL'=>array('name'=>'CHILE','code'=>'56'),
			'CM'=>array('name'=>'CAMEROON','code'=>'237'),
			'CN'=>array('name'=>'CHINA','code'=>'86'),
			'CO'=>array('name'=>'COLOMBIA','code'=>'57'),
			'CR'=>array('name'=>'COSTA RICA','code'=>'506'),
			'CU'=>array('name'=>'CUBA','code'=>'53'),
			'CV'=>array('name'=>'CAPE VERDE','code'=>'238'),
			//'CX'=>array('name'=>'CHRISTMAS ISLAND','code'=>'61'),
			'CY'=>array('name'=>'CYPRUS','code'=>'357'),
			'CZ'=>array('name'=>'CZECH REPUBLIC','code'=>'420'),
			'DE'=>array('name'=>'GERMANY','code'=>'49'),
			'DJ'=>array('name'=>'DJIBOUTI','code'=>'253'),
			'DK'=>array('name'=>'DENMARK','code'=>'45'),
			'DM'=>array('name'=>'DOMINICA','code'=>'1767'),
			'DO'=>array('name'=>'DOMINICAN REPUBLIC','code'=>'1809'),
			'DZ'=>array('name'=>'ALGERIA','code'=>'213'),
			'EC'=>array('name'=>'ECUADOR','code'=>'593'),
			'EE'=>array('name'=>'ESTONIA','code'=>'372'),
			'EG'=>array('name'=>'EGYPT','code'=>'20'),
			'ER'=>array('name'=>'ERITREA','code'=>'291'),
			'ES'=>array('name'=>'SPAIN','code'=>'34'),
			'ET'=>array('name'=>'ETHIOPIA','code'=>'251'),
			'FI'=>array('name'=>'FINLAND','code'=>'358'),
			'FJ'=>array('name'=>'FIJI','code'=>'679'),
			'FK'=>array('name'=>'FALKLAND ISLANDS (MALVINAS)','code'=>'500'),
			'FM'=>array('name'=>'MICRONESIA, FEDERATED STATES OF','code'=>'691'),
			'FO'=>array('name'=>'FAROE ISLANDS','code'=>'298'),
			'FR'=>array('name'=>'FRANCE','code'=>'33'),
			'GA'=>array('name'=>'GABON','code'=>'241'),
			'GB'=>array('name'=>'UNITED KINGDOM','code'=>'44'),
			'GD'=>array('name'=>'GRENADA','code'=>'1473'),
			'GE'=>array('name'=>'GEORGIA','code'=>'995'),
			'GH'=>array('name'=>'GHANA','code'=>'233'),
			'GI'=>array('name'=>'GIBRALTAR','code'=>'350'),
			'GL'=>array('name'=>'GREENLAND','code'=>'299'),
			'GM'=>array('name'=>'GAMBIA','code'=>'220'),
			'GN'=>array('name'=>'GUINEA','code'=>'224'),
			'GQ'=>array('name'=>'EQUATORIAL GUINEA','code'=>'240'),
			'GR'=>array('name'=>'GREECE','code'=>'30'),
			'GT'=>array('name'=>'GUATEMALA','code'=>'502'),
			'GU'=>array('name'=>'GUAM','code'=>'1671'),
			'GW'=>array('name'=>'GUINEA-BISSAU','code'=>'245'),
			'GY'=>array('name'=>'GUYANA','code'=>'592'),
			'HK'=>array('name'=>'HONG KONG','code'=>'852'),
			'HN'=>array('name'=>'HONDURAS','code'=>'504'),
			'HR'=>array('name'=>'CROATIA','code'=>'385'),
			'HT'=>array('name'=>'HAITI','code'=>'509'),
			'HU'=>array('name'=>'HUNGARY','code'=>'36'),
			'ID'=>array('name'=>'INDONESIA','code'=>'62'),
			'IE'=>array('name'=>'IRELAND','code'=>'353'),
			'IL'=>array('name'=>'ISRAEL','code'=>'972'),
			'IN'=>array('name'=>'INDIA','code'=>'91'),
			'IQ'=>array('name'=>'IRAQ','code'=>'964'),
			'IR'=>array('name'=>'IRAN, ISLAMIC REPUBLIC OF','code'=>'98'),
			'IS'=>array('name'=>'ICELAND','code'=>'354'),
			'IT'=>array('name'=>'ITALY','code'=>'39'),
			'JM'=>array('name'=>'JAMAICA','code'=>'1876'),
			'JO'=>array('name'=>'JORDAN','code'=>'962'),
			'JP'=>array('name'=>'JAPAN','code'=>'81'),
			'KE'=>array('name'=>'KENYA','code'=>'254'),
			'KG'=>array('name'=>'KYRGYZSTAN','code'=>'996'),
			'KH'=>array('name'=>'CAMBODIA','code'=>'855'),
			'KI'=>array('name'=>'KIRIBATI','code'=>'686'),
			'KM'=>array('name'=>'COMOROS','code'=>'269'),
			'KN'=>array('name'=>'SAINT KITTS AND NEVIS','code'=>'1869'),
			'KP'=>array('name'=>'KOREA DEMOCRATIC PEOPLES REPUBLIC OF','code'=>'850'),
			'KR'=>array('name'=>'KOREA REPUBLIC OF','code'=>'82'),
			'KW'=>array('name'=>'KUWAIT','code'=>'965'),
			'KY'=>array('name'=>'CAYMAN ISLANDS','code'=>'1345'),
			'KZ'=>array('name'=>'KAZAKSTAN','code'=>'7'),
			'LA'=>array('name'=>'LAO PEOPLES DEMOCRATIC REPUBLIC','code'=>'856'),
			'LB'=>array('name'=>'LEBANON','code'=>'961'),
			'LC'=>array('name'=>'SAINT LUCIA','code'=>'1758'),
			'LI'=>array('name'=>'LIECHTENSTEIN','code'=>'423'),
			'LK'=>array('name'=>'SRI LANKA','code'=>'94'),
			'LR'=>array('name'=>'LIBERIA','code'=>'231'),
			'LS'=>array('name'=>'LESOTHO','code'=>'266'),
			'LT'=>array('name'=>'LITHUANIA','code'=>'370'),
			'LU'=>array('name'=>'LUXEMBOURG','code'=>'352'),
			'LV'=>array('name'=>'LATVIA','code'=>'371'),
			'LY'=>array('name'=>'LIBYAN ARAB JAMAHIRIYA','code'=>'218'),
			'MA'=>array('name'=>'MOROCCO','code'=>'212'),
			'MC'=>array('name'=>'MONACO','code'=>'377'),
			'MD'=>array('name'=>'MOLDOVA, REPUBLIC OF','code'=>'373'),
			'ME'=>array('name'=>'MONTENEGRO','code'=>'382'),
			'MF'=>array('name'=>'SAINT MARTIN','code'=>'1599'),
			'MG'=>array('name'=>'MADAGASCAR','code'=>'261'),
			'MH'=>array('name'=>'MARSHALL ISLANDS','code'=>'692'),
			'MK'=>array('name'=>'MACEDONIA, THE FORMER YUGOSLAV REPUBLIC OF','code'=>'389'),
			'ML'=>array('name'=>'MALI','code'=>'223'),
			'MM'=>array('name'=>'MYANMAR','code'=>'95'),
			'MN'=>array('name'=>'MONGOLIA','code'=>'976'),
			'MO'=>array('name'=>'MACAU','code'=>'853'),
			'MP'=>array('name'=>'NORTHERN MARIANA ISLANDS','code'=>'1670'),
			'MR'=>array('name'=>'MAURITANIA','code'=>'222'),
			'MS'=>array('name'=>'MONTSERRAT','code'=>'1664'),
			'MT'=>array('name'=>'MALTA','code'=>'356'),
			'MU'=>array('name'=>'MAURITIUS','code'=>'230'),
			'MV'=>array('name'=>'MALDIVES','code'=>'960'),
			'MW'=>array('name'=>'MALAWI','code'=>'265'),
			'MX'=>array('name'=>'MEXICO','code'=>'52'),
			'MY'=>array('name'=>'MALAYSIA','code'=>'60'),
			'MZ'=>array('name'=>'MOZAMBIQUE','code'=>'258'),
			'NA'=>array('name'=>'NAMIBIA','code'=>'264'),
			'NC'=>array('name'=>'NEW CALEDONIA','code'=>'687'),
			'NE'=>array('name'=>'NIGER','code'=>'227'),
			'NG'=>array('name'=>'NIGERIA','code'=>'234'),
			'NI'=>array('name'=>'NICARAGUA','code'=>'505'),
			'NL'=>array('name'=>'NETHERLANDS','code'=>'31'),
			'NO'=>array('name'=>'NORWAY','code'=>'47'),
			'NP'=>array('name'=>'NEPAL','code'=>'977'),
			'NR'=>array('name'=>'NAURU','code'=>'674'),
			'NU'=>array('name'=>'NIUE','code'=>'683'),
			'NZ'=>array('name'=>'NEW ZEALAND','code'=>'64'),
			'OM'=>array('name'=>'OMAN','code'=>'968'),
			'PA'=>array('name'=>'PANAMA','code'=>'507'),
			'PE'=>array('name'=>'PERU','code'=>'51'),
			'PF'=>array('name'=>'FRENCH POLYNESIA','code'=>'689'),
			'PG'=>array('name'=>'PAPUA NEW GUINEA','code'=>'675'),
			'PH'=>array('name'=>'PHILIPPINES','code'=>'63'),
			'PK'=>array('name'=>'PAKISTAN','code'=>'92'),
			'PL'=>array('name'=>'POLAND','code'=>'48'),
			'PM'=>array('name'=>'SAINT PIERRE AND MIQUELON','code'=>'508'),
			'PN'=>array('name'=>'PITCAIRN','code'=>'870'),
			'PR'=>array('name'=>'PUERTO RICO','code'=>'1'),
			'PT'=>array('name'=>'PORTUGAL','code'=>'351'),
			'PW'=>array('name'=>'PALAU','code'=>'680'),
			'PY'=>array('name'=>'PARAGUAY','code'=>'595'),
			'QA'=>array('name'=>'QATAR','code'=>'974'),
			'RO'=>array('name'=>'ROMANIA','code'=>'40'),
			'RS'=>array('name'=>'SERBIA','code'=>'381'),
			'RU'=>array('name'=>'RUSSIAN FEDERATION','code'=>'7'),
			'RW'=>array('name'=>'RWANDA','code'=>'250'),
			'SA'=>array('name'=>'SAUDI ARABIA','code'=>'966'),
			'SB'=>array('name'=>'SOLOMON ISLANDS','code'=>'677'),
			'SC'=>array('name'=>'SEYCHELLES','code'=>'248'),
			'SD'=>array('name'=>'SUDAN','code'=>'249'),
			'SE'=>array('name'=>'SWEDEN','code'=>'46'),
			'SG'=>array('name'=>'SINGAPORE','code'=>'65'),
			'SH'=>array('name'=>'SAINT HELENA','code'=>'290'),
			'SI'=>array('name'=>'SLOVENIA','code'=>'386'),
			'SK'=>array('name'=>'SLOVAKIA','code'=>'421'),
			'SL'=>array('name'=>'SIERRA LEONE','code'=>'232'),
			'SM'=>array('name'=>'SAN MARINO','code'=>'378'),
			'SN'=>array('name'=>'SENEGAL','code'=>'221'),
			'SO'=>array('name'=>'SOMALIA','code'=>'252'),
			'SR'=>array('name'=>'SURINAME','code'=>'597'),
			'ST'=>array('name'=>'SAO TOME AND PRINCIPE','code'=>'239'),
			'SV'=>array('name'=>'EL SALVADOR','code'=>'503'),
			'SY'=>array('name'=>'SYRIAN ARAB REPUBLIC','code'=>'963'),
			'SZ'=>array('name'=>'SWAZILAND','code'=>'268'),
			'TC'=>array('name'=>'TURKS AND CAICOS ISLANDS','code'=>'1649'),
			'TD'=>array('name'=>'CHAD','code'=>'235'),
			'TG'=>array('name'=>'TOGO','code'=>'228'),
			'TH'=>array('name'=>'THAILAND','code'=>'66'),
			'TJ'=>array('name'=>'TAJIKISTAN','code'=>'992'),
			'TK'=>array('name'=>'TOKELAU','code'=>'690'),
			'TL'=>array('name'=>'TIMOR-LESTE','code'=>'670'),
			'TM'=>array('name'=>'TURKMENISTAN','code'=>'993'),
			'TN'=>array('name'=>'TUNISIA','code'=>'216'),
			'TO'=>array('name'=>'TONGA','code'=>'676'),
			'TR'=>array('name'=>'TURKEY','code'=>'90'),
			'TT'=>array('name'=>'TRINIDAD AND TOBAGO','code'=>'1868'),
			'TV'=>array('name'=>'TUVALU','code'=>'688'),
			'TW'=>array('name'=>'TAIWAN, PROVINCE OF CHINA','code'=>'886'),
			'TZ'=>array('name'=>'TANZANIA, UNITED REPUBLIC OF','code'=>'255'),
			'UA'=>array('name'=>'UKRAINE','code'=>'380'),
			'UG'=>array('name'=>'UGANDA','code'=>'256'),
			'US'=>array('name'=>'UNITED STATES','code'=>'1'),
			'UY'=>array('name'=>'URUGUAY','code'=>'598'),
			'UZ'=>array('name'=>'UZBEKISTAN','code'=>'998'),
			'VA'=>array('name'=>'HOLY SEE (VATICAN CITY STATE)','code'=>'39'),
			'VC'=>array('name'=>'SAINT VINCENT AND THE GRENADINES','code'=>'1784'),
			'VE'=>array('name'=>'VENEZUELA','code'=>'58'),
			'VG'=>array('name'=>'VIRGIN ISLANDS, BRITISH','code'=>'1284'),
			'VI'=>array('name'=>'VIRGIN ISLANDS, U.S.','code'=>'1340'),
			'VN'=>array('name'=>'VIET NAM','code'=>'84'),
			'VU'=>array('name'=>'VANUATU','code'=>'678'),
			'WF'=>array('name'=>'WALLIS AND FUTUNA','code'=>'681'),
			'WS'=>array('name'=>'SAMOA','code'=>'685'),
			'XK'=>array('name'=>'KOSOVO','code'=>'381'),
			'YE'=>array('name'=>'YEMEN','code'=>'967'),
			'YT'=>array('name'=>'MAYOTTE','code'=>'262'),
			'ZA'=>array('name'=>'SOUTH AFRICA','code'=>'27'),
			'ZM'=>array('name'=>'ZAMBIA','code'=>'260'),
			'ZW'=>array('name'=>'ZIMBABWE','code'=>'263')
		);	
		return $country_codes;
	}
	
	/**
	 * Get array for country code
	 *
	 * @return array
	 */
	public static function get_country_code_dropdown() {
		$countrycodes = array();
		
		$country_codes = self::get_country_codes();
		if(!empty($country_codes)) {
			foreach($country_codes as $key => $country) {
				$countryname = ucwords(strtolower($country["name"]));
				$code = $country['code'];
				
				$countrycodes['+'.$code] = $key.' - '.$countryname.' (+'.$code.')';
			}
		}
		
		return $countrycodes;
	}
	
	/**
	 * Get country code by country name
	 *
	 * @return array
	 */
	public static function get_country_code_by_country_name($getcountry = '') {
		$getcountry = strtolower($getcountry);
		
		$country_codes = self::get_country_codes();
		if(!empty($country_codes)) {
			foreach($country_codes as $key => $country) {
				$countryname = strtolower($country["name"]);
				if($getcountry == $countryname){
					$code = $country['code'];
					
					return '+'.$code;
				}
			}
		}
	}
	
	/**
	 * Sms template default fields
	 *
	 * @return array
	 */
	public static function sms_template_default_fields( ) {
		$default_templates = [];
		
		$default_templates['new_appointment_to_customer'] = esc_html__( 'New appointment made at %SITETITLE%. Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		$default_templates['new_appointment_to_member'] = esc_html__( 'New appointment made at %SITETITLE%. Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		$default_templates['new_appointment_to_admin'] = esc_html__( 'New appointment made at %SITETITLE%. Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		
		$default_templates['reminder_repeatpayment_to_customer'] = esc_html__( 'Repeat payment reminder at %SITETITLE%. Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		
		$default_templates['received_repeatpayment_to_customer'] = esc_html__( 'Received repeat payment at %SITETITLE%. Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		$default_templates['received_repeatpayment_to_admin'] = esc_html__( 'Received repeat payment at %SITETITLE%. Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		
		$default_templates['received_fullpayment_to_customer'] = esc_html__( 'Received full payment at %SITETITLE%. Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		$default_templates['received_fullpayment_to_admin'] = esc_html__( 'Received full payment at %SITETITLE%. Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		
		$default_templates['service_reschedule_to_customer'] = esc_html__( 'Service rescheduled at %SITETITLE%. Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		$default_templates['service_reschedule_to_member'] = esc_html__( 'Service rescheduled at %SITETITLE%. Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		$default_templates['service_reschedule_to_admin'] = esc_html__( 'Service rescheduled at %SITETITLE%. Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		
		$default_templates['service_complete_to_customer'] = esc_html__( 'Service completed at %SITETITLE%. Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		$default_templates['service_complete_to_member'] = esc_html__( 'Service completed at %SITETITLE%. Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		$default_templates['service_complete_to_admin'] = esc_html__( 'Service completed at %SITETITLE%. Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		
		$default_templates['service_cancel_to_customer'] = esc_html__( 'Service cancelled at %SITETITLE%. Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		$default_templates['service_cancel_to_member'] = esc_html__( 'Service cancelled at %SITETITLE%. Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		$default_templates['service_cancel_to_admin'] = esc_html__( 'Service cancelled at %SITETITLE%. Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		
		$default_templates['update_service_staff_to_customer'] = esc_html__( 'Update service staff at %SITETITLE%. Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		$default_templates['update_service_staff_to_member'] = esc_html__( 'Update service staff at %SITETITLE%. Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		$default_templates['update_service_staff_to_admin'] = esc_html__( 'Update service staff at %SITETITLE%. Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		
		$default_templates['invoice_generate_to_customer'] = esc_html__( 'New invoice generated from %SITETITLE%. Invoice Id is: %INVOICEID%.', 'appointy' );
		$default_templates['invoice_generate_to_member'] = esc_html__( 'New invoice generated from %SITETITLE%. Invoice Id is: %INVOICEID%.', 'appointy' );
		$default_templates['invoice_generate_to_admin'] = esc_html__( 'New invoice generated from %SITETITLE%. Invoice Id is: %INVOICEID%.', 'appointy' );
		
		$default_templates['invoice_paid_to_customer'] = esc_html__( 'You successfully paid invoice to %SITETITLE%. Invoice Id is: %INVOICEID%.', 'appointy' );
		$default_templates['invoice_paid_to_member'] = esc_html__( 'You successfully paid invoice to %SITETITLE%. Invoice Id is: %INVOICEID%.', 'appointy' );
		$default_templates['invoice_paid_to_admin'] = esc_html__( 'You successfully paid invoice to %SITETITLE%. Invoice Id is: %INVOICEID%.', 'appointy' );
		
		$default_templates['add_feedback_to_customer'] = esc_html__( 'Feedback added at %SITETITLE%. . Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		$default_templates['add_feedback_to_member'] = esc_html__( 'Feedback added at %SITETITLE%. . Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		$default_templates['add_feedback_to_admin'] = esc_html__( 'Feedback added at %SITETITLE%. . Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		
		$default_templates['update_feedback_to_customer'] = esc_html__( 'Feedback updated at %SITETITLE%. . Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		$default_templates['update_feedback_to_member'] = esc_html__( 'Feedback updated at %SITETITLE%. . Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		$default_templates['update_feedback_to_admin'] = esc_html__( 'Feedback updated at %SITETITLE%. . Appointment ID is: %APPOINTMENT_ID%.', 'appointy' );
		
		$default_templates = apply_filters( 'appointy_default_sms_templates', $default_templates );
		
		return $default_templates;	
	}
	
	/**
	 * Get sms templates
	 *
	 * @return array
	 */
	public static function get_sms_templates( ) {
		global $wpdb;
		
		$sms_templates = self::sms_template_fields();
		
		if ( ! empty( $sms_templates ) ) {
			foreach ( $sms_templates as $key => $sms_template ) {
				
				$nestedData['templatename'] = self::get_sms_section_label($key);
				
				$params['section'] = $key;
				$managecolom_url = Appointy_Router_Helper::generate_link( ['sms_templates', 'form'],$params );
				
				$managecolom = '<a href="'.esc_url( $managecolom_url ).'" class="site-button-outline button-sm">'.esc_html__( 'Manage','appointy' ).'</a>';
				
				$nestedData['manage'] = $managecolom;
				
				$data[] = $nestedData;
				
			}
		}
		
		$json_data = array( 'data' => $data );
		
		echo json_encode( $json_data );
		die();
	}
	
	/**
	 * Sms template fields
	 *
	 * @return array
	 */
	public static function sms_template_fields( ) {
		
		$fields = apply_filters( 'appointy_sms_template_form_fields', array(
			'new_appointment' => array(
				'new_appointment_to_customer' => array(
					'label'       => esc_html__( 'Description (Customer)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICES%, %APPOINTMENT_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %APPOINTMENT_AMOUNT%, %PAYMENT_METHOD%, %PAYMENT_STATUS%, %SITETITLE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 1
				),
				'new_appointment_to_member' => array(
					'label'       => esc_html__( 'Description (Member)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICES%, %APPOINTMENT_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %APPOINTMENT_AMOUNT%, %PAYMENT_METHOD%, %PAYMENT_STATUS%, %SITETITLE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 1
				),
				'new_appointment_to_admin' => array(
					'label'       => esc_html__( 'Description (Admin)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICES%, %APPOINTMENT_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %APPOINTMENT_AMOUNT%, %PAYMENT_METHOD%, %PAYMENT_STATUS%, %SITETITLE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 1
				)
			),
			'reminder_repeatpayment' => array(
				'reminder_repeatpayment_to_customer' => array(
					'label'       => esc_html__( 'Description (Customer)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %TAX_AMOUNT%, %TOTAL_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%, %PAYMENTLINK%',
					'priority'    => 1
				)
			),
			'received_repeatpayment' => array(
				'received_repeatpayment_to_customer' => array(
					'label'       => esc_html__( 'Description (Customer)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %TAX_AMOUNT%, %TOTAL_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 1
				),
				'received_repeatpayment_to_admin' => array(
					'label'       => esc_html__( 'Description (Admin)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %TAX_AMOUNT%, %TOTAL_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 2
				)
			),
			'received_fullpayment' => array(
				'received_fullpayment_to_customer' => array(
					'label'       => esc_html__( 'Description (Customer)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %ADDRESS%, %DUEAMOUNT%, %DEPOSITAMOUNT%, %TOTALAMOUNT%',
					'priority'    => 1
				),
				'received_fullpayment_to_admin' => array(
					'label'       => esc_html__( 'Description (Admin)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %ADDRESS%, %DUEAMOUNT%, %DEPOSITAMOUNT%, %TOTALAMOUNT%',
					'priority'    => 2
				)
			),
			'service_reschedule' => array(
				'service_reschedule_to_customer' => array(
					'label'       => esc_html__( 'Description (Customer)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 1
				),
				'service_reschedule_to_member' => array(
					'label'       => esc_html__( 'Description (Member)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 3
				),
				'service_reschedule_to_admin' => array(
					'label'       => esc_html__( 'Description (Admin)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 1
				)
			),
			'service_complete' => array(
				'service_complete_to_customer' => array(
					'label'       => esc_html__( 'Description (Customer)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 1
				),
				'service_complete_to_member' => array(
					'label'       => esc_html__( 'Description (Member)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 1
				),
				'service_complete_to_admin' => array(
					'label'       => esc_html__( 'Description (Admin)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 1
				)
			),
			'service_cancel' => array(
				'service_cancel_to_customer' => array(
					'label'       => esc_html__( 'Description (Customer)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 1
				),
				'service_cancel_to_member' => array(
					'label'       => esc_html__( 'Description (Member)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 1
				),
				'service_cancel_to_admin' => array(
					'label'       => esc_html__( 'Description (Admin)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 1
				)
			),
			'update_service_staff' => array(
				'update_service_staff_to_customer' => array(
					'label'       => esc_html__( 'Description (Customer)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 1
				),
				'update_service_staff_to_member' => array(
					'label'       => esc_html__( 'Description (Member)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 1
				),
				'update_service_staff_to_admin' => array(
					'label'       => esc_html__( 'Description (Admin)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 1
				)
			),
			'invoice_generate' => array(
				'invoice_generate_to_customer' => array(
					'label'       => esc_html__( 'Description (Customer)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %INVOICEID%, %DUEDATE%, %STATUS%, %INVOICE_ITEMS%, %TAX_INFO%, %TAX_AMOUNT%, %DISCOUNT_INFO%, %DISCOUNT_AMOUNT%, %SUBTOTAL%, %GRAND_TOTAL%, %PAYNOW_LINK%',
					'priority'    => 1
				),
				'invoice_generate_to_member' => array(
					'label'       => esc_html__( 'Description (Member)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %INVOICEID%, %DUEDATE%, %STATUS%, %INVOICE_ITEMS%, %TAX_INFO%, %TAX_AMOUNT%, %DISCOUNT_INFO%, %DISCOUNT_AMOUNT%, %SUBTOTAL%, %GRAND_TOTAL%, %PAYNOW_LINK%',
					'priority'    => 1
				),
				'invoice_generate_to_admin' => array(
					'label'       => esc_html__( 'Description (Admin)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %INVOICEID%, %DUEDATE%, %STATUS%, %INVOICE_ITEMS%, %TAX_INFO%, %TAX_AMOUNT%, %DISCOUNT_INFO%, %DISCOUNT_AMOUNT%, %SUBTOTAL%, %GRAND_TOTAL%, %PAYNOW_LINK%',
					'priority'    => 1
				)
			),
			'invoice_paid' => array(
				'invoice_paid_to_customer' => array(
					'label'       => esc_html__( 'Description (Customer)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %INVOICEID%, %DUEDATE%, %STATUS%, %INVOICE_ITEMS%, %TAX_INFO%, %TAX_AMOUNT%, %DISCOUNT_INFO%, %DISCOUNT_AMOUNT%, %SUBTOTAL%, %GRAND_TOTAL%, %PAYNOW_LINK%',
					'priority'    => 2
				),
				'invoice_paid_to_member' => array(
					'label'       => esc_html__( 'Description (Member)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %INVOICEID%, %DUEDATE%, %STATUS%, %INVOICE_ITEMS%, %TAX_INFO%, %TAX_AMOUNT%, %DISCOUNT_INFO%, %DISCOUNT_AMOUNT%, %SUBTOTAL%, %GRAND_TOTAL%, %PAYNOW_LINK%',
					'priority'    => 2
				),
				'invoice_paid_to_admin' => array(
					'label'       => esc_html__( 'Description (Admin)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %INVOICEID%, %DUEDATE%, %STATUS%, %INVOICE_ITEMS%, %TAX_INFO%, %TAX_AMOUNT%, %DISCOUNT_INFO%, %DISCOUNT_AMOUNT%, %SUBTOTAL%, %GRAND_TOTAL%, %PAYNOW_LINK%',
					'priority'    => 2
				)
			),
			'add_feedback' => array(
				'add_feedback_to_customer' => array(
					'label'       => esc_html__( 'Description (Customer)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 2
				),
				'add_feedback_to_member' => array(
					'label'       => esc_html__( 'Description (Member)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 2
				),
				'add_feedback_to_admin' => array(
					'label'       => esc_html__( 'Description (Admin)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 2
				)
			),
			'update_feedback' => array(
				'update_feedback_to_customer' => array(
					'label'       => esc_html__( 'Description (Customer)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 2
				),
				'update_feedback_to_member' => array(
					'label'       => esc_html__( 'Description (Member)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 2
				),
				'update_feedback_to_admin' => array(
					'label'       => esc_html__( 'Description (Admin)', 'appointy' ),
					'type'        => 'textarea',
					'colum-width' => 'col-lg-12',
					'description' => '%SITETITLE%, %APPOINTMENT_ID%, %SERVICE_NAME%, %SERVICE_DATE%, %SERVICE_TIME%, %SERVICE_DURATION%, %MEMBER_NAME%, %BRANCH_ADDRESS%, %SERVICE_AMOUNT%, %SERVICE_STATUS%, %CUSTOMER_NAME%, %CUSTOMER_EMAIL%, %CUSTOMER_PHONE%, %SERVICELOCATION%, %ADDRESS%',
					'priority'    => 2
				)
			),
		) );
		
		return Appointy_Form_Helper::get_fields( $fields );	
	}
	
	/**
	 * Sms template fields label
	 *
	 * @return array
	 */
	public static function sms_template_fields_label( ) {
		
		$fields = apply_filters( 'appointy_sms_template_form_fields_label', array(
			'new_appointment' => esc_html__( 'New appointment', 'appointy' ),
			'reminder_repeatpayment' => esc_html__( 'Repeat payment reminder', 'appointy' ),
			'received_repeatpayment' => esc_html__( 'Received repeat payment', 'appointy' ),
			'received_fullpayment' => esc_html__( 'Received full payment', 'appointy' ),
			'service_reschedule' => esc_html__( 'Service reschedule', 'appointy' ),
			'service_complete' => esc_html__( 'Service completed', 'appointy' ),
			'service_cancel' => esc_html__( 'Service cancelled', 'appointy' ),
			'update_service_staff' => esc_html__( 'Update service staff', 'appointy' ),
			'invoice_generate' => esc_html__( 'Invoice generate', 'appointy' ),
			'invoice_paid' => esc_html__( 'Invoice paid', 'appointy' ),
			'add_feedback' => esc_html__( 'Add Feedback', 'appointy' ),
			'update_feedback' => esc_html__( 'Update Feedback', 'appointy' ),
		) );
		
		return Appointy_Form_Helper::get_fields( $fields );	
	}
	
	/**
	 * Get sms section label
	 *
	 * @return array
	 */
	public static function get_sms_section_label($key = '') {
		
		$template_label = self::sms_template_fields_label();
		return Appointy_Router_Helper::get_sanitize_data( $template_label, $key );
	}
	
	/**
	 * Save sms templates
	 *
	 * @return array
	 */
	public static function save_sms_templates( ) {
		global $wpdb;
		
		$sms_template_key = Appointy_Router_Helper::get_sanitize_data( $_POST, 'sms_template_key' );
		
		$sms_fields = self::sms_template_fields();
		
		$sms_fields = ( !empty($sms_fields[$sms_template_key]) ) ? (array) $sms_fields[$sms_template_key] : array();
		
		$sms_templates = get_option( 'appointy_sms_templates' );
		
		if( !empty( $sms_fields ) ) {
			foreach( $sms_fields as $key => $field ){
				$sms_templates[$sms_template_key][$key] = Appointy_Router_Helper::get_sanitize_data( $_POST, $key );
			}
		}
		
		update_option( 'appointy_sms_templates', $sms_templates );
			
		$redirecturl = add_query_arg( array( 'page' => 'appointment','menu_item' => 'sms_templates__index' ), admin_url( 'admin.php' ) );
		
		$response = array( 'msg' => esc_html__('Sms template saved successfully.', 'appointy'), 'redirect' => $redirecturl );
		wp_send_json_success($response);
		die();
	}
}
new Appointy_Sms_Helper();