<?php 
class Appointy_Tax_Helper {

	/**
     * Initialize the class
     *
     * @since     1.0.0
     */
    public function __construct() {
		add_action('wp_ajax_appointy_get_taxes', array($this, 'get_taxes'));
		add_action('wp_ajax_appointy_save_tax', array($this, 'save_tax'));
		add_action('wp_ajax_appointy_load_tax', array($this, 'load_tax'));
		add_action('wp_ajax_appointy_delete_tax', array($this, 'delete_tax'));
		
    }
	
	/**
	 * Get tax
	 *
	 * @return void
	 */
	public static function get_taxes() {
	    global $wpdb;
		
		$id = 0;
		$results = $wpdb->get_results($wpdb->prepare('SELECT `id`,`tax_name`,`tax`,`tax_type`,`status` FROM `'.$wpdb->prefix.'appointy_taxes` WHERE `id` > %d ',$id));
		
		$data = array();
		if ( !empty($results) ) {
			$nestedData = array();
			foreach( $results as $row ){
				$taxid = Appointy_Router_Helper::get_request_data( $row, 'id' );
				$nestedData['delete'] = '<div class="checkbox sf-radio-checkbox">
											<input type="checkbox" id="tax-'.esc_attr($taxid).'" value="'.esc_attr($taxid).'" class="delete_row delete_tax">
											<label for="tax-'.esc_attr($taxid).'"></label>
										</div>';
				$nestedData['taxname'] =  Appointy_Router_Helper::get_request_data( $row, 'tax_name' );
				$nestedData['amount'] =  self::get_tax_amount( Appointy_Router_Helper::get_request_data( $row, 'tax' ), Appointy_Router_Helper::get_request_data( $row, 'tax_type' ) );
				
				$status = Appointy_Router_Helper::get_request_data( $row, 'status' );
				
				if( $status === 'yes' ) {
					$display_status = '<button type="button" class="btn btn-xs btn-light-danger">'.esc_html__('Enabled', 'appointy').'</button>';
				} else{
					$display_status = '<button type="button" class="btn btn-xs btn-light-warning">'.esc_html__('Disabled', 'appointy').'</button>';
				}
				
				$nestedData['status'] =  $display_status;
				
				$actions = '<div class="dropdown action-dropdown dropdown-left">
							  <button class="action-button btn btn-primary dropdown-toggle" type="button" data-bs-toggle="dropdown"><i class="fa fa-ellipsis-v"></i></button>
							  <ul class="dropdown-menu">
								<li><a href="javascript:;" class="dropdown-item edittax" data-taxid="'.esc_attr($taxid).'"><i class="fa fa-pencil"></i> '.esc_html__( 'Edit','appointy' ).'</a></li>
							  </ul>
							</div>';
				
				$nestedData['action'] = $actions;
				
				$data[] = $nestedData;
				
			}
		}
		
		$json_data = array( 'data' => $data );
		
		echo json_encode( $json_data );
		die();
	}
	
	/**
     * get tax amount
     *
     * @since    1.0.0
     */
    public static function get_tax_amount( $amount = 0, $tax_type = '' ) {
		if($tax_type === 'percent'){
			$taxamount = $amount.'%';	
		}elseif($tax_type === 'fixed'){
			$taxamount = Appointy_Misc_Helper::get_price_format($amount);
		}
		
		return $taxamount;
	}
	
	/**
     * Save tax
     *
     * @since    1.0.0
     */
    public function save_tax() {
		global $wpdb;
		
        if( ! wp_verify_nonce( $_POST['_nonce'], 'appointy_ajax_nonce' ) || !current_user_can('manage_options') ) {
			wp_send_json_error();
			die();
		}
		
		$taxid = Appointy_Router_Helper::get_sanitize_data( $_POST, 'taxid' );
		
		$services = (!empty($_POST['services'])) ? $_POST['services'] : array();
		
		$services = (!empty($services)) ? implode(',',$services) : '';
		
		if( !empty( $taxid ) ) {
			$data['tax_name'] 	= Appointy_Router_Helper::get_sanitize_data( $_POST, 'taxname' );
			$data['tax'] 		= Appointy_Router_Helper::get_sanitize_data( $_POST, 'tax' );
			$data['tax_type'] 	= Appointy_Router_Helper::get_sanitize_data( $_POST, 'tax_type' );
			$data['services'] 	= $services;
			$data['status'] 	= Appointy_Router_Helper::get_sanitize_data( $_POST, 'status', 'no' );
			
			$where = array(
				'id' => $taxid
			);
			
			$result = $wpdb->update($wpdb->prefix.'appointy_taxes',wp_unslash($data),$where);		

		} else {
			$data['tax_name'] 	= Appointy_Router_Helper::get_sanitize_data( $_POST, 'taxname' );
			$data['tax'] 		= Appointy_Router_Helper::get_sanitize_data( $_POST, 'tax' );
			$data['tax_type'] 	= Appointy_Router_Helper::get_sanitize_data( $_POST, 'tax_type' );
			$data['services'] 	= $services;
			$data['status'] 	= Appointy_Router_Helper::get_sanitize_data( $_POST, 'status', 'no' );
			
			$result = $wpdb->insert($wpdb->prefix.'appointy_taxes',wp_unslash($data));
		}
		
		
		
		if ( (bool) $result === false ){
			$response = array('msg' => $wpdb->print_error());
			wp_send_json_error($response);
	    } else {
			$response = array( 'msg' => esc_html__('Tax saved.', 'appointy') );
			wp_send_json_success($response);
	    }
   		die();
    }
	
	/**
	 * Delete tax
	 *
	 * @return array
	 */
	public static function delete_tax() {
		global $wpdb;
		
		$data_ids = Appointy_Router_Helper::get_request_data( $_POST, 'data_ids' );
		
		$data_id_array = explode(",", $data_ids); 

		if(!empty($data_id_array)) {
			foreach($data_id_array as $taxid) {
				$wpdb->query($wpdb->prepare('DELETE FROM `'.$wpdb->prefix.'appointy_taxes` WHERE `id` = %d',$taxid));
			}
		}
		
		wp_send_json_success();
		die();
	}
	
	/**
	 * Process load tax
	 *
	 * @return array
	 */
	public static function load_tax( ) {
		global $wpdb;
		
		$taxid = Appointy_Router_Helper::get_request_data( $_POST, 'taxid' );
		
		$row = $wpdb->get_row($wpdb->prepare('SELECT `tax_name`,`tax`,`tax_type`,`services`,`status` FROM `'.$wpdb->prefix.'appointy_taxes` WHERE `id` = %d ',$taxid));
		
		$data = array();
		
		$services = Appointy_Router_Helper::get_request_data( $row, 'services' );
					
		if(!empty($services)) {
			$services = explode(',',$services);
			$services = json_encode($services);
		}else{
			$services = array();
			$services = json_encode($services);
		}
		
		$data['tax_name'] 	= Appointy_Router_Helper::get_request_data( $row, 'tax_name' );
		$data['tax'] 		= Appointy_Router_Helper::get_request_data( $row, 'tax' );
		$data['tax_type'] 	= Appointy_Router_Helper::get_request_data( $row, 'tax_type' );
		$data['services'] 	= $services;
		$data['status'] 	= Appointy_Router_Helper::get_request_data( $row, 'status' );
		
		$response = $data;
		
		wp_send_json_success($response);
		
   		die();
	}
	
	public static function tax_fields( $post_id = 0 ) {
	
		$fields = apply_filters( 'appointy_tax_form_fields', array(
			'taxname' => array(
				'label'       => esc_html__( 'Name', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-tag',
				'colum-width' => 'col-lg-12',
				'required'    => true,
				'placeholder' => '',
				'priority'    => 1
			),
			'tax' => array(
				'label'       => esc_html__( 'Amount', 'appointy' ),
				'type'        => 'text',
				'icon'        => 'fa fa-tag',
				'colum-width' => 'col-lg-6',
				'required'    => true,
				'placeholder' => '',
				'priority'    => 2
			),
			'tax_type' => array(
				'label'       => esc_html__( 'Tax Type', 'appointy' ),
				'type'        => 'select',
				'icon'        => 'fa fa-globe',
				'colum-width' => 'col-lg-6',
				'required'    => true,
				'placeholder' => '',
				'priority'    => 3,
				'options' 	  => array('percent' => '%','fixed' => '$')
			),
			/*'services' => array(
				'label'       => esc_html__( 'Services', 'appointy' ),
				'type'        => 'multi-select',
				'default'     => '',
				'icon'        => 'fa fa-map-marker',
				'colum-width' => 'col-lg-6',
				'required'    => false,
				'placeholder' => esc_html__( 'Select service', 'appointy' ),
				'priority'    => 4,
				'options' 	  => Appointy_Service_Helper::get_service_array()
			),*/
			'status' => array(
				'label'       => esc_html__( 'Status', 'appointy' ),
				'type'        => 'checkbox',
				'colum-width' => 'col-lg-12',
				'required'    => false,
				'options'    => ['yes' => esc_html__( 'Enabled', 'appointy' )],
				'priority'    => 5
			),
		) );

		return Appointy_Form_Helper::get_fields( $fields );	
	}
	
	/**
     * Get all taxes
     *
     * @since    1.0.0
     */
    public static function get_all_taxes() {
		global $wpdb;
		
		$id = 0;
		$results = $wpdb->get_results($wpdb->prepare('SELECT `tax_name`,`tax`,`tax_type`,`services` FROM `'.$wpdb->prefix.'appointy_taxes` WHERE `id` > %d AND `status` = "yes"',$id));
		$taxes = array();
		if ( !empty($results) ) {
			$nesteddata = array();
			foreach( $results as $row ){
				
				$nesteddata['tax_name'] 	= Appointy_Router_Helper::get_request_data( $row, 'tax_name' );
				$nesteddata['tax'] 		= Appointy_Router_Helper::get_request_data( $row, 'tax' );
				$nesteddata['tax_type'] 	= Appointy_Router_Helper::get_request_data( $row, 'tax_type' );
				$nesteddata['services'] 	= Appointy_Router_Helper::get_request_data( $row, 'services' );
				
				$taxes[] = $nesteddata;
			}
		}	
		
		return $taxes;
    }
	
}
new Appointy_Tax_Helper();