<?php
/**
 * WordPress Settings Framework
 *
 * @link https://github.com/gilbitron/WordPress-Settings-Framework
 * @package wpsf
 */

/**
 * Define your settings
 *
 * The first parameter of this filter should be wpsf_register_settings_[options_group],
 * in this case "my_example_settings".
 *
 * Your "options_group" is the second param you use when running new WordPressSettingsFramework()
 * from your init function. It's important as it differentiates your options from others.
 *
 * To use the tabbed example, simply change the second param in the filter below to 'wpsf_tabbed_settings'
 * and check out the tabbed settings function on line 156.
 */

add_filter( 'wpsf_register_settings_appointy', 'appointy_tabbed_settings' );

/**
 * Tabbed settings.
 *
 * @param array $wpsf_settings settings.
 */
function appointy_tabbed_settings( $wpsf_settings ) {
	// Tabs.
	$wpsf_settings['tabs'] = array(
		array(
			'id'    => 'general_settings',
			'title' => esc_html__( 'General Settings', 'appointy' ),
		),
		array(
			'id'    => 'color_settings',
			'title' => esc_html__( 'Color Settings', 'appointy' ),
		),
		array(
			'id'    => 'invoice_settings',
			'title' => esc_html__( 'Invoice Settings', 'appointy' ),
		),
		array(
			'id'    => 'giftcard_settings',
			'title' => esc_html__( 'Giftcard Settings', 'appointy' ),
		),
		array(
			'id'    => 'google_calendar_settings',
			'title' => esc_html__( 'Google Calendar', 'appointy' ),
		),
		array(
			'id'    => 'google_map_api',
			'title' => esc_html__( 'Google Map API', 'appointy' ),
		),
		array(
			'id'    => 'sms_settings',
			'title' => esc_html__( 'SMS/WhatsApp Settings', 'appointy' ),
		),
		array(
			'id'    => 'woocommrce_payment_settings',
			'title' => esc_html__( 'Woocommerce Payment Gateway', 'appointy' ),
		),
		array(
			'id'    => 'booking_settings',
			'title' => esc_html__( 'Booking Settings', 'appointy' ),
		)
	);
	
	$wooproducts = array();

	if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
		$products = get_posts( array( 'post_status' => 'publish','post_type'   => 'product') );
		if( !empty($products) ) {
			foreach ($products as $product) {
				$wooproducts[$product->ID] = $product->post_title;
			}
		} else {
			$wooproducts[''] = esc_html__( 'No Products Found', 'appointy' );
		}
	} else {
		$wooproducts[''] = esc_html__( 'No Products Found', 'appointy' );
	}
	
	$sitepages = array();
		
	$pages = get_pages();

	if ( is_admin() && !empty($pages) ) {
		$sitepages[0] = esc_html__( 'Default Page', 'appointy' );
		foreach ($pages as $page) {
			$sitepages[$page->ID] = $page->post_title;
		}
	}

	// Settings.
	$wpsf_settings['sections'] = array(
		array(
			'tab_id'        => 'general_settings',
			'section_id'    => 'section',
			'section_title' => esc_html__( 'General Settings', 'appointy' ),
			'section_order' => 1,
			'fields'        => array(
				array(
					'id'      => 'dashboard_logo',
					'title'   => esc_html__( 'Dashboard Logo', 'appointy' ),
					'type'    => 'file'
				),
				array(
					'id'      => 'dashboard_logo_icon',
					'title'   => esc_html__( 'Dashboard Logo Icon', 'appointy' ),
					'type'    => 'file'
				),
				array(
					'id'      => 'email_logo',
					'title'   => esc_html__( 'Email Logo', 'appointy' ),
					'type'    => 'file'
				),
				array(
					'id'       => 'default_country',
					'title'    => esc_html__( 'Default Country', 'appointy' ),
					'type'     => 'select',
					'choices'  => appointy_get_countries()
				),
				array(
					'id'       => 'default_state',
					'title'    => esc_html__( 'Default State', 'appointy' ),
					'type'     => 'select',
					'choices'  => appointy_get_states()
				),
				array(
					'id'      => 'avl_interval_start_time',
					'title'   => esc_html__( 'Availability Interval Start Time (In Minutes)', 'appointy' ),
					'type'    => 'number',
					'default' => '15'
				),
				array(
					'id'      => 'avl_interval_end_time',
					'title'   => esc_html__( 'Availability Interval End Time (In Minutes)', 'appointy' ),
					'type'    => 'number',
					'default' => '240'
				),
				array(
					'id'      => 'avl_interval_period',
					'title'   => esc_html__( 'Availability Interval Period (In Minutes)', 'appointy' ),
					'type'    => 'number',
					'default' => '15'
				)
			)
		),
		array(
			'tab_id'        => 'color_settings',
			'section_id'    => 'section',
			'section_title' => esc_html__( 'Color Settings', 'appointy' ),
			'section_order' => 1,
			'fields'        => array(
				array(
					'id'      => 'primary_color',
					'title'   => esc_html__( 'Primary Color', 'appointy' ),
					'desc'    => esc_html__( 'Set primary color', 'appointy' ),
					'type'    => 'color',
					'default' => '#6139b3'
				),
				array(
					'id'      => 'secondary_color',
					'title'   => esc_html__( 'Secondary Color', 'appointy' ),
					'desc'    => esc_html__( 'Set secondary color', 'appointy' ),
					'type'    => 'color',
					'default' => '#ff8a00'
				),
				array(
					'id'      => 'custom_color1',
					'title'   => esc_html__( 'Notification Panel Color', 'appointy' ),
					'desc'    => esc_html__( 'Set notification panel color', 'appointy' ),
					'type'    => 'color',
					'default' => '#f0eef9'
				),
				array(
					'id'      => 'custom_color2',
					'title'   => esc_html__( 'Body Background Color', 'appointy' ),
					'desc'    => esc_html__( 'Set body background color', 'appointy' ),
					'type'    => 'color',
					'default' => '#f8f9fb'
				),
				array(
					'id'      => 'btn_primary_color',
					'title'   => esc_html__( 'Buttom Primary Color', 'appointy' ),
					'desc'    => esc_html__( 'Set button primary color', 'appointy' ),
					'type'    => 'color',
					'default' => '#ff8a00'
				),
				array(
					'id'      => 'btn_primary_color_hover',
					'title'   => esc_html__( 'Buttom Primary Color Hover', 'appointy' ),
					'desc'    => esc_html__( 'Set button primary hover color', 'appointy' ),
					'type'    => 'color',
					'default' => '#6139b3'
				),
				array(
					'id'      => 'btn_seconday_color',
					'title'   => esc_html__( 'Buttom Secondary Color', 'appointy' ),
					'desc'    => esc_html__( 'Set button secondary color', 'appointy' ),
					'type'    => 'color',
					'default' => '#6139b3'
				),
				array(
					'id'      => 'btn_seconday_color_hover',
					'title'   => esc_html__( 'Buttom Secondary Color Hover', 'appointy' ),
					'desc'    => esc_html__( 'Set button secondary color hover', 'appointy' ),
					'type'    => 'color',
					'default' => '#ff8a00'
				),
			)
		),
		array(
			'tab_id'        => 'invoice_settings',
			'section_id'    => 'section',
			'section_title' => esc_html__( 'Invoice Settings', 'appointy' ),
			'section_order' => 1,
			'fields'        => array(
				array(
					'id'      => 'invoice_from_name',
					'title'   => esc_html__( 'From Name', 'appointy' ),
					'type'    => 'text',
					'default' => ''
				),
				array(
					'id'      => 'invoice_from_email',
					'title'   => esc_html__( 'From Email', 'appointy' ),
					'type'    => 'text',
					'default' => ''
				),
				array(
					'id'      => 'invoice_from_phone',
					'title'   => esc_html__( 'From Phone', 'appointy' ),
					'type'    => 'text',
					'default' => ''
				),
				array(
					'id'      => 'invoice_from_address',
					'title'   => esc_html__( 'From Address', 'appointy' ),
					'type'    => 'text',
					'default' => ''
				),
				array(
					'id'      => 'invoice_extra_details',
					'title'   => esc_html__( 'Extra Details', 'appointy' ),
					'type'    => 'text',
					'default' => ''
				),
				array(
					'id'      => 'invoice_footer_lefttext',
					'title'   => esc_html__( 'Invoice Footer Left Text', 'appointy' ),
					'type'    => 'text',
					'default' => esc_html__( 'Thanks for Your Business','appointy' )
				),
				array(
					'id'      => 'invoice_footer_righttext',
					'title'   => esc_html__( 'Invoice Footer Right Text', 'appointy' ),
					'type'    => 'text',
					'default' => sprintf(esc_html__( '&copy; %s Appointy. All Rights Reserved','appointy' ),date('Y'))
				)
			)
		),
		array(
			'tab_id'        => 'giftcard_settings',
			'section_id'    => 'section',
			'section_title' => esc_html__( 'Giftcard Settings', 'appointy' ),
			'section_order' => 1,
			'fields'        => array(
				array(
					'id'      => 'giftcard_top_area',
					'title'   => esc_html__( 'Giftcard Top Area Text', 'appointy' ),
					'type'    => 'text',
					'default' => ''
				),
				array(
					'id'      => 'giftcard_bottom_area',
					'title'   => esc_html__( 'Giftcard Bottom Area Text', 'appointy' ),
					'type'    => 'text',
					'default' => ''
				)
			)
		),
		array(
			'tab_id'        => 'google_calendar_settings',
			'section_id'    => 'section',
			'section_title' => esc_html__( 'Google Calendar Settings', 'appointy' ),
			'section_order' => 1,
			'fields'        => array(
				array(
					'id'      => 'google_calendar_client_id',
					'title'   => esc_html__( 'Client ID', 'appointy' ),
					'type'    => 'text',
					'default' => ''
				),
				array(
					'id'      => 'google_calendar_client_secret',
					'title'   => esc_html__( 'Client secret', 'appointy' ),
					'type'    => 'text',
					'desc'    => esc_html__( 'Redirect URI:', 'appointy' ).' '.APPOINTY_GCAL_REDIRECT_URI,
					'default' => ''
				)
			)
		),
		array(
			'tab_id'        => 'google_map_api',
			'section_id'    => 'section',
			'section_title' => esc_html__( 'Google Map API', 'appointy' ),
			'section_order' => 1,
			'fields'        => array(
				array(
					'id'      => 'browser_api_key',
					'title'   => esc_html__( 'Browser API Key', 'appointy' ),
					'type'    => 'text'
				)
			)
		),
		array(
			'tab_id'        => 'sms_settings',
			'section_id'    => 'section',
			'section_title' => esc_html__( 'SMS/WhatsApp Gatway', 'appointy' ),
			'section_order' => 1,
			'fields'        => array(
				array(
					'id'      => 'twillio_sid',
					'title'   => esc_html__( 'Twillio SID', 'appointy' ),
					'type'    => 'text'
				),
				array(
					'id'      => 'twillio_token',
					'title'   => esc_html__( 'Twillio Token', 'appointy' ),
					'type'    => 'text'
				),
				array(
					'id'      => 'twillio_senderid',
					'title'   => esc_html__( 'Twillio Sender ID', 'appointy' ),
					'type'    => 'text'
				),
				array(
					'id'      => 'admin_phone_number',
					'title'   => esc_html__( 'Admin SMS/WhatsApp Number (With Country Code)', 'appointy' ),
					'type'    => 'text'
				)
			),
		),
		array(
			'tab_id'        => 'woocommrce_payment_settings',
			'section_id'    => 'section',
			'section_title' => esc_html__( 'Random Product Id', 'appointy' ),
			'section_order' => 1,
			'fields'        => array(
				array(
					'id'       => 'woo_product_id',
					'title'    => esc_html__( 'Woocommerce Product Id', 'appointy' ),
					'desc' 	   => esc_html__( 'Please create a random woocommerce product and select from Products dropdown here.', 'appointy' ),
					'type'     => 'select',
					'choices'  => $wooproducts
				)
			)
		),
		array(
			'tab_id'        => 'booking_settings',
			'section_id'    => 'section',
			'section_title' => esc_html__( 'Booking Settings', 'appointy' ),
			'section_order' => 1,
			'fields'        => array(
				array(
					'id'      => 'show_left_panel_logo',
					'title'   => esc_html__( 'Show Left Panel Logo', 'appointy' ),
					'type'    => 'toggle',
					'default' => true
				),
				array(
					'id'      => 'left_panel_logo',
					'title'   => esc_html__( 'Left Panel Logo', 'appointy' ),
					'type'    => 'file'
				),
				array(
					'id'      => 'left_panel_text',
					'title'   => esc_html__( 'Left Panel Text', 'appointy' ),
					'type'    => 'text',
					'default' => esc_html__( 'Cart is Empty','appointy' )
				),
				array(
					'id'      => 'booking_coupon_code',
					'title'   => esc_html__( 'Coupon Code for booking', 'appointy' ),
					'type'    => 'toggle',
					'default' => true
				),
				array(
					'id'      => 'coupon_code_for',
					'title'    => esc_html__( 'Coupon Code For', 'appointy' ),
					'type'    => 'radio',
					'default' => 'booking',
					'choices' => array(
						'booking' => esc_html__( 'Booking Price', 'appointy' ),
						'eachservice' => esc_html__( 'Service Price', 'appointy' ),
					)
				),
				array(
					'id'      => 'payment_mode',
					'title'    => esc_html__( 'Payment Mode', 'appointy' ),
					'type'    => 'radio',
					'default' => 'online',
					'choices' => array(
						'online' => esc_html__( 'Online Payment', 'appointy' ),
						'offline' => esc_html__( 'Offline Payment', 'appointy' ),
					)
				),
				array(
					'id'       => 'redirect_after_booking',
					'title'    => esc_html__( 'Redirect After Booking', 'appointy' ),
					'desc' 	   => esc_html__( 'Select page to redirect after booking.', 'appointy' ),
					'type'     => 'select',
					'choices'  => $sitepages
				),
				array(
					'id'       => 'redirect_after_giftcard_payment',
					'title'    => esc_html__( 'Redirect After Giftcard Payment', 'appointy' ),
					'desc' 	   => esc_html__( 'Select page to redirect after giftcard payment.', 'appointy' ),
					'type'     => 'select',
					'choices'  => $sitepages
				),
				array(
					'id'       => 'redirect_after_invoice_payment',
					'title'    => esc_html__( 'Redirect After Invoice Payment', 'appointy' ),
					'desc' 	   => esc_html__( 'Select page to redirect after invoice payment.', 'appointy' ),
					'type'     => 'select',
					'choices'  => $sitepages
				),
				array(
					'id'       => 'redirect_after_depositfullpayment_payment',
					'title'    => esc_html__( 'Redirect After Deposit Full Payment', 'appointy' ),
					'desc' 	   => esc_html__( 'Select page to redirect after deposit full payment.', 'appointy' ),
					'type'     => 'select',
					'choices'  => $sitepages
				),
				array(
					'id'      => 'booking_attachments',
					'title'   => esc_html__( 'Booking Attachments', 'appointy' ),
					'type'    => 'toggle',
					'default' => true
				),
				array(
					'id'      => 'upload_file_extensions',
					'title'   => esc_html__( 'Upload File Extensions', 'appointy' ),
					'type'    => 'text',
					'default' => 'jpg,jpeg,gif,png,doc,docx,pdf,xls,xlsx,txt,ppt,pptx'
				),
				array(
					'id'      => 'max_file_uploads',
					'title'   => esc_html__( 'Max File Uploads', 'appointy' ),
					'type'    => 'number',
					'default' => '5'
				),
				array(
					'id'      => 'deposit_options',
					'title'    => esc_html__( 'Deposit Options', 'appointy' ),
					'type'    => 'radio',
					'default' => 'full_payment',
					'choices' => array(
						'full_payment' => esc_html__( 'Full Payment', 'appointy' ),
						'deposit_only' => esc_html__( 'Deposit Only', 'appointy' ),
					)
				),
				array(
					'id'      => 'deposit_amount',
					'title'   => esc_html__( 'Deposit Amount/Percentage', 'appointy' ),
					'type'    => 'text'
				),
				array(
					'id'      => 'deposit_type',
					'title'    => esc_html__( 'Deposit Type', 'appointy' ),
					'type'    => 'radio',
					'choices' => array(
						'percent' => esc_html__( 'Percentage', 'appointy' ),
						'fixed' => esc_html__( 'Fixed', 'appointy' ),
					)
				),
			)
		),
		array(
			'tab_id'        => 'tab_2',
			'section_id'    => 'section_3',
			'section_title' => 'Section 3',
			'section_order' => 1,
			'fields'        => array(
				array(
					'id'      => 'text-3',
					'title'   => 'Text',
					'desc'    => 'This is a description.',
					'type'    => 'text',
					'default' => 'This is default',
				),
				array(
					'id'      => 'tab-control',
					'title'   => 'Will show Tab 3 if toggled',
					'type'    => 'toggle',
					'default' => false,
				),
			),
		),
		array(
			'tab_id'        => 'tab_3',
			'section_id'    => 'section_4',
			'section_title' => 'Section 4',
			'section_order' => 1,
			'fields'        => array(
				array(
					'id'      => 'text-4',
					'title'   => 'Text',
					'desc'    => 'This is a description.',
					'type'    => 'text',
					'default' => 'This is default',
				),
				array(
					'id'       => 'complex-group-1',
					'title'    => 'Complex Show Hide 1',
					'subtitle' => 'Multiple controls can show or hide fields',
					'type'     => 'select',
					'choices'  => array(
						'option-1' => 'Option 1',
						'option-2' => 'Option 2',
						'option-3' => 'Option 3',
					),
					'default'  => 'text',
				),
				array(
					'id'       => 'complex-group-2',
					'title'    => 'Complex Show Hide 2',
					'subtitle' => 'Multiple controls can show or hide fields',
					'type'     => 'toggle',
					'default'  => false,
				),
				array(
					'id'       => 'complex-group-3',
					'title'    => 'Complex Show Hide 3',
					'subtitle' => 'Multiple controls can show or hide fields',
					'type'     => 'toggle',
					'default'  => false,
				),
				array(
					'id'       => 'complex-group-show',
					'title'    => 'Complex Show Example',
					'subtitle' => 'Will show if Control 1 is Option 1 or Option 2 AND Control 2 is True, OR if Control 3 is true',
					'type'     => 'select',
					'type'     => 'text',
					'default'  => 'This is default',
					'show_if'  => array(
						// An array here is an AND group.
						array(
							// Show if Control 1 is Option 1 OR Option 2.
							array(
								'field' => 'tab_3_section_4_complex-group-1',
								'value' => array( 'option-1', 'option-2' ),
							),
							// AND Control 2 is True.
							array(
								'field' => 'tab_3_section_4_complex-group-2',
								'value' => array( '1' ),
							),
						),
						// OR show if Control 3 is True.
						array(
							'field' => 'tab_3_section_4_complex-group-3',
							'value' => array( '1' ),
						),
					),
				),
				array(
					'id'       => 'complex-group-hide',
					'title'    => 'Complex Hide Example',
					'subtitle' => 'Will hide if Control 1 is Option 1 or Option 2 AND Control 2 is True, OR if Control 3 is true',
					'type'     => 'select',
					'type'     => 'text',
					'default'  => 'This is default',
					'hide_if'  => array(
						// An array here is an AND group.
						array(
							// Hide if Control 1 is Option 1 OR Option 2.
							array(
								'field' => 'tab_3_section_4_complex-group-1',
								'value' => array( 'option-1', 'option-2' ),
							),
							// AND Control 2 is True.
							array(
								'field' => 'tab_3_section_4_complex-group-2',
								'value' => array( '1' ),
							),
						),
						// OR hide if Control 3 is True.
						array(
							'field' => 'tab_3_section_4_complex-group-3',
							'value' => array( '1' ),
						),
					),
				),
			),
		),
	);

	return $wpsf_settings;
}

/**
 * Get countries
 *
 * @return array
 */
function appointy_get_countries( ) {
	global $wpdb;
	
	$countries = $wpdb->get_results("SELECT t.term_id, t.name, t.slug FROM ".$wpdb->prefix."terms AS t INNER JOIN ".$wpdb->prefix."term_taxonomy AS tt ON (t.term_id = tt.term_id) WHERE tt.taxonomy IN ('appointy_country') ORDER BY t.name ASC");
	
	$countryarr[''] = esc_html__( 'Select country', 'appointy' );
	
	if(!empty($countries)) {
		foreach($countries as $country) {
			$countryarr[$country->slug] = $country->name;
		}
    }
	
	return $countryarr;
}

/**
 * Get states
 *
 * @return array
 */
function appointy_get_states( ) {
	global $wpdb;
	
	$default_country = Appointy_Misc_Helper::get_settings( 'general_settings', 'default_country' );
	
	$states = $wpdb->get_results("SELECT t.term_id, t.name, t.slug FROM ".$wpdb->prefix."terms AS t INNER JOIN ".$wpdb->prefix."term_taxonomy AS tt ON (t.term_id = tt.term_id) WHERE tt.taxonomy IN ('appointy_state') ORDER BY t.name ASC");
	
	$statearr[''] = esc_html__( 'Select state', 'appointy' );
	
	$has_state = false;
	
	if(!empty($states)) {
		foreach($states as $state) {
			
			if( $default_country != '' ) {
					
				$country_id = get_term_meta($state->term_id, 'country', true);
				
				if( $country_id > 0 ) {
					$country_slug_row = $wpdb->get_row('SELECT slug FROM '.$wpdb->prefix.'terms WHERE term_id = '.$country_id);
					$country_slug = (!empty($country_slug_row)) ? $country_slug_row->slug : '';
				} else {	
					$country_slug = '';	
				}
				
				if(strtolower($country_slug) === strtolower($default_country)) {
					$has_state = true;
					$statearr[$state->slug] = $state->name;
				}
			} else {
				$has_state = true;
				$statearr[$state->slug] = $state->name;
			}
		}
    }
	
	if( (bool) $has_state === true ) {
		return $statearr;
	} else {
		$statearr[''] = esc_html__( 'Not available', 'appointy' );
		return $statearr;
	}
}


